# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/compiler.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/compiler.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.grpc.qm.pb import inc_qua_pb2 as qm_dot_pb_dot_inc__qua__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from qm.grpc.qm.pb import qm_manager_pb2 as qm_dot_pb_dot_qm__manager__pb2
from qm.grpc.qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14qm/pb/compiler.proto\x12\x10qm.grpc.compiler\x1a\x13qm/pb/inc_qua.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x16qm/pb/qm_manager.proto\x1a\x1cqm/pb/general_messages.proto\"K\n\tQuaValues\x12\x11\n\tint_value\x18\x01 \x01(\r\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\x01\x12\x15\n\rboolean_value\x18\x03 \x01(\x08\"I\n\x0e\x43ompileRequest\x12(\n\x07program\x18\x01 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12\r\n\x05jobId\x18\x02 \x01(\t\"\xdf\x01\n\x0f\x43ompileResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x33\n\x08messages\x18\x02 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12\x0e\n\x06\x62inary\x18\x03 \x01(\x0c\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12;\n\x05\x64\x65\x62ug\x18\x1e \x03(\x0b\x32,.qm.grpc.compiler.CompileResponse.DebugEntry\x1a,\n\nDebugEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x0f\x43ompilerMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x35\n\x05level\x18\x02 \x01(\x0e\x32&.qm.grpc.general_messages.MessageLevel\"S\n\x12ValidationResponse\x12=\n\x08messages\x18\x01 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessage\"G\n\rDynamicConfig\x12\x0f\n\x07version\x18\x01 \x01(\r\x12%\n\x04root\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB)\n\x10qm.grpc.compilerB\rCompilerProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.compiler_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020qm.grpc.compilerB\rCompilerProtoP\001\242\002\003HLW'
  _globals['_COMPILERESPONSE_DEBUGENTRY']._loaded_options = None
  _globals['_COMPILERESPONSE_DEBUGENTRY']._serialized_options = b'8\001'
  _globals['_QUAVALUES']._serialized_start=147
  _globals['_QUAVALUES']._serialized_end=222
  _globals['_COMPILEREQUEST']._serialized_start=224
  _globals['_COMPILEREQUEST']._serialized_end=297
  _globals['_COMPILERESPONSE']._serialized_start=300
  _globals['_COMPILERESPONSE']._serialized_end=523
  _globals['_COMPILERESPONSE_DEBUGENTRY']._serialized_start=479
  _globals['_COMPILERESPONSE_DEBUGENTRY']._serialized_end=523
  _globals['_COMPILERMESSAGE']._serialized_start=525
  _globals['_COMPILERMESSAGE']._serialized_end=614
  _globals['_VALIDATIONRESPONSE']._serialized_start=616
  _globals['_VALIDATIONRESPONSE']._serialized_end=699
  _globals['_DYNAMICCONFIG']._serialized_start=701
  _globals['_DYNAMICCONFIG']._serialized_end=772
# @@protoc_insertion_point(module_scope)
