# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: io/qualang/api/v1/info_service.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'io/qualang/api/v1/info_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$io/qualang/api/v1/info_service.proto\x12\x11io.qualang.api.v1\"\x10\n\x0eGetInfoRequest\"i\n\x0fGetInfoResponse\x12@\n\x0eimplementation\x18\x01 \x01(\x0b\x32(.io.qualang.api.v1.ImplementationDetails\x12\x14\n\x0c\x63\x61pabilities\x18\x02 \x03(\t\"q\n\x15ImplementationDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x1a\n\rproto_version\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_proto_version2a\n\x0bInfoService\x12R\n\x07GetInfo\x12!.io.qualang.api.v1.GetInfoRequest\x1a\".io.qualang.api.v1.GetInfoResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'io.qualang.api.v1.info_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETINFOREQUEST']._serialized_start=59
  _globals['_GETINFOREQUEST']._serialized_end=75
  _globals['_GETINFORESPONSE']._serialized_start=77
  _globals['_GETINFORESPONSE']._serialized_end=182
  _globals['_IMPLEMENTATIONDETAILS']._serialized_start=184
  _globals['_IMPLEMENTATIONDETAILS']._serialized_end=297
  _globals['_INFOSERVICE']._serialized_start=299
  _globals['_INFOSERVICE']._serialized_end=396
# @@protoc_insertion_point(module_scope)
