# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: octave/v1/api.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'octave/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13octave/v1/api.proto\x12\x1dquantummachines.octave.api.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\x17\n\x15SubscribeStateRequest\"\x8e\x01\n\x16SubscribeStateResponse\x12\x39\n\x05state\x18\x01 \x01(\x0e\x32*.quantummachines.octave.api.v1.DeviceState\x12\x39\n\x05\x65rror\x18\x02 \x01(\x0e\x32*.quantummachines.octave.api.v1.DeviceError\"\x0e\n\x0cResetRequest\":\n\rResetResponse\x12\x12\n\nis_success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"F\n\rHealthRequest\x12 \n\x18monitor_interval_seconds\x18\x01 \x01(\r\x12\x13\n\x0bstop_stream\x18\x02 \x01(\x08\"\x92\x01\n\x0eHealthResponse\x12?\n\x07\x65xplore\x18\x01 \x01(\x0b\x32..quantummachines.octave.api.v1.ExploreResponse\x12?\n\x07monitor\x18\x02 \x01(\x0b\x32..quantummachines.octave.api.v1.MonitorResponse\"\x13\n\x11GetVersionRequest\"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"[\n\x0fModuleReference\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.quantummachines.octave.api.v1.OctaveModule\x12\r\n\x05index\x18\x02 \x01(\x05\"\x80\x01\n\x0bSaveRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x07modules\x18\x02 \x03(\x0b\x32..quantummachines.octave.api.v1.ModuleReference\x12\x11\n\toverwrite\x18\x03 \x01(\x08\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\"0\n\x0cSaveResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1b\n\rRecallRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x0eRecallResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"\r\n\x0bListRequest\"\x86\x01\n\x08SaveInfo\x12;\n\x07request\x18\x01 \x01(\x0b\x32*.quantummachines.octave.api.v1.SaveRequest\x12=\n\x07\x63ontent\x18\x02 \x01(\x0b\x32,.quantummachines.octave.api.v1.UpdateRequest\"K\n\x0cListResponse\x12;\n\nsave_infos\x18\x01 \x03(\x0b\x32\'.quantummachines.octave.api.v1.SaveInfo\"$\n\x0eMonitorRequest\x12\x12\n\nsense_only\x18\x01 \x01(\x08\"\xf8\x05\n\x0fMonitorResponse\x12L\n\x07modules\x18\x01 \x03(\x0b\x32;.quantummachines.octave.api.v1.MonitorResponse.ModuleStatus\x1a]\n\x11ModuleStatusError\x12H\n\x04type\x18\x01 \x01(\x0e\x32:.quantummachines.octave.api.v1.MonitorResponse.OctaveError\x1a\xb5\x01\n\x0cModuleStatus\x12>\n\x06module\x18\x01 \x01(\x0b\x32..quantummachines.octave.api.v1.ModuleReference\x12\x13\n\x0btemperature\x18\x02 \x01(\x02\x12P\n\x06\x65rrors\x18\x03 \x03(\x0b\x32@.quantummachines.octave.api.v1.MonitorResponse.ModuleStatusError\"\xff\x02\n\x0bOctaveError\x12\x1c\n\x18OCTAVE_ERROR_UNSPECIFIED\x10\x00\x12#\n\x1fOCTAVE_ERROR_BAD_EXTERNAL_CLOCK\x10\x01\x12#\n\x1fOCTAVE_ERROR_BAD_INTERNAL_CLOCK\x10\x02\x12\x1f\n\x1bOCTAVE_ERROR_FPGA_NOT_FOUND\x10\x03\x12\x1d\n\x19OCTAVE_ERROR_FPGA_HW_FAIL\x10\x04\x12\"\n\x1eOCTAVE_ERROR_FPGA_BITFILE_FAIL\x10\x05\x12!\n\x1dOCTAVE_ERROR_MODULE_NOT_FOUND\x10\x06\x12\x19\n\x15OCTAVE_ERROR_OVERHEAT\x10\x07\x12$\n OCTAVE_ERROR_OVERHEAT_PROTECTION\x10\x08\x12\x1f\n\x1bOCTAVE_ERROR_READ_TEMP_FAIL\x10\t\x12\x1f\n\x1bOCTAVE_ERROR_PLL_NOT_LOCKED\x10\n\"2\n\x0e\x43ontrolRequest\x12\x0e\n\x06w_data\x18\x01 \x01(\x0c\x12\x10\n\x08r_length\x18\x02 \x01(\x05\"\x8f\x01\n\x0f\x43ontrolResponse\x12\x0e\n\x06r_data\x18\x01 \x01(\x0c\"l\n\nRdataDebug\x12\x1b\n\x17RDATA_DEBUG_UNSPECIFIED\x10\x00\x12\x1f\n\x1aRDATA_DEBUG_ERROR_RESPONSE\x10\xa0\x01\x12 \n\x1cRDATA_DEBUG_SUCCESS_RESPONSE\x10 \"\x10\n\x0e\x45xploreRequest\"\xb3\x01\n\x0f\x45xploreResponse\x12H\n\x07modules\x18\x01 \x03(\x0b\x32\x37.quantummachines.octave.api.v1.ExploreResponse.ModuleId\x1aV\n\x08ModuleId\x12>\n\x06module\x18\x01 \x01(\x0b\x32..quantummachines.octave.api.v1.ModuleReference\x12\n\n\x02id\x18\x02 \x01(\t\"M\n\rUpdateRequest\x12<\n\x07updates\x18\x01 \x03(\x0b\x32+.quantummachines.octave.api.v1.SingleUpdate\"8\n\x0eUpdateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"\xb2\x03\n\x0cSingleUpdate\x12\x43\n\nrf_up_conv\x18\x01 \x01(\x0b\x32-.quantummachines.octave.api.v1.RFUpConvUpdateH\x00\x12G\n\x0crf_down_conv\x18\x02 \x01(\x0b\x32/.quantummachines.octave.api.v1.RFDownConvUpdateH\x00\x12G\n\x0cif_down_conv\x18\x03 \x01(\x0b\x32/.quantummachines.octave.api.v1.IFDownConvUpdateH\x00\x12;\n\x05synth\x18\x04 \x01(\x0b\x32*.quantummachines.octave.api.v1.SynthUpdateH\x00\x12;\n\x05\x63lock\x18\x05 \x01(\x0b\x32*.quantummachines.octave.api.v1.ClockUpdateH\x00\x12G\n\x0bmotherboard\x18\x06 \x01(\x0b\x32\x30.quantummachines.octave.api.v1.MotherboardUpdateH\x00\x42\x08\n\x06update\"\xc7\x05\n\x0eRFUpConvUpdate\x12\r\n\x05index\x18\x01 \x01(\r\x12R\n\ninput_attn\x18\x02 \x01(\x0e\x32>.quantummachines.octave.api.v1.RFUpConvUpdate.IfInputSelection\x12+\n\x07\x65nabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x11mixer_output_attn\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x11power_amp_enabled\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0epower_amp_attn\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12V\n\x10\x66\x61st_switch_mode\x18\x07 \x01(\x0e\x32<.quantummachines.octave.api.v1.RFUpConvUpdate.FastSwitchMode\"\x82\x01\n\x10IfInputSelection\x12\"\n\x1eIF_INPUT_SELECTION_UNSPECIFIED\x10\x00\x12#\n\x1fIF_INPUT_SELECTION_PASS_THROUGH\x10\x01\x12%\n!IF_INPUT_SELECTION_ATTENUATE_10DB\x10\x02\"\xa1\x01\n\x0e\x46\x61stSwitchMode\x12 \n\x1c\x46\x41ST_SWITCH_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46\x41ST_SWITCH_MODE_ON\x10\x01\x12\x18\n\x14\x46\x41ST_SWITCH_MODE_OFF\x10\x02\x12\x1b\n\x17\x46\x41ST_SWITCH_MODE_DIRECT\x10\x03\x12\x1d\n\x19\x46\x41ST_SWITCH_MODE_INVERTED\x10\x04\"\x9f\x04\n\x10RFDownConvUpdate\x12\r\n\x05index\x18\x01 \x01(\r\x12I\n\x08rf_input\x18\x02 \x01(\x0e\x32\x37.quantummachines.octave.api.v1.RFDownConvUpdate.RFInput\x12I\n\x08lo_input\x18\x03 \x01(\x0e\x32\x37.quantummachines.octave.api.v1.RFDownConvUpdate.LOInput\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xd8\x01\n\x07RFInput\x12\x18\n\x14RF_INPUT_UNSPECIFIED\x10\x00\x12\x14\n\x10RF_INPUT_DEBUG_1\x10\x01\x12\x14\n\x10RF_INPUT_DEBUG_2\x10\x02\x12\x14\n\x10RF_INPUT_DEBUG_3\x10\x03\x12\x14\n\x10RF_INPUT_DEBUG_4\x10\x04\x12\x14\n\x10RF_INPUT_DEBUG_5\x10\x05\x12\x11\n\rRF_INPUT_MAIN\x10\x06\x12\x19\n\x15RF_INPUT_FPGA_CONTROL\x10\x07\x12\x17\n\x13RF_INPUT_DISCONNECT\x10\x08\"^\n\x07LOInput\x12\x18\n\x14LO_INPUT_UNSPECIFIED\x10\x00\x12\x0e\n\nLO_INPUT_1\x10\x01\x12\x0e\n\nLO_INPUT_2\x10\x02\x12\x19\n\x15LO_INPUT_FPGA_CONTROL\x10\x03\"\x92\x04\n\x10IFDownConvUpdate\x12\r\n\x05index\x18\x01 \x01(\r\x12I\n\x08\x63hannel1\x18\x02 \x01(\x0b\x32\x37.quantummachines.octave.api.v1.IFDownConvUpdate.Channel\x12I\n\x08\x63hannel2\x18\x03 \x01(\x0b\x32\x37.quantummachines.octave.api.v1.IFDownConvUpdate.Channel\x1a\x99\x01\n\x07\x43hannel\x12\x42\n\x04mode\x18\x01 \x01(\x0e\x32\x34.quantummachines.octave.api.v1.IFDownConvUpdate.Mode\x12J\n\x08\x63oupling\x18\x02 \x01(\x0e\x32\x38.quantummachines.octave.api.v1.IFDownConvUpdate.Coupling\"b\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08MODE_OFF\x10\x01\x12\x0f\n\x0bMODE_BYPASS\x10\x02\x12\x15\n\x11MODE_POWER_DETECT\x10\x03\x12\x0e\n\nMODE_MIXER\x10\x04\"Y\n\x08\x43oupling\x12\x18\n\x14\x43OUPLING_UNSPECIFIED\x10\x00\x12\x11\n\rCOUPLING_OPEN\x10\x01\x12\x0f\n\x0b\x43OUPLING_DC\x10\x02\x12\x0f\n\x0b\x43OUPLING_AC\x10\x03\"\xba\x02\n\x0b\x43lockUpdate\x12=\n\x04mode\x18\x02 \x01(\x0e\x32/.quantummachines.octave.api.v1.ClockUpdate.Mode\x12\x35\n\x0f\x63lock_frequency\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x38\n\x12synthesizers_clock\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x16\n\tclustered\x18\x05 \x01(\x08H\x00\x88\x01\x01\"U\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x11\n\rMODE_BUFFERED\x10\x01\x12\x11\n\rMODE_EXTERNAL\x10\x02\x12\x11\n\rMODE_INTERNAL\x10\x03\x42\x0c\n\n_clustered\"D\n\x11MotherboardUpdate\x12/\n\tfan_speed\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xaf\x10\n\x0bSynthUpdate\x12\r\n\x05index\x18\x01 \x01(\r\x12R\n\x0freference_clock\x18\x02 \x01(\x0b\x32\x39.quantummachines.octave.api.v1.SynthUpdate.ReferenceClock\x12L\n\x0csynth_output\x18\x03 \x01(\x0b\x32\x36.quantummachines.octave.api.v1.SynthUpdate.SynthOutput\x12W\n\x12synth_output_power\x18\x04 \x01(\x0e\x32;.quantummachines.octave.api.v1.SynthUpdate.SynthOutputPower\x12,\n\x06heater\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04gain\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0c\x64igital_attn\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12J\n\x0bmain_source\x18\x08 \x01(\x0e\x32\x35.quantummachines.octave.api.v1.SynthUpdate.MainSource\x12J\n\x0bmain_output\x18\t \x01(\x0e\x32\x35.quantummachines.octave.api.v1.SynthUpdate.MainOutput\x12T\n\x10secondary_output\x18\n \x01(\x0e\x32:.quantummachines.octave.api.v1.SynthUpdate.SecondaryOutput\x12I\n\nstabilizer\x18\x0b \x01(\x0b\x32\x35.quantummachines.octave.api.v1.SynthUpdate.Stabilizer\x1a\xbb\x01\n\x0eReferenceClock\x12J\n\x06source\x18\x01 \x01(\x0e\x32:.quantummachines.octave.api.v1.SynthUpdate.ReferenceSource\x12/\n\tfrequency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x07\x64ivider\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1az\n\x0bSynthOutput\x12\x31\n\tfrequency\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueH\x00\x12.\n\x08\x64isabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x42\x08\n\x06update\x1a\xe9\x02\n\nStabilizer\x12(\n\x03k_p\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12(\n\x03k_i\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12(\n\x03k_d\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12&\n\x01\x61\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12&\n\x01\x62\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\nheater_max\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\tset_point\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12+\n\x07\x65nabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"q\n\x0fReferenceSource\x12 \n\x1cREFERENCE_SOURCE_UNSPECIFIED\x10\x00\x12\x1d\n\x19REFERENCE_SOURCE_INTERNAL\x10\x01\x12\x1d\n\x19REFERENCE_SOURCE_EXTERNAL\x10\x02\"\xb2\x01\n\x10SynthOutputPower\x12\"\n\x1eSYNTH_OUTPUT_POWER_UNSPECIFIED\x10\x00\x12\x1d\n\x19SYNTH_OUTPUT_POWER_NEG4DB\x10\x01\x12\x1d\n\x19SYNTH_OUTPUT_POWER_NEG1DB\x10\x02\x12\x1d\n\x19SYNTH_OUTPUT_POWER_POS2DB\x10\x03\x12\x1d\n\x19SYNTH_OUTPUT_POWER_POS5DB\x10\x04\"`\n\nMainSource\x12\x1b\n\x17MAIN_SOURCE_UNSPECIFIED\x10\x00\x12\x18\n\x14MAIN_SOURCE_EXTERNAL\x10\x01\x12\x1b\n\x17MAIN_SOURCE_SYNTHESIZER\x10\x02\"r\n\nMainOutput\x12\x1b\n\x17MAIN_OUTPUT_UNSPECIFIED\x10\x00\x12\x14\n\x10MAIN_OUTPUT_MAIN\x10\x01\x12\x13\n\x0fMAIN_OUTPUT_OFF\x10\x02\x12\x1c\n\x18MAIN_OUTPUT_FPGA_CONTROL\x10\x03\"\xaa\x01\n\x0fSecondaryOutput\x12 \n\x1cSECONDARY_OUTPUT_UNSPECIFIED\x10\x00\x12\x19\n\x15SECONDARY_OUTPUT_MAIN\x10\x01\x12\x1d\n\x19SECONDARY_OUTPUT_AUXILARY\x10\x02\x12\x18\n\x14SECONDARY_OUTPUT_OFF\x10\x03\x12!\n\x1dSECONDARY_OUTPUT_FPGA_CONTROL\x10\x04\"c\n\rAquireRequest\x12?\n\x07modules\x18\x01 \x03(\x0b\x32..quantummachines.octave.api.v1.ModuleReference\x12\x11\n\tuse_cache\x18\x02 \x01(\x08\"M\n\x0e\x41quireResponse\x12;\n\x05state\x18\x01 \x01(\x0b\x32,.quantummachines.octave.api.v1.UpdateRequest\"\x11\n\x0fIdentifyRequest\"\x85\x03\n\x10IdentifyResponse\x12I\n\x10rf_up_converters\x18\x01 \x03(\x0b\x32/.quantummachines.octave.api.v1.RFUpConvIdentity\x12M\n\x12rf_down_converters\x18\x02 \x03(\x0b\x32\x31.quantummachines.octave.api.v1.RFDownConvIdentity\x12M\n\x12if_down_converters\x18\x03 \x03(\x0b\x32\x31.quantummachines.octave.api.v1.IFDownConvIdentity\x12\x42\n\x0csynthesizers\x18\x04 \x03(\x0b\x32,.quantummachines.octave.api.v1.SynthIdentity\x12\x44\n\x0epanel_identity\x18\x05 \x01(\x0b\x32,.quantummachines.octave.api.v1.PanelIdentity\"\x1f\n\x0eUpConvRFOutput\x12\r\n\x05index\x18\x01 \x01(\r\"\xdf\x01\n\rSynthRFOutput\x12\r\n\x05index\x18\x01 \x01(\r\x12L\n\x0boutput_port\x18\x02 \x01(\x0e\x32\x37.quantummachines.octave.api.v1.SynthRFOutput.OutputPort\"q\n\nOutputPort\x12\x1b\n\x17OUTPUT_PORT_UNSPECIFIED\x10\x00\x12\x15\n\x11OUTPUT_PORT_SYNTH\x10\x01\x12\x14\n\x10OUTPUT_PORT_MAIN\x10\x02\x12\x19\n\x15OUTPUT_PORT_SECONDARY\x10\x03\"k\n\x0f\x45xternalRFInput\x12\x18\n\x0elo_input_index\x18\x01 \x01(\rH\x00\x12\x1e\n\x14\x64\x65mod_lo_input_index\x18\x02 \x01(\rH\x00\x12\x15\n\x0brf_in_index\x18\x03 \x01(\rH\x00\x42\x07\n\x05input\"\xba\x02\n\x08RFSource\x12J\n\x11rf_up_conv_output\x18\x01 \x01(\x0b\x32-.quantummachines.octave.api.v1.UpConvRFOutputH\x00\x12\x44\n\x0csynth_output\x18\x02 \x01(\x0b\x32,.quantummachines.octave.api.v1.SynthRFOutputH\x00\x12H\n\x0e\x65xternal_input\x18\x03 \x01(\x0b\x32..quantummachines.octave.api.v1.ExternalRFInputH\x00\x12H\n\x0f\x63onstant_source\x18\x04 \x01(\x0e\x32-.quantummachines.octave.api.v1.ConstantSourceH\x00\x42\x08\n\x06source\"\xc7\x01\n\x12RFDownConvIFSource\x12\r\n\x05index\x18\x01 \x01(\r\x12Q\n\x0boutput_port\x18\x02 \x01(\x0e\x32<.quantummachines.octave.api.v1.RFDownConvIFSource.OutputPort\"O\n\nOutputPort\x12\x1b\n\x17OUTPUT_PORT_UNSPECIFIED\x10\x00\x12\x11\n\rOUTPUT_PORT_I\x10\x01\x12\x11\n\rOUTPUT_PORT_Q\x10\x02\":\n\x12IFDownConvIFSource\x12\r\n\x05index\x18\x01 \x01(\r\x12\x15\n\rchannel_index\x18\x02 \x01(\r\"r\n\x0f\x45xternalIFInput\x12\x11\n\x07i_index\x18\x01 \x01(\rH\x00\x12\x11\n\x07q_index\x18\x02 \x01(\rH\x00\x12\x17\n\rif_lo_i_index\x18\x03 \x01(\rH\x00\x12\x17\n\rif_lo_q_index\x18\x04 \x01(\rH\x00\x42\x07\n\x05input\"\xd3\x02\n\x08IFSource\x12R\n\x15rf_downconv_if_source\x18\x01 \x01(\x0b\x32\x31.quantummachines.octave.api.v1.RFDownConvIFSourceH\x00\x12R\n\x15if_downconv_if_source\x18\x02 \x01(\x0b\x32\x31.quantummachines.octave.api.v1.IFDownConvIFSourceH\x00\x12K\n\x11\x65xternal_if_input\x18\x03 \x01(\x0b\x32..quantummachines.octave.api.v1.ExternalIFInputH\x00\x12H\n\x0f\x63onstant_source\x18\x04 \x01(\x0e\x32-.quantummachines.octave.api.v1.ConstantSourceH\x00\x42\x08\n\x06source\"\xb9\x03\n\x10RFUpConvIdentity\x12\r\n\x05index\x18\x01 \x01(\r\x12R\n\x0c\x63onnectivity\x18\x02 \x01(\x0b\x32<.quantummachines.octave.api.v1.RFUpConvIdentity.Connectivity\x12N\n\nparameters\x18\x03 \x01(\x0b\x32:.quantummachines.octave.api.v1.RFUpConvIdentity.Parameters\x1a\xbd\x01\n\x0c\x43onnectivity\x12\x38\n\x07i_input\x18\x01 \x01(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12\x38\n\x07q_input\x18\x02 \x01(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12\x39\n\x08lo_input\x18\x03 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x1a\x32\n\nParameters\x12\x11\n\tattn_1_db\x18\x01 \x01(\x02\x12\x11\n\tattn_2_db\x18\x02 \x01(\x02\"\x93\x05\n\x12RFDownConvIdentity\x12\r\n\x05index\x18\x01 \x01(\r\x12T\n\x0c\x63onnectivity\x18\x02 \x01(\x0b\x32>.quantummachines.octave.api.v1.RFDownConvIdentity.Connectivity\x1a\x97\x04\n\x0c\x43onnectivity\x12\x41\n\x10\x64\x65\x62ug_rf_input_1\x18\x01 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12\x41\n\x10\x64\x65\x62ug_rf_input_2\x18\x02 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12\x41\n\x10\x64\x65\x62ug_rf_input_3\x18\x03 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12\x41\n\x10\x64\x65\x62ug_rf_input_4\x18\x04 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12\x41\n\x10\x64\x65\x62ug_rf_input_5\x18\x05 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12>\n\rrf_main_input\x18\x06 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12;\n\nlo_input_1\x18\x07 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12;\n\nlo_input_2\x18\x08 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\"\x98\x03\n\x12IFDownConvIdentity\x12\r\n\x05index\x18\x01 \x01(\r\x12T\n\x0c\x63onnectivity\x18\x02 \x01(\x0b\x32>.quantummachines.octave.api.v1.IFDownConvIdentity.Connectivity\x1a\x9c\x02\n\x0c\x43onnectivity\x12@\n\x0f\x63hannel_1_input\x18\x01 \x01(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12\x43\n\x12\x63hannel_1_lo_input\x18\x02 \x01(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12@\n\x0f\x63hannel_2_input\x18\x03 \x01(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12\x43\n\x12\x63hannel_2_lo_input\x18\x04 \x01(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\"\x83\x06\n\rSynthIdentity\x12\r\n\x05index\x18\x01 \x01(\r\x12O\n\x0c\x63onnectivity\x18\x02 \x01(\x0b\x32\x39.quantummachines.octave.api.v1.SynthIdentity.Connectivity\x12K\n\nparameters\x18\x03 \x01(\x0b\x32\x37.quantummachines.octave.api.v1.SynthIdentity.Parameters\x1a\x93\x01\n\x0c\x43onnectivity\x12>\n\rmain_lo_input\x18\x01 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x12\x43\n\x12secondary_lo_input\x18\x02 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x1a\xae\x03\n\nParameters\x12i\n\x15low_frequency_filters\x18\x01 \x03(\x0b\x32J.quantummachines.octave.api.v1.SynthIdentity.Parameters.LowFrequencyFilter\x12k\n\x17medium_frequency_filter\x18\x02 \x01(\x0b\x32J.quantummachines.octave.api.v1.SynthIdentity.Parameters.ParametrizedFilter\x12i\n\x15high_frequency_filter\x18\x03 \x01(\x0b\x32J.quantummachines.octave.api.v1.SynthIdentity.Parameters.ParametrizedFilter\x1aG\n\x12LowFrequencyFilter\x12\r\n\x05index\x18\x01 \x01(\r\x12\x10\n\x08\x66ilter_1\x18\x02 \x01(\t\x12\x10\n\x08\x66ilter_2\x18\x03 \x01(\t\x1a\x14\n\x12ParametrizedFilter\"\xd2\x03\n\rPanelIdentity\x12I\n\nrf_outputs\x18\x01 \x03(\x0b\x32\x35.quantummachines.octave.api.v1.PanelIdentity.RFOutput\x12<\n\x0bif_output_i\x18\x02 \x03(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12<\n\x0bif_output_q\x18\x03 \x03(\x0b\x32\'.quantummachines.octave.api.v1.IFSource\x12O\n\rsynth_outputs\x18\x04 \x03(\x0b\x32\x38.quantummachines.octave.api.v1.PanelIdentity.SynthOutput\x1aR\n\x08RFOutput\x12\r\n\x05index\x18\x01 \x01(\r\x12\x37\n\x06source\x18\x02 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\x1aU\n\x0bSynthOutput\x12\r\n\x05index\x18\x01 \x01(\r\x12\x37\n\x06source\x18\x02 \x01(\x0b\x32\'.quantummachines.octave.api.v1.RFSource\")\n\x11MotherboardStatus\x12\x14\n\x0cvalid_1g_vco\x18\x01 \x01(\x08*\xf7\x01\n\x0b\x44\x65viceState\x12\x1c\n\x18\x44\x45VICE_STATE_UNSPECIFIED\x10\x00\x12 \n\x1c\x44\x45VICE_STATE_NON_OPERATIONAL\x10\x01\x12\x17\n\x13\x44\x45VICE_STATE_BOOTED\x10\x02\x12\x1b\n\x17\x44\x45VICE_STATE_CONFIGURED\x10\x03\x12\x1c\n\x18\x44\x45VICE_STATE_CLOCK_READY\x10\x04\x12\x1c\n\x18\x44\x45VICE_STATE_INITIALIZED\x10\x05\x12\x1c\n\x18\x44\x45VICE_STATE_OPERATIONAL\x10\x06\x12\x18\n\x14\x44\x45VICE_STATE_ERRORED\x10\x07*\xc4\x05\n\x0b\x44\x65viceError\x12\x1c\n\x18\x44\x45VICE_ERROR_UNSPECIFIED\x10\x00\x12\x14\n\x10\x44\x45VICE_ERROR_PLL\x10\x01\x12#\n\x1f\x44\x45VICE_ERROR_MOTHERBOARD_FW_UPD\x10\x02\x12\x1f\n\x1b\x44\x45VICE_ERROR_MODULES_DETECT\x10\x03\x12\x1d\n\x19\x44\x45VICE_ERROR_SYNTH_FW_UPD\x10\x04\x12\x1b\n\x17\x44\x45VICE_ERROR_SYNTH_COMM\x10\x05\x12\x1b\n\x17\x44\x45VICE_ERROR_START_FPGA\x10\x06\x12\x1c\n\x18\x44\x45VICE_ERROR_ATTACH_FPGA\x10\x07\x12\x19\n\x15\x44\x45VICE_ERROR_MAIN_PIC\x10\x08\x12\x1a\n\x16\x44\x45VICE_ERROR_GPIO_COMM\x10\t\x12\x1e\n\x1a\x44\x45VICE_ERROR_FPGA_OVERHEAT\x10\n\x12\x1d\n\x19\x44\x45VICE_ERROR_FPGA_HW_FAIL\x10\x0b\x12 \n\x1c\x44\x45VICE_ERROR_BAD_INPUT_CLOCK\x10\x0c\x12\x1f\n\x1b\x44\x45VICE_ERROR_SYNTH_OVERHEAT\x10\r\x12\x1f\n\x1b\x44\x45VICE_ERROR_SYNTH_BAD_READ\x10\x0e\x12&\n\"DEVICE_ERROR_IF_DOWN_CONV_OVERHEAT\x10\x0f\x12&\n\"DEVICE_ERROR_IF_DOWN_CONV_BAD_READ\x10\x10\x12&\n\"DEVICE_ERROR_RF_DOWN_CONV_OVERHEAT\x10\x11\x12&\n\"DEVICE_ERROR_RF_DOWN_CONV_BAD_READ\x10\x12\x12$\n DEVICE_ERROR_RF_UP_CONV_OVERHEAT\x10\x13\x12$\n DEVICE_ERROR_RF_UP_CONV_BAD_READ\x10\x14*\xec\x01\n\x0cOctaveModule\x12\x1d\n\x19OCTAVE_MODULE_UNSPECIFIED\x10\x00\x12 \n\x1cOCTAVE_MODULE_RF_UPCONVERTER\x10\x01\x12\"\n\x1eOCTAVE_MODULE_RF_DOWNCONVERTER\x10\x02\x12\"\n\x1eOCTAVE_MODULE_IF_DOWNCONVERTER\x10\x03\x12\x1d\n\x19OCTAVE_MODULE_SYNTHESIZER\x10\x04\x12\x1d\n\x19OCTAVE_MODULE_MOTHERBOARD\x10\x05\x12\x15\n\x11OCTAVE_MODULE_SOM\x10\x06*\x82\x01\n\x0e\x43onstantSource\x12\x1f\n\x1b\x43ONSTANT_SOURCE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x43ONSTANT_SOURCE_50_OHM\x10\x01\x12\x19\n\x15\x43ONSTANT_SOURCE_SHORT\x10\x02\x12\x18\n\x14\x43ONSTANT_SOURCE_OPEN\x10\x03\x32\x8f\x0b\n\rOctaveService\x12\x81\x01\n\x0eSubscribeState\x12\x34.quantummachines.octave.api.v1.SubscribeStateRequest\x1a\x35.quantummachines.octave.api.v1.SubscribeStateResponse\"\x00\x30\x01\x12s\n\nGetVersion\x12\x30.quantummachines.octave.api.v1.GetVersionRequest\x1a\x31.quantummachines.octave.api.v1.GetVersionResponse\"\x00\x12j\n\x07\x43ontrol\x12-.quantummachines.octave.api.v1.ControlRequest\x1a..quantummachines.octave.api.v1.ControlResponse\"\x00\x12g\n\x06Update\x12,.quantummachines.octave.api.v1.UpdateRequest\x1a-.quantummachines.octave.api.v1.UpdateResponse\"\x00\x12g\n\x06\x41quire\x12,.quantummachines.octave.api.v1.AquireRequest\x1a-.quantummachines.octave.api.v1.AquireResponse\"\x00\x12m\n\x08Identify\x12..quantummachines.octave.api.v1.IdentifyRequest\x1a/.quantummachines.octave.api.v1.IdentifyResponse\"\x00\x12j\n\x07Monitor\x12-.quantummachines.octave.api.v1.MonitorRequest\x1a..quantummachines.octave.api.v1.MonitorResponse\"\x00\x12j\n\x07\x45xplore\x12-.quantummachines.octave.api.v1.ExploreRequest\x1a..quantummachines.octave.api.v1.ExploreResponse\"\x00\x12\x61\n\x04Save\x12*.quantummachines.octave.api.v1.SaveRequest\x1a+.quantummachines.octave.api.v1.SaveResponse\"\x00\x12g\n\x06Recall\x12,.quantummachines.octave.api.v1.RecallRequest\x1a-.quantummachines.octave.api.v1.RecallResponse\"\x00\x12\x61\n\x04List\x12*.quantummachines.octave.api.v1.ListRequest\x1a+.quantummachines.octave.api.v1.ListResponse\"\x00\x12\x64\n\x05Reset\x12+.quantummachines.octave.api.v1.ResetRequest\x1a,.quantummachines.octave.api.v1.ResetResponse\"\x00\x12k\n\x06Health\x12,.quantummachines.octave.api.v1.HealthRequest\x1a-.quantummachines.octave.api.v1.HealthResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'octave.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEVICESTATE']._serialized_start=12054
  _globals['_DEVICESTATE']._serialized_end=12301
  _globals['_DEVICEERROR']._serialized_start=12304
  _globals['_DEVICEERROR']._serialized_end=13012
  _globals['_OCTAVEMODULE']._serialized_start=13015
  _globals['_OCTAVEMODULE']._serialized_end=13251
  _globals['_CONSTANTSOURCE']._serialized_start=13254
  _globals['_CONSTANTSOURCE']._serialized_end=13384
  _globals['_SUBSCRIBESTATEREQUEST']._serialized_start=86
  _globals['_SUBSCRIBESTATEREQUEST']._serialized_end=109
  _globals['_SUBSCRIBESTATERESPONSE']._serialized_start=112
  _globals['_SUBSCRIBESTATERESPONSE']._serialized_end=254
  _globals['_RESETREQUEST']._serialized_start=256
  _globals['_RESETREQUEST']._serialized_end=270
  _globals['_RESETRESPONSE']._serialized_start=272
  _globals['_RESETRESPONSE']._serialized_end=330
  _globals['_HEALTHREQUEST']._serialized_start=332
  _globals['_HEALTHREQUEST']._serialized_end=402
  _globals['_HEALTHRESPONSE']._serialized_start=405
  _globals['_HEALTHRESPONSE']._serialized_end=551
  _globals['_GETVERSIONREQUEST']._serialized_start=553
  _globals['_GETVERSIONREQUEST']._serialized_end=572
  _globals['_GETVERSIONRESPONSE']._serialized_start=574
  _globals['_GETVERSIONRESPONSE']._serialized_end=611
  _globals['_MODULEREFERENCE']._serialized_start=613
  _globals['_MODULEREFERENCE']._serialized_end=704
  _globals['_SAVEREQUEST']._serialized_start=707
  _globals['_SAVEREQUEST']._serialized_end=835
  _globals['_SAVERESPONSE']._serialized_start=837
  _globals['_SAVERESPONSE']._serialized_end=885
  _globals['_RECALLREQUEST']._serialized_start=887
  _globals['_RECALLREQUEST']._serialized_end=914
  _globals['_RECALLRESPONSE']._serialized_start=916
  _globals['_RECALLRESPONSE']._serialized_end=972
  _globals['_LISTREQUEST']._serialized_start=974
  _globals['_LISTREQUEST']._serialized_end=987
  _globals['_SAVEINFO']._serialized_start=990
  _globals['_SAVEINFO']._serialized_end=1124
  _globals['_LISTRESPONSE']._serialized_start=1126
  _globals['_LISTRESPONSE']._serialized_end=1201
  _globals['_MONITORREQUEST']._serialized_start=1203
  _globals['_MONITORREQUEST']._serialized_end=1239
  _globals['_MONITORRESPONSE']._serialized_start=1242
  _globals['_MONITORRESPONSE']._serialized_end=2002
  _globals['_MONITORRESPONSE_MODULESTATUSERROR']._serialized_start=1339
  _globals['_MONITORRESPONSE_MODULESTATUSERROR']._serialized_end=1432
  _globals['_MONITORRESPONSE_MODULESTATUS']._serialized_start=1435
  _globals['_MONITORRESPONSE_MODULESTATUS']._serialized_end=1616
  _globals['_MONITORRESPONSE_OCTAVEERROR']._serialized_start=1619
  _globals['_MONITORRESPONSE_OCTAVEERROR']._serialized_end=2002
  _globals['_CONTROLREQUEST']._serialized_start=2004
  _globals['_CONTROLREQUEST']._serialized_end=2054
  _globals['_CONTROLRESPONSE']._serialized_start=2057
  _globals['_CONTROLRESPONSE']._serialized_end=2200
  _globals['_CONTROLRESPONSE_RDATADEBUG']._serialized_start=2092
  _globals['_CONTROLRESPONSE_RDATADEBUG']._serialized_end=2200
  _globals['_EXPLOREREQUEST']._serialized_start=2202
  _globals['_EXPLOREREQUEST']._serialized_end=2218
  _globals['_EXPLORERESPONSE']._serialized_start=2221
  _globals['_EXPLORERESPONSE']._serialized_end=2400
  _globals['_EXPLORERESPONSE_MODULEID']._serialized_start=2314
  _globals['_EXPLORERESPONSE_MODULEID']._serialized_end=2400
  _globals['_UPDATEREQUEST']._serialized_start=2402
  _globals['_UPDATEREQUEST']._serialized_end=2479
  _globals['_UPDATERESPONSE']._serialized_start=2481
  _globals['_UPDATERESPONSE']._serialized_end=2537
  _globals['_SINGLEUPDATE']._serialized_start=2540
  _globals['_SINGLEUPDATE']._serialized_end=2974
  _globals['_RFUPCONVUPDATE']._serialized_start=2977
  _globals['_RFUPCONVUPDATE']._serialized_end=3688
  _globals['_RFUPCONVUPDATE_IFINPUTSELECTION']._serialized_start=3394
  _globals['_RFUPCONVUPDATE_IFINPUTSELECTION']._serialized_end=3524
  _globals['_RFUPCONVUPDATE_FASTSWITCHMODE']._serialized_start=3527
  _globals['_RFUPCONVUPDATE_FASTSWITCHMODE']._serialized_end=3688
  _globals['_RFDOWNCONVUPDATE']._serialized_start=3691
  _globals['_RFDOWNCONVUPDATE']._serialized_end=4234
  _globals['_RFDOWNCONVUPDATE_RFINPUT']._serialized_start=3922
  _globals['_RFDOWNCONVUPDATE_RFINPUT']._serialized_end=4138
  _globals['_RFDOWNCONVUPDATE_LOINPUT']._serialized_start=4140
  _globals['_RFDOWNCONVUPDATE_LOINPUT']._serialized_end=4234
  _globals['_IFDOWNCONVUPDATE']._serialized_start=4237
  _globals['_IFDOWNCONVUPDATE']._serialized_end=4767
  _globals['_IFDOWNCONVUPDATE_CHANNEL']._serialized_start=4423
  _globals['_IFDOWNCONVUPDATE_CHANNEL']._serialized_end=4576
  _globals['_IFDOWNCONVUPDATE_MODE']._serialized_start=4578
  _globals['_IFDOWNCONVUPDATE_MODE']._serialized_end=4676
  _globals['_IFDOWNCONVUPDATE_COUPLING']._serialized_start=4678
  _globals['_IFDOWNCONVUPDATE_COUPLING']._serialized_end=4767
  _globals['_CLOCKUPDATE']._serialized_start=4770
  _globals['_CLOCKUPDATE']._serialized_end=5084
  _globals['_CLOCKUPDATE_MODE']._serialized_start=4985
  _globals['_CLOCKUPDATE_MODE']._serialized_end=5070
  _globals['_MOTHERBOARDUPDATE']._serialized_start=5086
  _globals['_MOTHERBOARDUPDATE']._serialized_end=5154
  _globals['_SYNTHUPDATE']._serialized_start=5157
  _globals['_SYNTHUPDATE']._serialized_end=7252
  _globals['_SYNTHUPDATE_REFERENCECLOCK']._serialized_start=5894
  _globals['_SYNTHUPDATE_REFERENCECLOCK']._serialized_end=6081
  _globals['_SYNTHUPDATE_SYNTHOUTPUT']._serialized_start=6083
  _globals['_SYNTHUPDATE_SYNTHOUTPUT']._serialized_end=6205
  _globals['_SYNTHUPDATE_STABILIZER']._serialized_start=6208
  _globals['_SYNTHUPDATE_STABILIZER']._serialized_end=6569
  _globals['_SYNTHUPDATE_REFERENCESOURCE']._serialized_start=6571
  _globals['_SYNTHUPDATE_REFERENCESOURCE']._serialized_end=6684
  _globals['_SYNTHUPDATE_SYNTHOUTPUTPOWER']._serialized_start=6687
  _globals['_SYNTHUPDATE_SYNTHOUTPUTPOWER']._serialized_end=6865
  _globals['_SYNTHUPDATE_MAINSOURCE']._serialized_start=6867
  _globals['_SYNTHUPDATE_MAINSOURCE']._serialized_end=6963
  _globals['_SYNTHUPDATE_MAINOUTPUT']._serialized_start=6965
  _globals['_SYNTHUPDATE_MAINOUTPUT']._serialized_end=7079
  _globals['_SYNTHUPDATE_SECONDARYOUTPUT']._serialized_start=7082
  _globals['_SYNTHUPDATE_SECONDARYOUTPUT']._serialized_end=7252
  _globals['_AQUIREREQUEST']._serialized_start=7254
  _globals['_AQUIREREQUEST']._serialized_end=7353
  _globals['_AQUIRERESPONSE']._serialized_start=7355
  _globals['_AQUIRERESPONSE']._serialized_end=7432
  _globals['_IDENTIFYREQUEST']._serialized_start=7434
  _globals['_IDENTIFYREQUEST']._serialized_end=7451
  _globals['_IDENTIFYRESPONSE']._serialized_start=7454
  _globals['_IDENTIFYRESPONSE']._serialized_end=7843
  _globals['_UPCONVRFOUTPUT']._serialized_start=7845
  _globals['_UPCONVRFOUTPUT']._serialized_end=7876
  _globals['_SYNTHRFOUTPUT']._serialized_start=7879
  _globals['_SYNTHRFOUTPUT']._serialized_end=8102
  _globals['_SYNTHRFOUTPUT_OUTPUTPORT']._serialized_start=7989
  _globals['_SYNTHRFOUTPUT_OUTPUTPORT']._serialized_end=8102
  _globals['_EXTERNALRFINPUT']._serialized_start=8104
  _globals['_EXTERNALRFINPUT']._serialized_end=8211
  _globals['_RFSOURCE']._serialized_start=8214
  _globals['_RFSOURCE']._serialized_end=8528
  _globals['_RFDOWNCONVIFSOURCE']._serialized_start=8531
  _globals['_RFDOWNCONVIFSOURCE']._serialized_end=8730
  _globals['_RFDOWNCONVIFSOURCE_OUTPUTPORT']._serialized_start=8651
  _globals['_RFDOWNCONVIFSOURCE_OUTPUTPORT']._serialized_end=8730
  _globals['_IFDOWNCONVIFSOURCE']._serialized_start=8732
  _globals['_IFDOWNCONVIFSOURCE']._serialized_end=8790
  _globals['_EXTERNALIFINPUT']._serialized_start=8792
  _globals['_EXTERNALIFINPUT']._serialized_end=8906
  _globals['_IFSOURCE']._serialized_start=8909
  _globals['_IFSOURCE']._serialized_end=9248
  _globals['_RFUPCONVIDENTITY']._serialized_start=9251
  _globals['_RFUPCONVIDENTITY']._serialized_end=9692
  _globals['_RFUPCONVIDENTITY_CONNECTIVITY']._serialized_start=9451
  _globals['_RFUPCONVIDENTITY_CONNECTIVITY']._serialized_end=9640
  _globals['_RFUPCONVIDENTITY_PARAMETERS']._serialized_start=9642
  _globals['_RFUPCONVIDENTITY_PARAMETERS']._serialized_end=9692
  _globals['_RFDOWNCONVIDENTITY']._serialized_start=9695
  _globals['_RFDOWNCONVIDENTITY']._serialized_end=10354
  _globals['_RFDOWNCONVIDENTITY_CONNECTIVITY']._serialized_start=9819
  _globals['_RFDOWNCONVIDENTITY_CONNECTIVITY']._serialized_end=10354
  _globals['_IFDOWNCONVIDENTITY']._serialized_start=10357
  _globals['_IFDOWNCONVIDENTITY']._serialized_end=10765
  _globals['_IFDOWNCONVIDENTITY_CONNECTIVITY']._serialized_start=10481
  _globals['_IFDOWNCONVIDENTITY_CONNECTIVITY']._serialized_end=10765
  _globals['_SYNTHIDENTITY']._serialized_start=10768
  _globals['_SYNTHIDENTITY']._serialized_end=11539
  _globals['_SYNTHIDENTITY_CONNECTIVITY']._serialized_start=10959
  _globals['_SYNTHIDENTITY_CONNECTIVITY']._serialized_end=11106
  _globals['_SYNTHIDENTITY_PARAMETERS']._serialized_start=11109
  _globals['_SYNTHIDENTITY_PARAMETERS']._serialized_end=11539
  _globals['_SYNTHIDENTITY_PARAMETERS_LOWFREQUENCYFILTER']._serialized_start=11446
  _globals['_SYNTHIDENTITY_PARAMETERS_LOWFREQUENCYFILTER']._serialized_end=11517
  _globals['_SYNTHIDENTITY_PARAMETERS_PARAMETRIZEDFILTER']._serialized_start=11519
  _globals['_SYNTHIDENTITY_PARAMETERS_PARAMETRIZEDFILTER']._serialized_end=11539
  _globals['_PANELIDENTITY']._serialized_start=11542
  _globals['_PANELIDENTITY']._serialized_end=12008
  _globals['_PANELIDENTITY_RFOUTPUT']._serialized_start=11839
  _globals['_PANELIDENTITY_RFOUTPUT']._serialized_end=11921
  _globals['_PANELIDENTITY_SYNTHOUTPUT']._serialized_start=11923
  _globals['_PANELIDENTITY_SYNTHOUTPUT']._serialized_end=12008
  _globals['_MOTHERBOARDSTATUS']._serialized_start=12010
  _globals['_MOTHERBOARDSTATUS']._serialized_end=12051
  _globals['_OCTAVESERVICE']._serialized_start=13387
  _globals['_OCTAVESERVICE']._serialized_end=14810
# @@protoc_insertion_point(module_scope)
