# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/inc_qm_api.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/inc_qm_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.grpc.qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.grpc.qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16qm/pb/inc_qm_api.proto\x12\x0eqm.grpc.qm_api\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x1cqm/pb/general_messages.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xd7\x16\n\x10HighQmApiRequest\x12,\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x18.qm.grpc.qm_api.QmConfigB\x02\x18\x01\x12\x37\n\x0cstrongConfig\x18\x02 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfigB\x02\x18\x01\x12\x18\n\x10quantumMachineId\x18\x03 \x01(\t\x12G\n\rsetCorrection\x18\x33 \x01(\x0b\x32..qm.grpc.qm_api.HighQmApiRequest.SetCorrectionH\x00\x12\x45\n\x0csetFrequency\x18\x34 \x01(\x0b\x32-.qm.grpc.qm_api.HighQmApiRequest.SetFrequencyH\x00\x12G\n\x0bsetDcOffset\x18\x35 \x01(\x0b\x32,.qm.grpc.qm_api.HighQmApiRequest.SetDcOffsetB\x02\x18\x01H\x00\x12K\n\x0fsetDigitalRoute\x18\x36 \x01(\x0b\x32\x30.qm.grpc.qm_api.HighQmApiRequest.SetDigitalRouteH\x00\x12\x43\n\x0bsetIOValues\x18\x37 \x01(\x0b\x32,.qm.grpc.qm_api.HighQmApiRequest.SetIOValuesH\x00\x12M\n\x10setInputDcOffset\x18\x38 \x01(\x0b\x32\x31.qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffsetH\x00\x12O\n\x11setOutputDcOffset\x18\x39 \x01(\x0b\x32\x32.qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffsetH\x00\x12S\n\x13setOutputFilterTaps\x18: \x01(\x0b\x32\x34.qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTapsH\x00\x12]\n\x18setDigitalInputThreshold\x18; \x01(\x0b\x32\x39.qm.grpc.qm_api.HighQmApiRequest.SetDigitalInputThresholdH\x00\x12[\n\x17setDigitalInputDeadtime\x18= \x01(\x0b\x32\x38.qm.grpc.qm_api.HighQmApiRequest.SetDigitalInputDeadtimeH\x00\x12[\n\x17setDigitalInputPolarity\x18? \x01(\x0b\x32\x38.qm.grpc.qm_api.HighQmApiRequest.SetDigitalInputPolarityH\x00\x1a\xab\x01\n\rSetCorrection\x12*\n\ncorrection\x18\x01 \x01(\x0b\x32\x16.qm.grpc.qm_api.Matrix\x12\x0c\n\x02qe\x18\n \x01(\tH\x00\x12H\n\x05mixer\x18\x0b \x01(\x0b\x32\x37.qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfoH\x00\x42\x16\n\x14oneof_set_correction\x1a\xbe\x01\n\x16SetCorrectionMixerInfo\x12\r\n\x05mixer\x18\x01 \x01(\t\x12!\n\x15intermediateFrequency\x18\x02 \x01(\x04\x42\x02\x18\x01\x12\x17\n\x0bloFrequency\x18\x03 \x01(\x04\x42\x02\x18\x01\x12\x19\n\x11\x66requencyNegative\x18\x04 \x01(\x08\x12#\n\x1bintermediateFrequencyDouble\x18\x05 \x01(\x01\x12\x19\n\x11loFrequencyDouble\x18\x06 \x01(\x01\x1a\x42\n\x0cSetFrequency\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x02qe\x18\n \x01(\tH\x00\x42\x15\n\x13oneof_set_frequency\x1aj\n\x0bSetDcOffset\x12\t\n\x01I\x18\x01 \x01(\x01\x12\t\n\x01Q\x18\x02 \x01(\x01\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x0e\n\x0coneof_set_dc\x1ap\n\x11SetOutputDcOffset\x12\t\n\x01I\x18\x01 \x01(\x01\x12\t\n\x01Q\x18\x02 \x01(\x01\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x0e\n\x0coneof_set_dc\x1a\xae\x01\n\x13SetOutputFilterTaps\x12G\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x37.qm.grpc.qm_api.HighQmApiRequest.AnalogOutputPortFilter\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x17\n\x15oneof_set_filter_Taps\x1a?\n\x16\x41nalogOutputPortFilter\x12\x13\n\x0b\x66\x65\x65\x64\x66orward\x18\x01 \x03(\x01\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x03(\x01\x1ai\n\x10SetInputDcOffset\x12\x0e\n\x06offset\x18\x01 \x01(\x01\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x0e\n\x0coneof_set_dc\x1a\xd3\x01\n\x0fSetDigitalRoute\x12\r\n\x05value\x18\x01 \x01(\r\x12\x38\n\x05\x64\x65lay\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x12\x39\n\x06\x62uffer\x18\x0b \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x12\r\n\x03tof\x18\x0c \x01(\tH\x00\x12\x12\n\x08smearing\x18\r \x01(\tH\x00\x42\x19\n\x17oneof_set_digital_route\x1a|\n\x0bSetIOValues\x12\r\n\x03\x61ll\x18\x01 \x01(\x08H\x00\x12G\n\x0eioValueSetData\x18\x33 \x03(\x0b\x32/.qm.grpc.qm_api.HighQmApiRequest.IOValueSetDataB\x0f\n\roneof_setTypeJ\x04\x08\x02\x10\x33\x1a\"\n\x06QePort\x12\n\n\x02qe\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\t\x1aw\n\x0eIOValueSetData\x12\x11\n\tio_number\x18\x01 \x01(\x05\x12\x12\n\x08intValue\x18\x02 \x01(\x05H\x00\x12\x15\n\x0b\x64oubleValue\x18\x03 \x01(\x01H\x00\x12\x16\n\x0c\x62ooleanValue\x18\x04 \x01(\x08H\x00\x42\x0f\n\roneof_IO_type\x1a\x64\n\x18SetDigitalInputThreshold\x12\x35\n\x0b\x64igitalPort\x18\x01 \x01(\x0b\x32 .qm.grpc.qm_api.DigitalInputPort\x12\x11\n\tthreshold\x18\x02 \x01(\x01\x1a\x8c\x01\n\x17SetDigitalInputPolarity\x12\x35\n\x0b\x64igitalPort\x18\x01 \x01(\x0b\x32 .qm.grpc.qm_api.DigitalInputPort\x12:\n\x08polarity\x18\x02 \x01(\x0e\x32(.qm.grpc.qm_api.DigitalInputPortPolarity\x1a\x62\n\x17SetDigitalInputDeadtime\x12\x35\n\x0b\x64igitalPort\x18\x01 \x01(\x0b\x32 .qm.grpc.qm_api.DigitalInputPort\x12\x10\n\x08\x64\x65\x61\x64time\x18\x02 \x01(\rB\x0b\n\tapi_oneofJ\x04\x08\x04\x10\x33\"R\n\x10\x44igitalInputPort\x12\x16\n\x0e\x63ontrollerName\x18\x01 \x01(\t\x12\x12\n\nportNumber\x18\x02 \x01(\r\x12\x12\n\nfem_Number\x18\x03 \x01(\r\"W\n\x11HighQmApiResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x02 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\"B\n\x08QmConfig\x12\x0f\n\x07version\x18\x01 \x01(\r\x12%\n\x04root\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"<\n\x06Matrix\x12\x0b\n\x03v00\x18\x01 \x01(\x01\x12\x0b\n\x03v01\x18\x02 \x01(\x01\x12\x0b\n\x03v10\x18\x03 \x01(\x01\x12\x0b\n\x03v11\x18\x04 \x01(\x01\"3\n\rPortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r*3\n\x18\x44igitalInputPortPolarity\x12\n\n\x06RISING\x10\x00\x12\x0b\n\x07\x46\x41LLING\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.inc_qm_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO'].fields_by_name['intermediateFrequency']._loaded_options = None
  _globals['_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO'].fields_by_name['intermediateFrequency']._serialized_options = b'\030\001'
  _globals['_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO'].fields_by_name['loFrequency']._loaded_options = None
  _globals['_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO'].fields_by_name['loFrequency']._serialized_options = b'\030\001'
  _globals['_HIGHQMAPIREQUEST'].fields_by_name['config']._loaded_options = None
  _globals['_HIGHQMAPIREQUEST'].fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_HIGHQMAPIREQUEST'].fields_by_name['strongConfig']._loaded_options = None
  _globals['_HIGHQMAPIREQUEST'].fields_by_name['strongConfig']._serialized_options = b'\030\001'
  _globals['_HIGHQMAPIREQUEST'].fields_by_name['setDcOffset']._loaded_options = None
  _globals['_HIGHQMAPIREQUEST'].fields_by_name['setDcOffset']._serialized_options = b'\030\001'
  _globals['_DIGITALINPUTPORTPOLARITY']._serialized_start=3392
  _globals['_DIGITALINPUTPORTPOLARITY']._serialized_end=3443
  _globals['_HIGHQMAPIREQUEST']._serialized_start=131
  _globals['_HIGHQMAPIREQUEST']._serialized_end=3034
  _globals['_HIGHQMAPIREQUEST_SETCORRECTION']._serialized_start=1170
  _globals['_HIGHQMAPIREQUEST_SETCORRECTION']._serialized_end=1341
  _globals['_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO']._serialized_start=1344
  _globals['_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO']._serialized_end=1534
  _globals['_HIGHQMAPIREQUEST_SETFREQUENCY']._serialized_start=1536
  _globals['_HIGHQMAPIREQUEST_SETFREQUENCY']._serialized_end=1602
  _globals['_HIGHQMAPIREQUEST_SETDCOFFSET']._serialized_start=1604
  _globals['_HIGHQMAPIREQUEST_SETDCOFFSET']._serialized_end=1710
  _globals['_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET']._serialized_start=1712
  _globals['_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET']._serialized_end=1824
  _globals['_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS']._serialized_start=1827
  _globals['_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS']._serialized_end=2001
  _globals['_HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER']._serialized_start=2003
  _globals['_HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER']._serialized_end=2066
  _globals['_HIGHQMAPIREQUEST_SETINPUTDCOFFSET']._serialized_start=2068
  _globals['_HIGHQMAPIREQUEST_SETINPUTDCOFFSET']._serialized_end=2173
  _globals['_HIGHQMAPIREQUEST_SETDIGITALROUTE']._serialized_start=2176
  _globals['_HIGHQMAPIREQUEST_SETDIGITALROUTE']._serialized_end=2387
  _globals['_HIGHQMAPIREQUEST_SETIOVALUES']._serialized_start=2389
  _globals['_HIGHQMAPIREQUEST_SETIOVALUES']._serialized_end=2513
  _globals['_HIGHQMAPIREQUEST_QEPORT']._serialized_start=2515
  _globals['_HIGHQMAPIREQUEST_QEPORT']._serialized_end=2549
  _globals['_HIGHQMAPIREQUEST_IOVALUESETDATA']._serialized_start=2551
  _globals['_HIGHQMAPIREQUEST_IOVALUESETDATA']._serialized_end=2670
  _globals['_HIGHQMAPIREQUEST_SETDIGITALINPUTTHRESHOLD']._serialized_start=2672
  _globals['_HIGHQMAPIREQUEST_SETDIGITALINPUTTHRESHOLD']._serialized_end=2772
  _globals['_HIGHQMAPIREQUEST_SETDIGITALINPUTPOLARITY']._serialized_start=2775
  _globals['_HIGHQMAPIREQUEST_SETDIGITALINPUTPOLARITY']._serialized_end=2915
  _globals['_HIGHQMAPIREQUEST_SETDIGITALINPUTDEADTIME']._serialized_start=2917
  _globals['_HIGHQMAPIREQUEST_SETDIGITALINPUTDEADTIME']._serialized_end=3015
  _globals['_DIGITALINPUTPORT']._serialized_start=3036
  _globals['_DIGITALINPUTPORT']._serialized_end=3118
  _globals['_HIGHQMAPIRESPONSE']._serialized_start=3120
  _globals['_HIGHQMAPIRESPONSE']._serialized_end=3207
  _globals['_QMCONFIG']._serialized_start=3209
  _globals['_QMCONFIG']._serialized_end=3275
  _globals['_MATRIX']._serialized_start=3277
  _globals['_MATRIX']._serialized_end=3337
  _globals['_PORTREFERENCE']._serialized_start=3339
  _globals['_PORTREFERENCE']._serialized_end=3390
# @@protoc_insertion_point(module_scope)
