# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/inc_qua.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/inc_qua.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from qm.grpc.qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13qm/pb/inc_qua.proto\x12\x0bqm.grpc.qua\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x19google/protobuf/any.proto\"\xb4\x94\x01\n\nQuaProgram\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x38\n\tdynConfig\x18\x02 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.DynamicConfig\x12.\n\x06script\x18\x05 \x01(\x0b\x32\x1e.qm.grpc.qua.QuaProgram.Script\x12@\n\x0f\x63ompilerOptions\x18\x06 \x01(\x0b\x32\'.qm.grpc.qua.QuaProgram.CompilerOptions\x12\x36\n\x0eresultAnalysis\x18\x07 \x01(\x0b\x32\x1e.qm.grpc.qua.QuaResultAnalysis\x12\x34\n\rconfig_update\x18\x08 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x1a\xd2\x01\n\x0f\x43ompilerOptions\x12.\n\"useExperimentalCalculationCompiler\x18\x01 \x01(\x08\x42\x02\x18\x01\x12&\n\x1aoptimizeMergeCodeExecution\x18\x02 \x01(\x08\x42\x02\x18\x01\x12%\n\x19optimizeWriteReadCommands\x18\x03 \x01(\x08\x42\x02\x18\x01\x12\x1d\n\x11skipOptimizations\x18\x04 \x03(\tB\x02\x18\x01\x12\x12\n\x06strict\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\r\n\x05\x66lags\x18\x06 \x03(\t\x1a\xcb\x01\n\x06Script\x12\x39\n\tvariables\x18\x01 \x03(\x0b\x32&.qm.grpc.qua.QuaProgram.VarDeclaration\x12J\n\x0f\x65xternalStreams\x18\x02 \x03(\x0b\x32\x31.qm.grpc.qua.QuaProgram.ExternalStreamDeclaration\x12:\n\x04\x62ody\x18\n \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x1a\xb1\x02\n\x0eVarDeclaration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.qm.grpc.qua.QuaProgram.Type\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x38\n\x05value\x18\x04 \x03(\x0b\x32).qm.grpc.qua.QuaProgram.LiteralExpression\x12\x0b\n\x03\x64im\x18\x05 \x01(\x05\x12\x15\n\risInputStream\x18\x06 \x01(\x08\x12I\n\x0cstructMember\x18\x07 \x01(\x0b\x32\x33.qm.grpc.qua.QuaProgram.VarDeclaration.StructMember\x1a.\n\x0cStructMember\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\x05\x1a\xa3\x01\n\x19\x45xternalStreamDeclaration\x12\x11\n\tstream_id\x18\x01 \x01(\r\x12=\n\rexpectedTypes\x18\x02 \x03(\x0b\x32&.qm.grpc.qua.QuaProgram.VarDeclaration\x12\x34\n\tdirection\x18\x03 \x01(\x0e\x32!.qm.grpc.qua.QuaProgram.Direction\x1a\x34\n\x17QuantumElementReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a+\n\x0ePulseReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x37\n\x1aIntegrationWeightReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\xbf\x11\n\x0c\x41nyStatement\x12\x35\n\x04play\x18\x01 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.PlayStatementH\x00\x12;\n\x07measure\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.MeasureStatementH\x00\x12\x35\n\x04wait\x18\x03 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.WaitStatementH\x00\x12\x35\n\x04sync\x18\x04 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.SyncStatementH\x00\x12\x31\n\x02if\x18\x05 \x01(\x0b\x32#.qm.grpc.qua.QuaProgram.IfStatementH\x00\x12=\n\x06\x61ssign\x18\x06 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AssignmentStatementH\x00\x12\x33\n\x03\x66or\x18\x07 \x01(\x0b\x32$.qm.grpc.qua.QuaProgram.ForStatementH\x00\x12\x33\n\x03rus\x18\x08 \x01(\x0b\x32$.qm.grpc.qua.QuaProgram.RusStatementH\x00\x12\x37\n\x05\x61lign\x18\t \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.AlignStatementH\x00\x12K\n\x0fupdateFrequency\x18\n \x01(\x0b\x32\x30.qm.grpc.qua.QuaProgram.UpdateFrequencyStatementH\x00\x12?\n\tzRotation\x18\x0b \x01(\x0b\x32*.qm.grpc.qua.QuaProgram.ZRotationStatementH\x00\x12\x37\n\x05pause\x18\x0c \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PauseStatementH\x00\x12\x35\n\x04save\x18\r \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.SaveStatementH\x00\x12;\n\x07\x66orEach\x18\x0e \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.ForEachStatementH\x00\x12I\n\x0ewaitForTrigger\x18\x0f \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.WaitForTriggerStatementH\x00\x12\x39\n\x04qrun\x18\x10 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.QRunStatementB\x02\x18\x01H\x00\x12M\n\x10updateCorrection\x18\x11 \x01(\x0b\x32\x31.qm.grpc.qua.QuaProgram.UpdateCorrectionStatementH\x00\x12\x41\n\nresetPhase\x18\x12 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.ResetPhaseStatementH\x00\x12\x41\n\nrampToZero\x18\x13 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.RampToZeroStatementH\x00\x12\x41\n\nresetFrame\x18\x14 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.ResetFrameStatementH\x00\x12\x43\n\x0bsetDcOffset\x18\x15 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.SetDcOffsetStatementH\x00\x12Q\n\x12\x61\x64vanceInputStream\x18\x16 \x01(\x0b\x32\x33.qm.grpc.qua.QuaProgram.AdvanceInputStreamStatementH\x00\x12\x45\n\x0cstrictTiming\x18\x17 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.StrictTimingStatementH\x00\x12O\n\x11\x66\x61stFrameRotation\x18\x18 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.FastFrameRotationStatementH\x00\x12_\n\x19updateOscillatorFrequency\x18\x19 \x01(\x0b\x32:.qm.grpc.qua.QuaProgram.UpdateOscillatorFrequencyStatementH\x00\x12M\n\x10resetGlobalPhase\x18\x1b \x01(\x0b\x32\x31.qm.grpc.qua.QuaProgram.ResetGlobalPhaseStatementH\x00\x12\x45\n\x0cloadWaveform\x18\x1c \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.LoadWaveformStatementH\x00\x12U\n\x14sendToExternalStream\x18\x1d \x01(\x0b\x32\x35.qm.grpc.qua.QuaProgram.SendToExternalStreamStatementH\x00\x12_\n\x19receiveFromExternalStream\x18\x1e \x01(\x0b\x32:.qm.grpc.qua.QuaProgram.ReceiveFromExternalStreamStatementH\x00\x12]\n\x18globalVariableAssignment\x18\x1f \x01(\x0b\x32\x39.qm.grpc.qua.QuaProgram.GlobalVariableAssignmentStatementH\x00\x12?\n\tarbitrary\x18\x64 \x01(\x0b\x32*.qm.grpc.qua.QuaProgram.ArbitraryStatementH\x00\x12M\n\x10\x61rbitraryContext\x18\x65 \x01(\x0b\x32\x31.qm.grpc.qua.QuaProgram.ArbitraryContextStatementH\x00\x42\x11\n\x0fstatement_oneof\x1a\x80\x02\n\rAmpMultiplier\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x37\n\x02v0\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02v1\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02v2\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02v3\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\x8f\x01\n\x13RampToZeroStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12.\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aT\n\tRampPulse\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\xe4\x02\n\x05\x43hirp\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x41\n\nscalarRate\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpressionH\x00\x12\x42\n\tarrayRate\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x12\x32\n\x05units\x18\x03 \x01(\x0e\x32#.qm.grpc.qua.QuaProgram.Chirp.Units\x12\r\n\x05times\x18\x04 \x03(\r\x12\x15\n\rcontinueChirp\x18\x05 \x01(\x08\"e\n\x05Units\x12\x10\n\x0cHzPerNanoSec\x10\x00\x12\x11\n\rmHzPerNanoSec\x10\x01\x12\x11\n\ruHzPerNanoSec\x10\x02\x12\x11\n\rnHzPerNanoSec\x10\x03\x12\x11\n\rpHzPerNanoSec\x10\x04\x42\x06\n\x04rate\x1a\xa9\x05\n\rPlayStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x39\n\x05pulse\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReferenceB\x02\x18\x01\x12<\n\nnamedPulse\x18\x07 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReferenceH\x00\x12\x36\n\trampPulse\x18\x08 \x01(\x0b\x32!.qm.grpc.qua.QuaProgram.RampPulseH\x00\x12\x32\n\x03\x61mp\x18\x03 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.AmpMultiplier\x12=\n\x08\x64uration\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12>\n\tcondition\x18\x05 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x43\n\x0eport_condition\x18\x0c \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x13\n\x0btargetInput\x18\x06 \x01(\t\x12,\n\x05\x63hirp\x18\t \x01(\x0b\x32\x1d.qm.grpc.qua.QuaProgram.Chirp\x12=\n\x08truncate\x18\n \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x16\n\x0etimestampLabel\x18\x0b \x01(\tB\x0b\n\tpulseType\x1a\xaf\x02\n\x18UpdateFrequencyStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x45\n\x05units\x18\x03 \x01(\x0e\x32\x36.qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.Units\x12\x11\n\tkeepPhase\x18\x04 \x01(\x08\"3\n\x05Units\x12\x06\n\x02Hz\x10\x00\x12\x07\n\x03mHz\x10\x01\x12\x07\n\x03uHz\x10\x02\x12\x07\n\x03nHz\x10\x03\x12\x07\n\x03pHz\x10\x04\x1a\xf2\x03\n\"UpdateOscillatorFrequencyStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12O\n\x05units\x18\x03 \x01(\x0e\x32@.qm.grpc.qua.QuaProgram.UpdateOscillatorFrequencyStatement.Units\x12\x11\n\tkeepPhase\x18\x04 \x01(\x08\x12l\n\x0fupdateComponent\x18\x05 \x01(\x0e\x32S.qm.grpc.qua.QuaProgram.UpdateOscillatorFrequencyStatement.UpdateComponentSelection\"*\n\x05Units\x12\x07\n\x03GHz\x10\x00\x12\x07\n\x03MHz\x10\x01\x12\x07\n\x03KHz\x10\x02\x12\x06\n\x02Hz\x10\x03\"H\n\x18UpdateComponentSelection\x12\x08\n\x04\x62oth\x10\x00\x12\x0f\n\x0bupconverter\x10\x01\x12\x11\n\rdownconverter\x10\x02\x1a\xb7\x01\n\x14SetDcOffsetStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x18\n\x10qeInputReference\x18\x02 \x01(\t\x12;\n\x06offset\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\x9a\x01\n\x12ZRotationStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x03 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a_\n\x13ResetFrameStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x02 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x1a\xde\x01\n\x1a\x46\x61stFrameRotationStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12;\n\x06\x63osine\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x39\n\x04sine\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1aZ\n\x0e\x41lignStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x1a\x9d\x01\n\x0eMeasureProcess\x12>\n\x06\x61nalog\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.AnalogMeasureProcessH\x00\x12@\n\x07\x64igital\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.DigitalMeasureProcessH\x00\x42\t\n\x07process\x1a\xe4\x0e\n\x14\x41nalogMeasureProcess\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12W\n\x0f\x62\x61reIntegration\x18\x01 \x01(\x0b\x32<.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegrationH\x00\x12Y\n\x10\x64\x65modIntegration\x18\x02 \x01(\x0b\x32=.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegrationH\x00\x12U\n\x0erawTimeTagging\x18\x03 \x01(\x0b\x32;.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTaggingH\x00\x12_\n\x13\x64ualBareIntegration\x18\x04 \x01(\x0b\x32@.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegrationH\x00\x12\x61\n\x14\x64ualDemodIntegration\x18\x05 \x01(\x0b\x32\x41.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegrationH\x00\x12]\n\x12highResTimeTagging\x18\x06 \x01(\x0b\x32?.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTaggingH\x00\x1a\xae\x01\n\x0f\x42\x61reIntegration\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x15\n\relementOutput\x18\t \x01(\t\x1a\x96\x02\n\x13\x44ualBareIntegration\x12H\n\x0cintegration1\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12H\n\x0cintegration2\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x16\n\x0e\x65lementOutput1\x18\t \x01(\t\x12\x16\n\x0e\x65lementOutput2\x18\n \x01(\t\x1a\xaf\x01\n\x10\x44\x65modIntegration\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x15\n\relementOutput\x18\t \x01(\t\x1a\x97\x02\n\x14\x44ualDemodIntegration\x12H\n\x0cintegration1\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12H\n\x0cintegration2\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x16\n\x0e\x65lementOutput1\x18\t \x01(\t\x12\x16\n\x0e\x65lementOutput2\x18\n \x01(\t\x1a\xb4\x01\n\x0eRawTimeTagging\x12=\n\x06target\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12;\n\ttargetLen\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x03 \x01(\x05\x12\x15\n\relementOutput\x18\t \x01(\t\x1a\xb8\x01\n\x12HighResTimeTagging\x12=\n\x06target\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12;\n\ttargetLen\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x03 \x01(\x05\x12\x15\n\relementOutput\x18\t \x01(\tB\t\n\x07process\x1a\xf9\x03\n\x15\x44igitalMeasureProcess\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12V\n\x0erawTimeTagging\x18\x01 \x01(\x0b\x32<.qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTaggingH\x00\x12J\n\x08\x63ounting\x18\x02 \x01(\x0b\x32\x36.qm.grpc.qua.QuaProgram.DigitalMeasureProcess.CountingH\x00\x1a\xb4\x01\n\x0eRawTimeTagging\x12\x15\n\relementOutput\x18\x01 \x01(\t\x12=\n\x06target\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12;\n\ttargetLen\x18\x03 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x04 \x01(\x05\x1am\n\x08\x43ounting\x12\x16\n\x0e\x65lementOutputs\x18\x01 \x03(\t\x12\x38\n\x06target\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x03 \x01(\x05\x42\t\n\x07process\x1a\xb8\x06\n\x13\x41nalogProcessTarget\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12X\n\rscalarProcess\x18\x01 \x01(\x0b\x32?.qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTargetH\x00\x12X\n\rvectorProcess\x18\x02 \x01(\x0b\x32?.qm.grpc.qua.QuaProgram.AnalogProcessTarget.VectorProcessTargetH\x00\x1a\xa2\x01\n\x13ScalarProcessTarget\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x42\x08\n\x06target\x1a\xa3\x01\n\x13VectorProcessTarget\x12<\n\x05\x61rray\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12N\n\x0ctimeDivision\x18\x02 \x01(\x0b\x32\x38.qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision\x1a\x83\x02\n\x0cTimeDivision\x12\x43\n\x06sliced\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua.QuaProgram.AnalogTimeDivision.SlicedH\x00\x12M\n\x0b\x61\x63\x63umulated\x18\x03 \x01(\x0b\x32\x36.qm.grpc.qua.QuaProgram.AnalogTimeDivision.AccumulatedH\x00\x12O\n\x0cmovingWindow\x18\x04 \x01(\x0b\x32\x37.qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindowH\x00\x42\x0e\n\x0ctimeDivisionB\x0f\n\rprocessTarget\x1a\xc8\x01\n\x12\x41nalogTimeDivision\x1a.\n\x06Sliced\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x17\n\x0fsamplesPerChunk\x18\x01 \x01(\x05\x1a\x33\n\x0b\x41\x63\x63umulated\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x17\n\x0fsamplesPerChunk\x18\x01 \x01(\x05\x1aM\n\x0cMovingWindow\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x17\n\x0fsamplesPerChunk\x18\x01 \x01(\x05\x12\x17\n\x0f\x63hunksPerWindow\x18\x02 \x01(\x05\x1a\x8b\x03\n\rMeasureOutput\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12>\n\x08variable\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionB\x02\x18\x01\x12\x0e\n\x06output\x18\x03 \x01(\t\x12<\n\x06target\x18\x04 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.MeasureOutput.Target\x1a\x95\x01\n\x06Target\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x42\x08\n\x06target\x1a\xef\x02\n\x10MeasureStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x35\n\x05pulse\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReference\x12\x32\n\x03\x61mp\x18\x03 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.AmpMultiplier\x12:\n\x07outputs\x18\x04 \x03(\x0b\x32%.qm.grpc.qua.QuaProgram.MeasureOutputB\x02\x18\x01\x12\x10\n\x08streamAs\x18\x05 \x01(\t\x12@\n\x10measureProcesses\x18\x07 \x03(\x0b\x32&.qm.grpc.qua.QuaProgram.MeasureProcess\x12\x16\n\x0etimestampLabel\x18\x08 \x01(\t\x1a\x94\x01\n\rWaitStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x39\n\x04time\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1aS\n\x12\x41rbitraryStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x1a\xa4\x01\n\x19\x41rbitraryContextStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x88\x01\x01\x12:\n\x04\x62ody\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollectionB\x07\n\x05_data\x1a\xa6\x03\n\x17WaitForTriggerStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12;\n\x0bpulseToPlay\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReference\x12/\n\rglobalTrigger\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12V\n\relementOutput\x18\x04 \x01(\x0b\x32=.qm.grpc.qua.QuaProgram.WaitForTriggerStatement.ElementOutputH\x00\x12?\n\rtimeTagTarget\x18\x05 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x1a\x30\n\rElementOutput\x12\x0f\n\x07\x65lement\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\tB\x08\n\x06source\x1a\x9d\x01\n\x19UpdateCorrectionStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x36\n\ncorrection\x18\x02 \x01(\x0b\x32\".qm.grpc.qua.QuaProgram.Correction\x1a_\n\x13ResetPhaseStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x1a(\n\x19ResetGlobalPhaseStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xb1\x01\n\x1dSendToExternalStreamStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x43\n\x06stream\x18\x01 \x01(\x0b\x32\x33.qm.grpc.qua.QuaProgram.ExternalStreamRefExpression\x12>\n\x06struct\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.StructVarRefExpression\x1a\xb6\x01\n\"ReceiveFromExternalStreamStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x43\n\x06stream\x18\x01 \x01(\x0b\x32\x33.qm.grpc.qua.QuaProgram.ExternalStreamRefExpression\x12>\n\x06struct\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.StructVarRefExpression\x1am\n!GlobalVariableAssignmentStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\tvariables\x18\x01 \x03(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x1a\xfd\x01\n\nCorrection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x37\n\x02\x63\x30\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02\x63\x31\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02\x63\x32\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02\x63\x33\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\x1c\n\rSyncStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x91\x01\n\x06\x45lseIf\x12>\n\tcondition\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x93\x02\n\x0bIfStatement\x12>\n\tcondition\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12:\n\x04\x65lse\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12/\n\x07\x65lseifs\x18\x04 \x03(\x0b\x32\x1e.qm.grpc.qua.QuaProgram.ElseIf\x12\x0e\n\x06unsafe\x18\x05 \x01(\x08\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x91\x02\n\x0c\x46orStatement\x12:\n\x04init\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12<\n\x06update\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12:\n\x04\x62ody\x18\x04 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1aX\n\rQRunStatement\x12:\n\x04\x62ody\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a`\n\x15StrictTimingStatement\x12:\n\x04\x62ody\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xbb\x02\n\x10\x46orEachStatement\x12M\n\x08iterator\x18\x01 \x03(\x0b\x32;.qm.grpc.qua.QuaProgram.ForEachStatement.VariableWithValues\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x8e\x01\n\x12VariableWithValues\x12:\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12<\n\x05\x61rray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x1a\xd7\x01\n\x0cRusStatement\x12=\n\x07\x64oBlock\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12?\n\tfailBlock\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12:\n\x05until\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x91\x03\n\x13\x41ssignmentStatement\x12>\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionB\x02\x18\x01\x12?\n\nexpression\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x10\n\x04save\x18\x03 \x01(\x08\x42\x02\x18\x01\x12\x42\n\x06target\x18\x04 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.AssignmentStatement.Target\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x95\x01\n\x06Target\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x42\x08\n\x06target\x1a[\n\x0ePauseStatement\x12<\n\x03qes\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xfd\x02\n\rSaveStatement\x12>\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionB\x02\x18\x01\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12<\n\x06source\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.SaveStatement.Source\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xd3\x01\n\x06Source\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x12<\n\x07literal\x18\x03 \x01(\x0b\x32).qm.grpc.qua.QuaProgram.LiteralExpressionH\x00\x42\x08\n\x06source\x1a\xdd\x01\n\x15LoadWaveformStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x35\n\x05pulse\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReference\x12\x43\n\x0ewaveform_index\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1aP\n\x14StatementsCollection\x12\x38\n\nstatements\x18\x01 \x03(\x0b\x32$.qm.grpc.qua.QuaProgram.AnyStatement\x1a\x87\x05\n\x13\x41nyScalarExpression\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12<\n\x07literal\x18\x02 \x01(\x0b\x32).qm.grpc.qua.QuaProgram.LiteralExpressionH\x00\x12\x43\n\x0f\x62inaryOperation\x18\x03 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.BinaryExpressionH\x00\x12\x43\n\tarrayCell\x18\x04 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x12\x44\n\x0b\x61rrayLength\x18\x05 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayLengthExpressionH\x00\x12\x44\n\x0blibFunction\x18\x06 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.LibFunctionExpressionH\x00\x12>\n\x08\x66unction\x18\x07 \x01(\x0b\x32*.qm.grpc.qua.QuaProgram.FunctionExpressionH\x00\x12@\n\tbroadcast\x18\x08 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.BroadcastExpressionH\x00\x12H\n\x0eglobalVariable\x18\t \x01(\x0b\x32..qm.grpc.qua.QuaProgram.GlobalVarRefExpressionH\x00\x42\x12\n\x10\x65xpression_oneof\x1a\xc4\x01\n\x1b\x41\x64vanceInputStreamStatement\x12\x42\n\x0estreamVariable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x44\n\x0bstreamArray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x12\x0b\n\x03loc\x18\x64 \x01(\tB\x0e\n\x0cstream_oneof\x1a\x62\n\x15\x41rrayLengthExpression\x12<\n\x05\x61rray\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1aV\n\x10VarRefExpression\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x12\n\x08ioNumber\x18\x03 \x01(\x05H\x00\x12\x0b\n\x03loc\x18\x64 \x01(\tB\x0b\n\tvar_oneofJ\x04\x08\x01\x10\x02\x1a\x39\n\x16StructVarRefExpression\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03loc\x18\x64 \x01(\tJ\x04\x08\x01\x10\x02\x1a\x43\n\x1b\x45xternalStreamRefExpression\x12\x11\n\tstream_id\x18\x02 \x01(\r\x12\x0b\n\x03loc\x18\x64 \x01(\tJ\x04\x08\x01\x10\x02\x1a\x8e\x01\n\x15\x41rrayVarRefExpression\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x46\n\tstructVar\x18\x03 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.StructVarRefExpressionH\x00\x88\x01\x01\x12\x0b\n\x03loc\x18\x64 \x01(\tB\x0c\n\n_structVarJ\x04\x08\x01\x10\x02\x1a\xa8\x01\n\x16\x41rrayCellRefExpression\x12?\n\x08\x61rrayVar\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12:\n\x05index\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\tJ\x04\x08\x01\x10\x02\x1a[\n\x11LiteralExpression\x12\r\n\x05value\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.qm.grpc.qua.QuaProgram.Type\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xe9\x02\n\x10\x42inaryExpression\x12\x43\n\x02op\x18\x01 \x01(\x0e\x32\x37.qm.grpc.qua.QuaProgram.BinaryExpression.BinaryOperator\x12\x39\n\x04left\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12:\n\x05right\x18\x05 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\"\x8b\x01\n\x0e\x42inaryOperator\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\x07\n\x03SUB\x10\x01\x12\x08\n\x04MULT\x10\x02\x12\x07\n\x03\x44IV\x10\x03\x12\x07\n\x03\x41ND\x10\x04\x12\x06\n\x02OR\x10\x05\x12\x07\n\x03XOR\x10\x06\x12\x06\n\x02LT\x10\x07\x12\x07\n\x03LET\x10\x08\x12\x06\n\x02GT\x10\t\x12\x07\n\x03GET\x10\n\x12\x06\n\x02\x45Q\x10\x0b\x12\x07\n\x03SHL\x10\x0c\x12\x07\n\x03SHR\x10\r\x1a\xb8\x02\n\x15LibFunctionExpression\x12\x14\n\x0c\x66unctionName\x18\x01 \x01(\t\x12I\n\targuments\x18\x02 \x03(\x0b\x32\x36.qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument\x12\x13\n\x0blibraryName\x18\x03 \x01(\t\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x9b\x01\n\x08\x41rgument\x12=\n\x06scalar\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpressionH\x00\x12>\n\x05\x61rray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x42\x10\n\x0e\x61rgument_oneof\x1a\xd7\x05\n\x12\x46unctionExpression\x12\x45\n\x03\x61nd\x18\x01 \x01(\x0b\x32\x36.qm.grpc.qua.QuaProgram.FunctionExpression.AndFunctionH\x00\x12\x43\n\x02or\x18\x02 \x01(\x0b\x32\x35.qm.grpc.qua.QuaProgram.FunctionExpression.OrFunctionH\x00\x12\x45\n\x03xor\x18\x03 \x01(\x0b\x32\x36.qm.grpc.qua.QuaProgram.FunctionExpression.XorFunctionH\x00\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xa9\x01\n\x16ScalarOrVectorArgument\x12=\n\x06scalar\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpressionH\x00\x12>\n\x05\x61rray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x42\x10\n\x0e\x61rgument_oneof\x1a`\n\x0b\x41ndFunction\x12Q\n\x06values\x18\x01 \x03(\x0b\x32\x41.qm.grpc.qua.QuaProgram.FunctionExpression.ScalarOrVectorArgument\x1a_\n\nOrFunction\x12Q\n\x06values\x18\x01 \x03(\x0b\x32\x41.qm.grpc.qua.QuaProgram.FunctionExpression.ScalarOrVectorArgument\x1a`\n\x0bXorFunction\x12Q\n\x06values\x18\x01 \x03(\x0b\x32\x41.qm.grpc.qua.QuaProgram.FunctionExpression.ScalarOrVectorArgumentB\x10\n\x0e\x66unction_oneof\x1a^\n\x13\x42roadcastExpression\x12:\n\x05value\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1ar\n\x16GlobalVarRefExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04\x62its\x18\x01 \x03(\x05\x12=\n\toperation\x18\x02 \x01(\x0e\x32*.qm.grpc.qua.QuaProgram.GlobalVarOperation\x1aG\n\rDynamicConfig\x12\x0f\n\x07version\x18\x01 \x01(\r\x12%\n\x04root\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"#\n\x04Type\x12\x07\n\x03INT\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04REAL\x10\x02\"\'\n\tDirection\x12\x0c\n\x08INCOMING\x10\x00\x12\x0c\n\x08OUTGOING\x10\x01\"7\n\x12GlobalVarOperation\x12\x08\n\x04read\x10\x00\x12\x0e\n\nread_shift\x10\x01\x12\x07\n\x03xor\x10\x02\"O\n\x11QuaResultAnalysis\x12\x0f\n\x07version\x18\x01 \x01(\r\x12)\n\x05model\x18\x03 \x03(\x0b\x32\x1a.google.protobuf.ListValueB\x02P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.inc_qua_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['useExperimentalCalculationCompiler']._loaded_options = None
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['useExperimentalCalculationCompiler']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['optimizeMergeCodeExecution']._loaded_options = None
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['optimizeMergeCodeExecution']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['optimizeWriteReadCommands']._loaded_options = None
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['optimizeWriteReadCommands']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['skipOptimizations']._loaded_options = None
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['skipOptimizations']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['strict']._loaded_options = None
  _globals['_QUAPROGRAM_COMPILEROPTIONS'].fields_by_name['strict']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_ANYSTATEMENT'].fields_by_name['qrun']._loaded_options = None
  _globals['_QUAPROGRAM_ANYSTATEMENT'].fields_by_name['qrun']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_PLAYSTATEMENT'].fields_by_name['pulse']._loaded_options = None
  _globals['_QUAPROGRAM_PLAYSTATEMENT'].fields_by_name['pulse']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_MEASUREOUTPUT'].fields_by_name['variable']._loaded_options = None
  _globals['_QUAPROGRAM_MEASUREOUTPUT'].fields_by_name['variable']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_MEASURESTATEMENT'].fields_by_name['outputs']._loaded_options = None
  _globals['_QUAPROGRAM_MEASURESTATEMENT'].fields_by_name['outputs']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT'].fields_by_name['variable']._loaded_options = None
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT'].fields_by_name['variable']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT'].fields_by_name['save']._loaded_options = None
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT'].fields_by_name['save']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM_SAVESTATEMENT'].fields_by_name['variable']._loaded_options = None
  _globals['_QUAPROGRAM_SAVESTATEMENT'].fields_by_name['variable']._serialized_options = b'\030\001'
  _globals['_QUAPROGRAM']._serialized_start=184
  _globals['_QUAPROGRAM']._serialized_end=19180
  _globals['_QUAPROGRAM_COMPILEROPTIONS']._serialized_start=528
  _globals['_QUAPROGRAM_COMPILEROPTIONS']._serialized_end=738
  _globals['_QUAPROGRAM_SCRIPT']._serialized_start=741
  _globals['_QUAPROGRAM_SCRIPT']._serialized_end=944
  _globals['_QUAPROGRAM_VARDECLARATION']._serialized_start=947
  _globals['_QUAPROGRAM_VARDECLARATION']._serialized_end=1252
  _globals['_QUAPROGRAM_VARDECLARATION_STRUCTMEMBER']._serialized_start=1206
  _globals['_QUAPROGRAM_VARDECLARATION_STRUCTMEMBER']._serialized_end=1252
  _globals['_QUAPROGRAM_EXTERNALSTREAMDECLARATION']._serialized_start=1255
  _globals['_QUAPROGRAM_EXTERNALSTREAMDECLARATION']._serialized_end=1418
  _globals['_QUAPROGRAM_QUANTUMELEMENTREFERENCE']._serialized_start=1420
  _globals['_QUAPROGRAM_QUANTUMELEMENTREFERENCE']._serialized_end=1472
  _globals['_QUAPROGRAM_PULSEREFERENCE']._serialized_start=1474
  _globals['_QUAPROGRAM_PULSEREFERENCE']._serialized_end=1517
  _globals['_QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE']._serialized_start=1519
  _globals['_QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE']._serialized_end=1574
  _globals['_QUAPROGRAM_ANYSTATEMENT']._serialized_start=1577
  _globals['_QUAPROGRAM_ANYSTATEMENT']._serialized_end=3816
  _globals['_QUAPROGRAM_AMPMULTIPLIER']._serialized_start=3819
  _globals['_QUAPROGRAM_AMPMULTIPLIER']._serialized_end=4075
  _globals['_QUAPROGRAM_RAMPTOZEROSTATEMENT']._serialized_start=4078
  _globals['_QUAPROGRAM_RAMPTOZEROSTATEMENT']._serialized_end=4221
  _globals['_QUAPROGRAM_RAMPPULSE']._serialized_start=4223
  _globals['_QUAPROGRAM_RAMPPULSE']._serialized_end=4307
  _globals['_QUAPROGRAM_CHIRP']._serialized_start=4310
  _globals['_QUAPROGRAM_CHIRP']._serialized_end=4666
  _globals['_QUAPROGRAM_CHIRP_UNITS']._serialized_start=4557
  _globals['_QUAPROGRAM_CHIRP_UNITS']._serialized_end=4658
  _globals['_QUAPROGRAM_PLAYSTATEMENT']._serialized_start=4669
  _globals['_QUAPROGRAM_PLAYSTATEMENT']._serialized_end=5350
  _globals['_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT']._serialized_start=5353
  _globals['_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT']._serialized_end=5656
  _globals['_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS']._serialized_start=5605
  _globals['_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS']._serialized_end=5656
  _globals['_QUAPROGRAM_UPDATEOSCILLATORFREQUENCYSTATEMENT']._serialized_start=5659
  _globals['_QUAPROGRAM_UPDATEOSCILLATORFREQUENCYSTATEMENT']._serialized_end=6157
  _globals['_QUAPROGRAM_UPDATEOSCILLATORFREQUENCYSTATEMENT_UNITS']._serialized_start=6041
  _globals['_QUAPROGRAM_UPDATEOSCILLATORFREQUENCYSTATEMENT_UNITS']._serialized_end=6083
  _globals['_QUAPROGRAM_UPDATEOSCILLATORFREQUENCYSTATEMENT_UPDATECOMPONENTSELECTION']._serialized_start=6085
  _globals['_QUAPROGRAM_UPDATEOSCILLATORFREQUENCYSTATEMENT_UPDATECOMPONENTSELECTION']._serialized_end=6157
  _globals['_QUAPROGRAM_SETDCOFFSETSTATEMENT']._serialized_start=6160
  _globals['_QUAPROGRAM_SETDCOFFSETSTATEMENT']._serialized_end=6343
  _globals['_QUAPROGRAM_ZROTATIONSTATEMENT']._serialized_start=6346
  _globals['_QUAPROGRAM_ZROTATIONSTATEMENT']._serialized_end=6500
  _globals['_QUAPROGRAM_RESETFRAMESTATEMENT']._serialized_start=6502
  _globals['_QUAPROGRAM_RESETFRAMESTATEMENT']._serialized_end=6597
  _globals['_QUAPROGRAM_FASTFRAMEROTATIONSTATEMENT']._serialized_start=6600
  _globals['_QUAPROGRAM_FASTFRAMEROTATIONSTATEMENT']._serialized_end=6822
  _globals['_QUAPROGRAM_ALIGNSTATEMENT']._serialized_start=6824
  _globals['_QUAPROGRAM_ALIGNSTATEMENT']._serialized_end=6914
  _globals['_QUAPROGRAM_MEASUREPROCESS']._serialized_start=6917
  _globals['_QUAPROGRAM_MEASUREPROCESS']._serialized_end=7074
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS']._serialized_start=7077
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS']._serialized_end=8969
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION']._serialized_start=7673
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION']._serialized_end=7847
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION']._serialized_start=7850
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION']._serialized_end=8128
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION']._serialized_start=8131
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION']._serialized_end=8306
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION']._serialized_start=8309
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION']._serialized_end=8588
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING']._serialized_start=8591
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING']._serialized_end=8771
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING']._serialized_start=8774
  _globals['_QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING']._serialized_end=8958
  _globals['_QUAPROGRAM_DIGITALMEASUREPROCESS']._serialized_start=8972
  _globals['_QUAPROGRAM_DIGITALMEASUREPROCESS']._serialized_end=9477
  _globals['_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING']._serialized_start=9175
  _globals['_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING']._serialized_end=9355
  _globals['_QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING']._serialized_start=9357
  _globals['_QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING']._serialized_end=9466
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET']._serialized_start=9480
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET']._serialized_end=10304
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET']._serialized_start=9697
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET']._serialized_end=9859
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET']._serialized_start=9862
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET']._serialized_end=10025
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION']._serialized_start=10028
  _globals['_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION']._serialized_end=10287
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION']._serialized_start=10307
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION']._serialized_end=10507
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION_SLICED']._serialized_start=10329
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION_SLICED']._serialized_end=10375
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED']._serialized_start=10377
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED']._serialized_end=10428
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW']._serialized_start=10430
  _globals['_QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW']._serialized_end=10507
  _globals['_QUAPROGRAM_MEASUREOUTPUT']._serialized_start=10510
  _globals['_QUAPROGRAM_MEASUREOUTPUT']._serialized_end=10905
  _globals['_QUAPROGRAM_MEASUREOUTPUT_TARGET']._serialized_start=10756
  _globals['_QUAPROGRAM_MEASUREOUTPUT_TARGET']._serialized_end=10905
  _globals['_QUAPROGRAM_MEASURESTATEMENT']._serialized_start=10908
  _globals['_QUAPROGRAM_MEASURESTATEMENT']._serialized_end=11275
  _globals['_QUAPROGRAM_WAITSTATEMENT']._serialized_start=11278
  _globals['_QUAPROGRAM_WAITSTATEMENT']._serialized_end=11426
  _globals['_QUAPROGRAM_ARBITRARYSTATEMENT']._serialized_start=11428
  _globals['_QUAPROGRAM_ARBITRARYSTATEMENT']._serialized_end=11511
  _globals['_QUAPROGRAM_ARBITRARYCONTEXTSTATEMENT']._serialized_start=11514
  _globals['_QUAPROGRAM_ARBITRARYCONTEXTSTATEMENT']._serialized_end=11678
  _globals['_QUAPROGRAM_WAITFORTRIGGERSTATEMENT']._serialized_start=11681
  _globals['_QUAPROGRAM_WAITFORTRIGGERSTATEMENT']._serialized_end=12103
  _globals['_QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT']._serialized_start=12045
  _globals['_QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT']._serialized_end=12093
  _globals['_QUAPROGRAM_UPDATECORRECTIONSTATEMENT']._serialized_start=12106
  _globals['_QUAPROGRAM_UPDATECORRECTIONSTATEMENT']._serialized_end=12263
  _globals['_QUAPROGRAM_RESETPHASESTATEMENT']._serialized_start=12265
  _globals['_QUAPROGRAM_RESETPHASESTATEMENT']._serialized_end=12360
  _globals['_QUAPROGRAM_RESETGLOBALPHASESTATEMENT']._serialized_start=12362
  _globals['_QUAPROGRAM_RESETGLOBALPHASESTATEMENT']._serialized_end=12402
  _globals['_QUAPROGRAM_SENDTOEXTERNALSTREAMSTATEMENT']._serialized_start=12405
  _globals['_QUAPROGRAM_SENDTOEXTERNALSTREAMSTATEMENT']._serialized_end=12582
  _globals['_QUAPROGRAM_RECEIVEFROMEXTERNALSTREAMSTATEMENT']._serialized_start=12585
  _globals['_QUAPROGRAM_RECEIVEFROMEXTERNALSTREAMSTATEMENT']._serialized_end=12767
  _globals['_QUAPROGRAM_GLOBALVARIABLEASSIGNMENTSTATEMENT']._serialized_start=12769
  _globals['_QUAPROGRAM_GLOBALVARIABLEASSIGNMENTSTATEMENT']._serialized_end=12878
  _globals['_QUAPROGRAM_CORRECTION']._serialized_start=12881
  _globals['_QUAPROGRAM_CORRECTION']._serialized_end=13134
  _globals['_QUAPROGRAM_SYNCSTATEMENT']._serialized_start=13136
  _globals['_QUAPROGRAM_SYNCSTATEMENT']._serialized_end=13164
  _globals['_QUAPROGRAM_ELSEIF']._serialized_start=13167
  _globals['_QUAPROGRAM_ELSEIF']._serialized_end=13312
  _globals['_QUAPROGRAM_IFSTATEMENT']._serialized_start=13315
  _globals['_QUAPROGRAM_IFSTATEMENT']._serialized_end=13590
  _globals['_QUAPROGRAM_FORSTATEMENT']._serialized_start=13593
  _globals['_QUAPROGRAM_FORSTATEMENT']._serialized_end=13866
  _globals['_QUAPROGRAM_QRUNSTATEMENT']._serialized_start=13868
  _globals['_QUAPROGRAM_QRUNSTATEMENT']._serialized_end=13956
  _globals['_QUAPROGRAM_STRICTTIMINGSTATEMENT']._serialized_start=13958
  _globals['_QUAPROGRAM_STRICTTIMINGSTATEMENT']._serialized_end=14054
  _globals['_QUAPROGRAM_FOREACHSTATEMENT']._serialized_start=14057
  _globals['_QUAPROGRAM_FOREACHSTATEMENT']._serialized_end=14372
  _globals['_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES']._serialized_start=14230
  _globals['_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES']._serialized_end=14372
  _globals['_QUAPROGRAM_RUSSTATEMENT']._serialized_start=14375
  _globals['_QUAPROGRAM_RUSSTATEMENT']._serialized_end=14590
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT']._serialized_start=14593
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT']._serialized_end=14994
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET']._serialized_start=10756
  _globals['_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET']._serialized_end=10905
  _globals['_QUAPROGRAM_PAUSESTATEMENT']._serialized_start=14996
  _globals['_QUAPROGRAM_PAUSESTATEMENT']._serialized_end=15087
  _globals['_QUAPROGRAM_SAVESTATEMENT']._serialized_start=15090
  _globals['_QUAPROGRAM_SAVESTATEMENT']._serialized_end=15471
  _globals['_QUAPROGRAM_SAVESTATEMENT_SOURCE']._serialized_start=15260
  _globals['_QUAPROGRAM_SAVESTATEMENT_SOURCE']._serialized_end=15471
  _globals['_QUAPROGRAM_LOADWAVEFORMSTATEMENT']._serialized_start=15474
  _globals['_QUAPROGRAM_LOADWAVEFORMSTATEMENT']._serialized_end=15695
  _globals['_QUAPROGRAM_STATEMENTSCOLLECTION']._serialized_start=15697
  _globals['_QUAPROGRAM_STATEMENTSCOLLECTION']._serialized_end=15777
  _globals['_QUAPROGRAM_ANYSCALAREXPRESSION']._serialized_start=15780
  _globals['_QUAPROGRAM_ANYSCALAREXPRESSION']._serialized_end=16427
  _globals['_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT']._serialized_start=16430
  _globals['_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT']._serialized_end=16626
  _globals['_QUAPROGRAM_ARRAYLENGTHEXPRESSION']._serialized_start=16628
  _globals['_QUAPROGRAM_ARRAYLENGTHEXPRESSION']._serialized_end=16726
  _globals['_QUAPROGRAM_VARREFEXPRESSION']._serialized_start=16728
  _globals['_QUAPROGRAM_VARREFEXPRESSION']._serialized_end=16814
  _globals['_QUAPROGRAM_STRUCTVARREFEXPRESSION']._serialized_start=16816
  _globals['_QUAPROGRAM_STRUCTVARREFEXPRESSION']._serialized_end=16873
  _globals['_QUAPROGRAM_EXTERNALSTREAMREFEXPRESSION']._serialized_start=16875
  _globals['_QUAPROGRAM_EXTERNALSTREAMREFEXPRESSION']._serialized_end=16942
  _globals['_QUAPROGRAM_ARRAYVARREFEXPRESSION']._serialized_start=16945
  _globals['_QUAPROGRAM_ARRAYVARREFEXPRESSION']._serialized_end=17087
  _globals['_QUAPROGRAM_ARRAYCELLREFEXPRESSION']._serialized_start=17090
  _globals['_QUAPROGRAM_ARRAYCELLREFEXPRESSION']._serialized_end=17258
  _globals['_QUAPROGRAM_LITERALEXPRESSION']._serialized_start=17260
  _globals['_QUAPROGRAM_LITERALEXPRESSION']._serialized_end=17351
  _globals['_QUAPROGRAM_BINARYEXPRESSION']._serialized_start=17354
  _globals['_QUAPROGRAM_BINARYEXPRESSION']._serialized_end=17715
  _globals['_QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR']._serialized_start=17576
  _globals['_QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR']._serialized_end=17715
  _globals['_QUAPROGRAM_LIBFUNCTIONEXPRESSION']._serialized_start=17718
  _globals['_QUAPROGRAM_LIBFUNCTIONEXPRESSION']._serialized_end=18030
  _globals['_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT']._serialized_start=17875
  _globals['_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT']._serialized_end=18030
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION']._serialized_start=18033
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION']._serialized_end=18760
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_SCALARORVECTORARGUMENT']._serialized_start=18280
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_SCALARORVECTORARGUMENT']._serialized_end=18449
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_ANDFUNCTION']._serialized_start=18451
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_ANDFUNCTION']._serialized_end=18547
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_ORFUNCTION']._serialized_start=18549
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_ORFUNCTION']._serialized_end=18644
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_XORFUNCTION']._serialized_start=18646
  _globals['_QUAPROGRAM_FUNCTIONEXPRESSION_XORFUNCTION']._serialized_end=18742
  _globals['_QUAPROGRAM_BROADCASTEXPRESSION']._serialized_start=18762
  _globals['_QUAPROGRAM_BROADCASTEXPRESSION']._serialized_end=18856
  _globals['_QUAPROGRAM_GLOBALVARREFEXPRESSION']._serialized_start=18858
  _globals['_QUAPROGRAM_GLOBALVARREFEXPRESSION']._serialized_end=18972
  _globals['_QUAPROGRAM_DYNAMICCONFIG']._serialized_start=18974
  _globals['_QUAPROGRAM_DYNAMICCONFIG']._serialized_end=19045
  _globals['_QUAPROGRAM_TYPE']._serialized_start=19047
  _globals['_QUAPROGRAM_TYPE']._serialized_end=19082
  _globals['_QUAPROGRAM_DIRECTION']._serialized_start=19084
  _globals['_QUAPROGRAM_DIRECTION']._serialized_end=19123
  _globals['_QUAPROGRAM_GLOBALVAROPERATION']._serialized_start=19125
  _globals['_QUAPROGRAM_GLOBALVAROPERATION']._serialized_end=19180
  _globals['_QUARESULTANALYSIS']._serialized_start=19182
  _globals['_QUARESULTANALYSIS']._serialized_end=19261
# @@protoc_insertion_point(module_scope)
