# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/qm_manager.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/qm_manager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.grpc.qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.grpc.qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16qm/pb/qm_manager.proto\x12\x12qm.grpc.qm_manager\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x1cqm/pb/general_messages.proto\"\xc2\x01\n\x19OpenQuantumMachineRequest\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x0f\n\x05never\x18\x02 \x01(\x08H\x00\x12\x10\n\x06\x61lways\x18\x03 \x01(\x08H\x00\x12\x12\n\x08ifNeeded\x18\x04 \x01(\x08H\x00\x12$\n\x1ckeep_dc_offsets_when_closing\x18\x05 \x01(\x08\x42\x19\n\x17oneOfCloseOtherMachines\"\x99\x02\n\x1aOpenQuantumMachineResponse\x12\x11\n\tmachineID\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12K\n\x16\x63onfigValidationErrors\x18\x03 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessage\x12O\n\x18physicalValidationErrors\x18\x04 \x03(\x0b\x32-.qm.grpc.qm_manager.PhysicalValidationMessage\x12\x39\n\x0eopenQmWarnings\x18\x05 \x03(\x0b\x32!.qm.grpc.qm_manager.OpenQmWarning\"/\n\x1a\x43loseQuantumMachineRequest\x12\x11\n\tmachineID\x18\x01 \x01(\t\"f\n\x1b\x43loseQuantumMachineResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x02 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\"-\n\x18GetQuantumMachineRequest\x12\x11\n\tmachineID\x18\x01 \x01(\t\"\xa6\x01\n\x19GetQuantumMachineResponse\x12\x11\n\tmachineID\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x04 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\")\n\x14GetRunningJobRequest\x12\x11\n\tmachineID\x18\x01 \x01(\t\"9\n\x15GetRunningJobResponse\x12\x11\n\tmachineID\x18\x01 \x01(\t\x12\r\n\x05jobId\x18\x02 \x01(\t\"5\n\x1fListOpenQuantumMachinesResponse\x12\x12\n\nmachineIDs\x18\x01 \x03(\t\"j\n\x1f\x43loseAllQuantumMachinesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x02 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\"M\n\x16GetControllersResponse\x12\x33\n\x0b\x63ontrollers\x18\x01 \x03(\x0b\x32\x1e.qm.grpc.qm_manager.Controller\"D\n\nController\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0btemperature\x18\x02 \x01(\x01H\x00\x88\x01\x01\x42\x0e\n\x0c_temperature\"~\n\x17\x43onfigValidationMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x35\n\x05level\x18\x04 \x01(\x0e\x32&.qm.grpc.general_messages.MessageLevel\"\x80\x01\n\x19PhysicalValidationMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x35\n\x05level\x18\x04 \x01(\x0e\x32&.qm.grpc.general_messages.MessageLevel\".\n\rOpenQmWarning\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\tB+\n\x11qm.grpc.qmManagerB\x0eQmManagerProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.qm_manager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021qm.grpc.qmManagerB\016QmManagerProtoP\001\242\002\003HLW'
  _globals['_OPENQUANTUMMACHINEREQUEST']._serialized_start=105
  _globals['_OPENQUANTUMMACHINEREQUEST']._serialized_end=299
  _globals['_OPENQUANTUMMACHINERESPONSE']._serialized_start=302
  _globals['_OPENQUANTUMMACHINERESPONSE']._serialized_end=583
  _globals['_CLOSEQUANTUMMACHINEREQUEST']._serialized_start=585
  _globals['_CLOSEQUANTUMMACHINEREQUEST']._serialized_end=632
  _globals['_CLOSEQUANTUMMACHINERESPONSE']._serialized_start=634
  _globals['_CLOSEQUANTUMMACHINERESPONSE']._serialized_end=736
  _globals['_GETQUANTUMMACHINEREQUEST']._serialized_start=738
  _globals['_GETQUANTUMMACHINEREQUEST']._serialized_end=783
  _globals['_GETQUANTUMMACHINERESPONSE']._serialized_start=786
  _globals['_GETQUANTUMMACHINERESPONSE']._serialized_end=952
  _globals['_GETRUNNINGJOBREQUEST']._serialized_start=954
  _globals['_GETRUNNINGJOBREQUEST']._serialized_end=995
  _globals['_GETRUNNINGJOBRESPONSE']._serialized_start=997
  _globals['_GETRUNNINGJOBRESPONSE']._serialized_end=1054
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE']._serialized_start=1056
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE']._serialized_end=1109
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE']._serialized_start=1111
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE']._serialized_end=1217
  _globals['_GETCONTROLLERSRESPONSE']._serialized_start=1219
  _globals['_GETCONTROLLERSRESPONSE']._serialized_end=1296
  _globals['_CONTROLLER']._serialized_start=1298
  _globals['_CONTROLLER']._serialized_end=1366
  _globals['_CONFIGVALIDATIONMESSAGE']._serialized_start=1368
  _globals['_CONFIGVALIDATIONMESSAGE']._serialized_end=1494
  _globals['_PHYSICALVALIDATIONMESSAGE']._serialized_start=1497
  _globals['_PHYSICALVALIDATIONMESSAGE']._serialized_end=1625
  _globals['_OPENQMWARNING']._serialized_start=1627
  _globals['_OPENQMWARNING']._serialized_end=1673
# @@protoc_insertion_point(module_scope)
