# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/grpc/v2/job_api.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/grpc/v2/job_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from qm.grpc.qm.grpc.v2 import qm_api_pb2 as qm_dot_grpc_dot_v2_dot_qm__api__pb2
from qm.grpc.qm.grpc.v2 import common_types_pb2 as qm_dot_grpc_dot_v2_dot_common__types__pb2
from qm.grpc.qm.pb import inc_qm_api_pb2 as qm_dot_pb_dot_inc__qm__api__pb2
from qm.grpc.qm.pb import job_manager_pb2 as qm_dot_pb_dot_job__manager__pb2
from qm.grpc.qm.pb import job_results_pb2 as qm_dot_pb_dot_job__results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qm/grpc/v2/job_api.proto\x12\nqm.grpc.v2\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17qm/grpc/v2/qm_api.proto\x1a\x1dqm/grpc/v2/common_types.proto\x1a\x16qm/pb/inc_qm_api.proto\x1a\x17qm/pb/job_manager.proto\x1a\x17qm/pb/job_results.proto\"\xc4\x02\n\x1bSetMatrixCorrectionResponse\x12]\n\x07success\x18\x01 \x01(\x0b\x32J.qm.grpc.v2.SetMatrixCorrectionResponse.SetMatrixCorrectionResponseSuccessH\x00\x12Y\n\x05\x65rror\x18\x02 \x01(\x0b\x32H.qm.grpc.v2.SetMatrixCorrectionResponse.SetMatrixCorrectionResponseErrorH\x00\x1a\x33\n SetMatrixCorrectionResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a$\n\"SetMatrixCorrectionResponseSuccessB\x10\n\x0eresponse_oneof\"\xe7\x02\n SetIntermediateFrequencyResponse\x12g\n\x07success\x18\x01 \x01(\x0b\x32T.qm.grpc.v2.SetIntermediateFrequencyResponse.SetIntermediateFrequencyResponseSuccessH\x00\x12\x63\n\x05\x65rror\x18\x02 \x01(\x0b\x32R.qm.grpc.v2.SetIntermediateFrequencyResponse.SetIntermediateFrequencyResponseErrorH\x00\x1a\x38\n%SetIntermediateFrequencyResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a)\n\'SetIntermediateFrequencyResponseSuccessB\x10\n\x0eresponse_oneof\"\xa8\x02\n\x17SetDigitalDelayResponse\x12U\n\x07success\x18\x01 \x01(\x0b\x32\x42.qm.grpc.v2.SetDigitalDelayResponse.SetDigitalDelayResponseSuccessH\x00\x12Q\n\x05\x65rror\x18\x02 \x01(\x0b\x32@.qm.grpc.v2.SetDigitalDelayResponse.SetDigitalDelayResponseErrorH\x00\x1a/\n\x1cSetDigitalDelayResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a \n\x1eSetDigitalDelayResponseSuccessB\x10\n\x0eresponse_oneof\"\xaf\x02\n\x18SetDigitalBufferResponse\x12W\n\x07success\x18\x01 \x01(\x0b\x32\x44.qm.grpc.v2.SetDigitalBufferResponse.SetDigitalBufferResponseSuccessH\x00\x12S\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x42.qm.grpc.v2.SetDigitalBufferResponse.SetDigitalBufferResponseErrorH\x00\x1a\x30\n\x1dSetDigitalBufferResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a!\n\x1fSetDigitalBufferResponseSuccessB\x10\n\x0eresponse_oneof\"\xaf\x02\n\x18SetInputDcOffsetResponse\x12W\n\x07success\x18\x01 \x01(\x0b\x32\x44.qm.grpc.v2.SetInputDcOffsetResponse.SetInputDcOffsetResponseSuccessH\x00\x12S\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x42.qm.grpc.v2.SetInputDcOffsetResponse.SetInputDcOffsetResponseErrorH\x00\x1a\x30\n\x1dSetInputDcOffsetResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a!\n\x1fSetInputDcOffsetResponseSuccessB\x10\n\x0eresponse_oneof\"\xb6\x02\n\x19SetOutputDcOffsetResponse\x12Y\n\x07success\x18\x01 \x01(\x0b\x32\x46.qm.grpc.v2.SetOutputDcOffsetResponse.SetOutputDcOffsetResponseSuccessH\x00\x12U\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x44.qm.grpc.v2.SetOutputDcOffsetResponse.SetOutputDcOffsetResponseErrorH\x00\x1a\x31\n\x1eSetOutputDcOffsetResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\"\n SetOutputDcOffsetResponseSuccessB\x10\n\x0eresponse_oneof\"\x8c\x02\n\x13SetIoValuesResponse\x12M\n\x07success\x18\x01 \x01(\x0b\x32:.qm.grpc.v2.SetIoValuesResponse.SetIoValuesResponseSuccessH\x00\x12I\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x38.qm.grpc.v2.SetIoValuesResponse.SetIoValuesResponseErrorH\x00\x1a+\n\x18SetIoValuesResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\x1c\n\x1aSetIoValuesResponseSuccessB\x10\n\x0eresponse_oneof\"\x85\x02\n\x12SetIoValuesRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12:\n\x03io1\x18\x02 \x01(\x0b\x32-.qm.grpc.v2.SetIoValuesRequest.IOValueSetData\x12:\n\x03io2\x18\x03 \x01(\x0b\x32-.qm.grpc.v2.SetIoValuesRequest.IOValueSetData\x1ag\n\x0eIOValueSetData\x12\x13\n\tint_value\x18\x02 \x01(\x05H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x17\n\rboolean_value\x18\x04 \x01(\x08H\x00\x42\x0f\n\roneof_IO_type\"$\n\x12GetIoValuesRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"N\n\x0cIOValuesData\x12\x11\n\tint_value\x18\x01 \x01(\r\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\x01\x12\x15\n\rboolean_value\x18\x03 \x01(\x08\"\x89\x04\n\x13GetIoValuesResponse\x12M\n\x07success\x18\x01 \x01(\x0b\x32:.qm.grpc.v2.GetIoValuesResponse.GetIoValuesResponseSuccessH\x00\x12I\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x38.qm.grpc.v2.GetIoValuesResponse.GetIoValuesResponseErrorH\x00\x1a\x98\x02\n\x1aGetIoValuesResponseSuccess\x12T\n\x03io1\x18\x01 \x01(\x0b\x32G.qm.grpc.v2.GetIoValuesResponse.GetIoValuesResponseSuccess.IOValuesData\x12T\n\x03io2\x18\x02 \x01(\x0b\x32G.qm.grpc.v2.GetIoValuesResponse.GetIoValuesResponseSuccess.IOValuesData\x1aN\n\x0cIOValuesData\x12\x11\n\tint_value\x18\x01 \x01(\r\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\x01\x12\x15\n\rboolean_value\x18\x03 \x01(\x08\x1a+\n\x18GetIoValuesResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"+\n\x19JobServiceIsPausedRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x8a\x02\n\x10IsPausedResponse\x12\x43\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x32.qm.grpc.v2.IsPausedResponse.IsPausedResponseErrorH\x00\x12G\n\x07success\x18\x02 \x01(\x0b\x32\x34.qm.grpc.v2.IsPausedResponse.IsPausedResponseSuccessH\x00\x1a(\n\x15IsPausedResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a,\n\x17IsPausedResponseSuccess\x12\x11\n\tis_paused\x18\x01 \x01(\x08\x42\x10\n\x0eresponse_oneof\",\n\x1aJobServiceGetConfigRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"/\n\x1dJobServiceGetJobStatusRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x1f\n\rResumeRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xe9\x01\n\x0eResumeResponse\x12\x43\n\x07success\x18\x01 \x01(\x0b\x32\x30.qm.grpc.v2.ResumeResponse.ResumeResponseSuccessH\x00\x12?\n\x05\x65rror\x18\x02 \x01(\x0b\x32..qm.grpc.v2.ResumeResponse.ResumeResponseErrorH\x00\x1a&\n\x13ResumeResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\x17\n\x15ResumeResponseSuccessB\x10\n\x0eresponse_oneof\"d\n\x1aSetMatrixCorrectionRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12*\n\ncorrection\x18\x03 \x01(\x0b\x32\x16.qm.grpc.qm_api.Matrix\"P\n\x1fSetIntermediateFrequencyRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x11\n\tfrequency\x18\x03 \x01(\x01\"Q\n\x16SetDigitalDelayRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\x12\r\n\x05\x64\x65lay\x18\x04 \x01(\r\"S\n\x17SetDigitalBufferRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\x12\x0e\n\x06\x62uffer\x18\x04 \x01(\r\"S\n\x17SetInputDcOffsetRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x01\"\xc0\x01\n\x18SetOutputDcOffsetRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x33\n\nmix_inputs\x18\x03 \x01(\x0b\x32\x1d.qm.grpc.v2.MixInputsDcOffsetH\x00\x12\x37\n\x0csingle_input\x18\x04 \x01(\x0b\x32\x1f.qm.grpc.v2.SingleInputDcOffsetH\x00\x42\x1a\n\x18oneof_element_input_type\"8\n\x1aGetMatrixCorrectionRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\"+\n\x18GetMatrixCorrectionError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\"\x94\x03\n\x1bGetMatrixCorrectionResponse\x12Y\n\x05\x65rror\x18\x01 \x01(\x0b\x32H.qm.grpc.v2.GetMatrixCorrectionResponse.GetMatrixCorrectionResponseErrorH\x00\x12]\n\x07success\x18\x02 \x01(\x0b\x32J.qm.grpc.v2.GetMatrixCorrectionResponse.GetMatrixCorrectionResponseSuccessH\x00\x1aP\n\"GetMatrixCorrectionResponseSuccess\x12*\n\ncorrection\x18\x01 \x01(\x0b\x32\x16.qm.grpc.qm_api.Matrix\x1aW\n GetMatrixCorrectionResponseError\x12\x33\n\x05\x65rror\x18\x01 \x01(\x0b\x32$.qm.grpc.v2.GetMatrixCorrectionErrorB\x10\n\x0eresponse_oneof\"=\n\x1fGetIntermediateFrequencyRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\"\xfa\x02\n GetIntermediateFrequencyResponse\x12\x63\n\x05\x65rror\x18\x01 \x01(\x0b\x32R.qm.grpc.v2.GetIntermediateFrequencyResponse.GetIntermediateFrequencyResponseErrorH\x00\x12g\n\x07success\x18\x02 \x01(\x0b\x32T.qm.grpc.v2.GetIntermediateFrequencyResponse.GetIntermediateFrequencyResponseSuccessH\x00\x1a\x38\n%GetIntermediateFrequencyResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a<\n\'GetIntermediateFrequencyResponseSuccess\x12\x11\n\tfrequency\x18\x01 \x01(\x01\x42\x10\n\x0eresponse_oneof\"B\n\x16GetDigitalDelayRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\"\xb7\x02\n\x17GetDigitalDelayResponse\x12U\n\x07success\x18\x01 \x01(\x0b\x32\x42.qm.grpc.v2.GetDigitalDelayResponse.GetDigitalDelayResponseSuccessH\x00\x12Q\n\x05\x65rror\x18\x02 \x01(\x0b\x32@.qm.grpc.v2.GetDigitalDelayResponse.GetDigitalDelayResponseErrorH\x00\x1a/\n\x1cGetDigitalDelayResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a/\n\x1eGetDigitalDelayResponseSuccess\x12\r\n\x05\x64\x65lay\x18\x01 \x01(\rB\x10\n\x0eresponse_oneof\"C\n\x17GetDigitalBufferRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\"\xbf\x02\n\x18GetDigitalBufferResponse\x12W\n\x07success\x18\x01 \x01(\x0b\x32\x44.qm.grpc.v2.GetDigitalBufferResponse.GetDigitalBufferResponseSuccessH\x00\x12S\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x42.qm.grpc.v2.GetDigitalBufferResponse.GetDigitalBufferResponseErrorH\x00\x1a\x30\n\x1dGetDigitalBufferResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\x31\n\x1fGetDigitalBufferResponseSuccess\x12\x0e\n\x06\x62uffer\x18\x01 \x01(\rB\x10\n\x0eresponse_oneof\"C\n\x17GetInputDcOffsetRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\"(\n\x15GetInputDcOffsetError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\")\n\x17GetInputDcOffsetSuccess\x12\x0e\n\x06offset\x18\x01 \x01(\x01\"\xbf\x02\n\x18GetInputDcOffsetResponse\x12W\n\x07success\x18\x01 \x01(\x0b\x32\x44.qm.grpc.v2.GetInputDcOffsetResponse.GetInputDcOffsetResponseSuccessH\x00\x12S\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x42.qm.grpc.v2.GetInputDcOffsetResponse.GetInputDcOffsetResponseErrorH\x00\x1a\x30\n\x1dGetInputDcOffsetResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\x31\n\x1fGetInputDcOffsetResponseSuccess\x12\x0e\n\x06offset\x18\x01 \x01(\x01\x42\x10\n\x0eresponse_oneof\"6\n\x18GetOutputDcOffsetRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\"\xc1\x03\n\x19GetOutputDcOffsetResponse\x12Y\n\x07success\x18\x01 \x01(\x0b\x32\x46.qm.grpc.v2.GetOutputDcOffsetResponse.GetOutputDcOffsetResponseSuccessH\x00\x12U\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x44.qm.grpc.v2.GetOutputDcOffsetResponse.GetOutputDcOffsetResponseErrorH\x00\x1a\x31\n\x1eGetOutputDcOffsetResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\xac\x01\n GetOutputDcOffsetResponseSuccess\x12\x33\n\nmix_inputs\x18\x02 \x01(\x0b\x32\x1d.qm.grpc.v2.MixInputsDcOffsetH\x00\x12\x37\n\x0csingle_input\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.v2.SingleInputDcOffsetH\x00\x42\x1a\n\x18oneof_element_input_typeB\x10\n\x0eresponse_oneof\"?\n\x11MixInputsDcOffset\x12\x0e\n\x01I\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0e\n\x01Q\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x04\n\x02_IB\x04\n\x02_Q\"%\n\x13SingleInputDcOffset\x12\x0e\n\x06offset\x18\x01 \x01(\x01\"\x8d\x01\n\x1bJobServiceGetConfigResponse\x12/\n\x07success\x18\x01 \x01(\x0b\x32\x1c.qm.grpc.v2.GetConfigSuccessH\x00\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1a.qm.grpc.v2.GetConfigErrorH\x00\x42\x10\n\x0eresponse_oneof\"\x89\x03\n\x1eJobServiceGetJobStatusResponse\x12\x63\n\x07success\x18\x01 \x01(\x0b\x32P.qm.grpc.v2.JobServiceGetJobStatusResponse.JobServiceGetJobStatusResponseSuccessH\x00\x12_\n\x05\x65rror\x18\x02 \x01(\x0b\x32N.qm.grpc.v2.JobServiceGetJobStatusResponse.JobServiceGetJobStatusResponseErrorH\x00\x1a\x36\n#JobServiceGetJobStatusResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1aW\n%JobServiceGetJobStatusResponseSuccess\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.qm.grpc.v2.JobExecutionStatusB\x10\n\x0eresponse_oneof\"\xa1\x02\n\"JobServicePushToInputStreamRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12=\n\x0fint_stream_data\x18\x03 \x01(\x0b\x32\".qm.grpc.job_manager.IntStreamDataH\x00\x12\x41\n\x11\x66ixed_stream_data\x18\x04 \x01(\x0b\x32$.qm.grpc.job_manager.FixedStreamDataH\x00\x12?\n\x10\x62ool_stream_data\x18\x05 \x01(\x0b\x32#.qm.grpc.job_manager.BoolStreamDataH\x00\x42\x13\n\x11stream_data_oneof\"\xb6\x02\n\x19PushToInputStreamResponse\x12Y\n\x07success\x18\x01 \x01(\x0b\x32\x46.qm.grpc.v2.PushToInputStreamResponse.PushToInputStreamResponseSuccessH\x00\x12U\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x44.qm.grpc.v2.PushToInputStreamResponse.PushToInputStreamResponseErrorH\x00\x1a\"\n PushToInputStreamResponseSuccess\x1a\x31\n\x1ePushToInputStreamResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"+\n\x19GetJobResultSchemaRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x82\x04\n\x1aGetJobResultSchemaResponse\x12[\n\x07success\x18\x01 \x01(\x0b\x32H.qm.grpc.v2.GetJobResultSchemaResponse.GetJobResultSchemaResponseSuccessH\x00\x12W\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x46.qm.grpc.v2.GetJobResultSchemaResponse.GetJobResultSchemaResponseErrorH\x00\x1a\xe7\x01\n!GetJobResultSchemaResponseSuccess\x12\\\n\x05items\x18\x01 \x03(\x0b\x32M.qm.grpc.v2.GetJobResultSchemaResponse.GetJobResultSchemaResponseSuccess.Item\x1a\x64\n\x04Item\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0csimple_dtype\x18\x02 \x01(\t\x12\x11\n\tis_single\x18\x03 \x01(\x08\x12\x16\n\x0e\x65xpected_count\x18\x04 \x01(\x05\x12\r\n\x05shape\x18\x05 \x03(\x05\x1a\x32\n\x1fGetJobResultSchemaResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"Z\n\x1eGetJobNamedResultHeaderRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\x12\x13\n\x0b\x66lat_format\x18\x03 \x01(\x08\"\xac\x01\n GetJobNamedResultsHeadersRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x44\n\x07outputs\x18\x02 \x03(\x0b\x32\x33.qm.grpc.v2.GetJobNamedResultsHeadersRequest.Output\x1a\x32\n\x06Output\x12\x13\n\x0boutput_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66lat_format\x18\x02 \x01(\x08\"\xdc\x04\n!GetJobNamedResultsHeadersResponse\x12i\n\x07success\x18\x01 \x01(\x0b\x32V.qm.grpc.v2.GetJobNamedResultsHeadersResponse.GetJobNamedResultsHeadersResponseSuccessH\x00\x12\x65\n\x05\x65rror\x18\x02 \x01(\x0b\x32T.qm.grpc.v2.GetJobNamedResultsHeadersResponse.GetJobNamedResultsHeadersResponseErrorH\x00\x1a\x97\x02\n(GetJobNamedResultsHeadersResponseSuccess\x12t\n\x07headers\x18\x01 \x03(\x0b\x32\x63.qm.grpc.v2.GetJobNamedResultsHeadersResponse.GetJobNamedResultsHeadersResponseSuccess.OutputHeader\x1au\n\x0cOutputHeader\x12\x14\n\x0c\x63ount_so_far\x18\x01 \x01(\x05\x12\x15\n\rhas_data_loss\x18\x02 \x01(\x08\x12\x13\n\x0boutput_name\x18\x03 \x01(\t\x12\x14\n\x0csimple_dtype\x18\x04 \x01(\t\x12\r\n\x05shape\x18\x05 \x03(\x05\x1a\x39\n&GetJobNamedResultsHeadersResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\xdb\x03\n\x1fGetJobNamedResultHeaderResponse\x12\x65\n\x07success\x18\x01 \x01(\x0b\x32R.qm.grpc.v2.GetJobNamedResultHeaderResponse.GetJobNamedResultHeaderResponseSuccessH\x00\x12\x61\n\x05\x65rror\x18\x02 \x01(\x0b\x32P.qm.grpc.v2.GetJobNamedResultHeaderResponse.GetJobNamedResultHeaderResponseErrorH\x00\x1a\x37\n$GetJobNamedResultHeaderResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\xa2\x01\n&GetJobNamedResultHeaderResponseSuccess\x12\x11\n\tis_single\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ount_so_far\x18\x02 \x01(\x05\x12\x14\n\x0csimple_dtype\x18\x03 \x01(\t\x12\x15\n\rhas_data_loss\x18\x04 \x01(\x08\x12\r\n\x05shape\x18\x05 \x03(\x05\x12\x13\n\x0boutput_name\x18\x06 \x01(\tB\x10\n\x0eresponse_oneof\"\xa5\x01\n\x16GetNamedResultsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12:\n\x07outputs\x18\x02 \x03(\x0b\x32).qm.grpc.v2.GetNamedResultsRequest.Output\x1a?\n\x06Output\x12\x13\n\x0boutput_name\x18\x01 \x01(\t\x12 \n\x05range\x18\x02 \x01(\x0b\x32\x11.qm.grpc.v2.Range\"}\n\x15GetNamedResultRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x30\n\x0blong_offset\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xf4\x04\n\x16GetNamedResultResponse\x12S\n\x07success\x18\x01 \x01(\x0b\x32@.qm.grpc.v2.GetNamedResultResponse.GetNamedResultResponseSuccessH\x00\x12O\n\x05\x65rror\x18\x02 \x01(\x0b\x32>.qm.grpc.v2.GetNamedResultResponse.GetNamedResultResponseErrorH\x00\x1a.\n\x1bGetNamedResultResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\xf1\x02\n\x1dGetNamedResultResponseSuccess\x12\x1a\n\x0e\x63ount_of_items\x18\x01 \x01(\x05\x42\x02\x18\x01\x12\x10\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x02\x18\x01\x12`\n\ndata_chunk\x18\x03 \x01(\x0b\x32J.qm.grpc.v2.GetNamedResultResponse.GetNamedResultResponseSuccess.DataChunkH\x00\x12\x64\n\x0c\x64\x61ta_summary\x18\x04 \x01(\x0b\x32L.qm.grpc.v2.GetNamedResultResponse.GetNamedResultResponseSuccess.DataSummaryH\x00\x12\x13\n\x0boutput_name\x18\x05 \x01(\t\x1a\x19\n\tDataChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x1a\x1c\n\x0b\x44\x61taSummary\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x42\x0c\n\ndata_oneofB\x10\n\x0eresponse_oneof\"%\n\x13GetJobErrorsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xb4\x04\n\x14GetJobErrorsResponse\x12O\n\x07success\x18\x01 \x01(\x0b\x32<.qm.grpc.v2.GetJobErrorsResponse.GetJobErrorsResponseSuccessH\x00\x12K\n\x05\x65rror\x18\x02 \x01(\x0b\x32:.qm.grpc.v2.GetJobErrorsResponse.GetJobErrorsResponseErrorH\x00\x1a,\n\x19GetJobErrorsResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\xbd\x02\n\x1bGetJobErrorsResponseSuccess\x12R\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x42.qm.grpc.v2.GetJobErrorsResponse.GetJobErrorsResponseSuccess.Error\x1a\x97\x01\n\x05\x45rror\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12j\n\rerrorSeverity\x18\x02 \x01(\x0e\x32S.qm.grpc.v2.GetJobErrorsResponse.GetJobErrorsResponseSuccess.ExecutionErrorSeverity\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\x16\x45xecutionErrorSeverity\x12\t\n\x05\x45RROR\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x42\x10\n\x0eresponse_oneof\"\x1f\n\rCancelRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xd5\x01\n\x0e\x43\x61ncelResponse\x12>\n\x07success\x18\x01 \x01(\x0b\x32+.qm.grpc.v2.CancelResponse.CancelJobSuccessH\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32).qm.grpc.v2.CancelResponse.CancelJobErrorH\x00\x1a!\n\x0e\x43\x61ncelJobError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\x12\n\x10\x43\x61ncelJobSuccessB\x10\n\x0eresponse_oneof\"*\n\x18GetJobResultStateRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xea\x02\n\x19GetJobResultStateResponse\x12Y\n\x07success\x18\x01 \x01(\x0b\x32\x46.qm.grpc.v2.GetJobResultStateResponse.GetJobResultStateResponseSuccessH\x00\x12U\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x44.qm.grpc.v2.GetJobResultStateResponse.GetJobResultStateResponseErrorH\x00\x1a\x31\n\x1eGetJobResultStateResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1aV\n GetJobResultStateResponseSuccess\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12\x0e\n\x06\x63losed\x18\x02 \x01(\x08\x12\x14\n\x0chas_dataloss\x18\x03 \x01(\x08\x42\x10\n\x0eresponse_oneof\"U\n\x12PullSamplesRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x16\n\x0einclude_analog\x18\x02 \x01(\x08\x12\x17\n\x0finclude_digital\x18\x03 \x01(\x08\"\xeb\x07\n\x13PullSamplesResponse\x12M\n\x07success\x18\x01 \x01(\x0b\x32:.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccessH\x00\x12I\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x38.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseErrorH\x00\x1a+\n\x18PullSamplesResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\xfa\x05\n\x1aPullSamplesResponseSuccess\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x65m_id\x18\x02 \x01(\x05\x12\x0f\n\x07port_id\x18\x03 \x01(\x05\x12M\n\x04mode\x18\x04 \x01(\x0e\x32?.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccess.Mode\x12\\\n\x0b\x64ouble_data\x18\x05 \x01(\x0b\x32\x45.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccess.doubleDataH\x00\x12^\n\x0c\x62oolean_data\x18\x06 \x01(\x0b\x32\x46.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccess.booleanDataH\x00\x1a\xb0\x01\n\ndoubleData\x12K\n\x02mw\x18\x01 \x01(\x0b\x32=.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccess.mwH\x00\x12K\n\x02lf\x18\x02 \x01(\x0b\x32=.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccess.lfH\x00\x42\x08\n\x06output\x1a)\n\x02mw\x12\r\n\x05\x64ucId\x18\x01 \x01(\x05\x12\t\n\x01I\x18\x02 \x03(\x01\x12\t\n\x01Q\x18\x03 \x03(\x01\x1a\x13\n\x02lf\x12\r\n\x05items\x18\x01 \x03(\x01\x1a~\n\x0b\x62ooleanData\x12Y\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32K.qm.grpc.v2.PullSamplesResponse.PullSamplesResponseSuccess.booleanData.Data\x1a\x14\n\x04\x44\x61ta\x12\x0c\n\x04item\x18\x01 \x03(\x08\"\x1f\n\x04Mode\x12\n\n\x06\x41NALOG\x10\x00\x12\x0b\n\x07\x44IGITAL\x10\x01\x42\x06\n\x04\x64\x61taB\x10\n\x0eresponse_oneof\"\xfd\x01\n\x1dSetOscillatorFrequencyRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\n\n\x02qe\x18\x02 \x01(\t\x12\x18\n\x10new_frequency_hz\x18\x03 \x01(\x01\x12\\\n\x10update_component\x18\x04 \x01(\x0e\x32\x42.qm.grpc.v2.SetOscillatorFrequencyRequest.UpdateComponentSelection\"H\n\x18UpdateComponentSelection\x12\x08\n\x04\x62oth\x10\x00\x12\x0f\n\x0bupconverter\x10\x01\x12\x11\n\rdownconverter\x10\x02\"\xc5\x02\n\x1eSetOscillatorFrequencyResponse\x12^\n\x07success\x18\x01 \x01(\x0b\x32K.qm.grpc.v2.SetOscillatorFrequencyResponse.ChangeOscillatorFrequencySuccessH\x00\x12Z\n\x05\x65rror\x18\x02 \x01(\x0b\x32I.qm.grpc.v2.SetOscillatorFrequencyResponse.ChangeOscillatorFrequencyErrorH\x00\x1a\x31\n\x1e\x43hangeOscillatorFrequencyError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\"\n ChangeOscillatorFrequencySuccessB\x10\n\x0eresponse_oneof\"*\n\x18GetWaveformReportRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xc7\x02\n\x19GetWaveformReportResponse\x12Q\n\x07success\x18\x01 \x01(\x0b\x32>.qm.grpc.v2.GetWaveformReportResponse.GetWaveformReportSuccessH\x00\x12M\n\x05\x65rror\x18\x02 \x01(\x0b\x32<.qm.grpc.v2.GetWaveformReportResponse.GetWaveformReportErrorH\x00\x1aK\n\x18GetWaveformReportSuccess\x12/\n\x0ewaveformReport\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a)\n\x16GetWaveformReportError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof2\xf6\x17\n\nJobService\x12^\n\tGetConfig\x12&.qm.grpc.v2.JobServiceGetConfigRequest\x1a\'.qm.grpc.v2.JobServiceGetConfigResponse\"\x00\x12g\n\x0cGetJobStatus\x12).qm.grpc.v2.JobServiceGetJobStatusRequest\x1a*.qm.grpc.v2.JobServiceGetJobStatusResponse\"\x00\x12p\n\x13GetJobStatusUpdates\x12).qm.grpc.v2.JobServiceGetJobStatusRequest\x1a*.qm.grpc.v2.JobServiceGetJobStatusResponse\"\x00\x30\x01\x12l\n\x11PushToInputStream\x12..qm.grpc.v2.JobServicePushToInputStreamRequest\x1a%.qm.grpc.v2.PushToInputStreamResponse\"\x00\x12Q\n\x08IsPaused\x12%.qm.grpc.v2.JobServiceIsPausedRequest\x1a\x1c.qm.grpc.v2.IsPausedResponse\"\x00\x12\x41\n\x06Resume\x12\x19.qm.grpc.v2.ResumeRequest\x1a\x1a.qm.grpc.v2.ResumeResponse\"\x00\x12h\n\x13SetMatrixCorrection\x12&.qm.grpc.v2.SetMatrixCorrectionRequest\x1a\'.qm.grpc.v2.SetMatrixCorrectionResponse\"\x00\x12h\n\x13GetMatrixCorrection\x12&.qm.grpc.v2.GetMatrixCorrectionRequest\x1a\'.qm.grpc.v2.GetMatrixCorrectionResponse\"\x00\x12w\n\x18SetIntermediateFrequency\x12+.qm.grpc.v2.SetIntermediateFrequencyRequest\x1a,.qm.grpc.v2.SetIntermediateFrequencyResponse\"\x00\x12w\n\x18GetIntermediateFrequency\x12+.qm.grpc.v2.GetIntermediateFrequencyRequest\x1a,.qm.grpc.v2.GetIntermediateFrequencyResponse\"\x00\x12\\\n\x0fSetDigitalDelay\x12\".qm.grpc.v2.SetDigitalDelayRequest\x1a#.qm.grpc.v2.SetDigitalDelayResponse\"\x00\x12\\\n\x0fGetDigitalDelay\x12\".qm.grpc.v2.GetDigitalDelayRequest\x1a#.qm.grpc.v2.GetDigitalDelayResponse\"\x00\x12_\n\x10SetDigitalBuffer\x12#.qm.grpc.v2.SetDigitalBufferRequest\x1a$.qm.grpc.v2.SetDigitalBufferResponse\"\x00\x12_\n\x10GetDigitalBuffer\x12#.qm.grpc.v2.GetDigitalBufferRequest\x1a$.qm.grpc.v2.GetDigitalBufferResponse\"\x00\x12_\n\x10SetInputDcOffset\x12#.qm.grpc.v2.SetInputDcOffsetRequest\x1a$.qm.grpc.v2.SetInputDcOffsetResponse\"\x00\x12_\n\x10GetInputDcOffset\x12#.qm.grpc.v2.GetInputDcOffsetRequest\x1a$.qm.grpc.v2.GetInputDcOffsetResponse\"\x00\x12\x62\n\x11SetOutputDcOffset\x12$.qm.grpc.v2.SetOutputDcOffsetRequest\x1a%.qm.grpc.v2.SetOutputDcOffsetResponse\"\x00\x12\x62\n\x11GetOutputDcOffset\x12$.qm.grpc.v2.GetOutputDcOffsetRequest\x1a%.qm.grpc.v2.GetOutputDcOffsetResponse\"\x00\x12q\n\x16SetOscillatorFrequency\x12).qm.grpc.v2.SetOscillatorFrequencyRequest\x1a*.qm.grpc.v2.SetOscillatorFrequencyResponse\"\x00\x12P\n\x0bSetIOValues\x12\x1e.qm.grpc.v2.SetIoValuesRequest\x1a\x1f.qm.grpc.v2.SetIoValuesResponse\"\x00\x12P\n\x0bGetIOValues\x12\x1e.qm.grpc.v2.GetIoValuesRequest\x1a\x1f.qm.grpc.v2.GetIoValuesResponse\"\x00\x12\x65\n\x12GetJobResultSchema\x12%.qm.grpc.v2.GetJobResultSchemaRequest\x1a&.qm.grpc.v2.GetJobResultSchemaResponse\"\x00\x12t\n\x17GetJobNamedResultHeader\x12*.qm.grpc.v2.GetJobNamedResultHeaderRequest\x1a+.qm.grpc.v2.GetJobNamedResultHeaderResponse\"\x00\x12z\n\x19GetJobNamedResultsHeaders\x12,.qm.grpc.v2.GetJobNamedResultsHeadersRequest\x1a-.qm.grpc.v2.GetJobNamedResultsHeadersResponse\"\x00\x12[\n\x0eGetNamedResult\x12!.qm.grpc.v2.GetNamedResultRequest\x1a\".qm.grpc.v2.GetNamedResultResponse\"\x00\x30\x01\x12]\n\x0fGetNamedResults\x12\".qm.grpc.v2.GetNamedResultsRequest\x1a\".qm.grpc.v2.GetNamedResultResponse\"\x00\x30\x01\x12P\n\tGetErrors\x12\x1f.qm.grpc.v2.GetJobErrorsRequest\x1a .qm.grpc.v2.GetJobErrorsResponse\"\x00\x12\x62\n\x11GetJobResultState\x12$.qm.grpc.v2.GetJobResultStateRequest\x1a%.qm.grpc.v2.GetJobResultStateResponse\"\x00\x12R\n\x0bPullSamples\x12\x1e.qm.grpc.v2.PullSamplesRequest\x1a\x1f.qm.grpc.v2.PullSamplesResponse\"\x00\x30\x01\x12\x41\n\x06\x43\x61ncel\x12\x19.qm.grpc.v2.CancelRequest\x1a\x1a.qm.grpc.v2.CancelResponse\"\x00\x12\x62\n\x11GetWaveformReport\x12$.qm.grpc.v2.GetWaveformReportRequest\x1a%.qm.grpc.v2.GetWaveformReportResponse\"\x00\x42\x1a\n\x10qm.client.api.v2P\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.grpc.v2.job_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020qm.client.api.v2P\001\242\002\003HLW'
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS'].fields_by_name['count_of_items']._loaded_options = None
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS'].fields_by_name['count_of_items']._serialized_options = b'\030\001'
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS'].fields_by_name['data']._loaded_options = None
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS'].fields_by_name['data']._serialized_options = b'\030\001'
  _globals['_SETMATRIXCORRECTIONRESPONSE']._serialized_start=233
  _globals['_SETMATRIXCORRECTIONRESPONSE']._serialized_end=557
  _globals['_SETMATRIXCORRECTIONRESPONSE_SETMATRIXCORRECTIONRESPONSEERROR']._serialized_start=450
  _globals['_SETMATRIXCORRECTIONRESPONSE_SETMATRIXCORRECTIONRESPONSEERROR']._serialized_end=501
  _globals['_SETMATRIXCORRECTIONRESPONSE_SETMATRIXCORRECTIONRESPONSESUCCESS']._serialized_start=503
  _globals['_SETMATRIXCORRECTIONRESPONSE_SETMATRIXCORRECTIONRESPONSESUCCESS']._serialized_end=539
  _globals['_SETINTERMEDIATEFREQUENCYRESPONSE']._serialized_start=560
  _globals['_SETINTERMEDIATEFREQUENCYRESPONSE']._serialized_end=919
  _globals['_SETINTERMEDIATEFREQUENCYRESPONSE_SETINTERMEDIATEFREQUENCYRESPONSEERROR']._serialized_start=802
  _globals['_SETINTERMEDIATEFREQUENCYRESPONSE_SETINTERMEDIATEFREQUENCYRESPONSEERROR']._serialized_end=858
  _globals['_SETINTERMEDIATEFREQUENCYRESPONSE_SETINTERMEDIATEFREQUENCYRESPONSESUCCESS']._serialized_start=860
  _globals['_SETINTERMEDIATEFREQUENCYRESPONSE_SETINTERMEDIATEFREQUENCYRESPONSESUCCESS']._serialized_end=901
  _globals['_SETDIGITALDELAYRESPONSE']._serialized_start=922
  _globals['_SETDIGITALDELAYRESPONSE']._serialized_end=1218
  _globals['_SETDIGITALDELAYRESPONSE_SETDIGITALDELAYRESPONSEERROR']._serialized_start=1119
  _globals['_SETDIGITALDELAYRESPONSE_SETDIGITALDELAYRESPONSEERROR']._serialized_end=1166
  _globals['_SETDIGITALDELAYRESPONSE_SETDIGITALDELAYRESPONSESUCCESS']._serialized_start=1168
  _globals['_SETDIGITALDELAYRESPONSE_SETDIGITALDELAYRESPONSESUCCESS']._serialized_end=1200
  _globals['_SETDIGITALBUFFERRESPONSE']._serialized_start=1221
  _globals['_SETDIGITALBUFFERRESPONSE']._serialized_end=1524
  _globals['_SETDIGITALBUFFERRESPONSE_SETDIGITALBUFFERRESPONSEERROR']._serialized_start=1423
  _globals['_SETDIGITALBUFFERRESPONSE_SETDIGITALBUFFERRESPONSEERROR']._serialized_end=1471
  _globals['_SETDIGITALBUFFERRESPONSE_SETDIGITALBUFFERRESPONSESUCCESS']._serialized_start=1473
  _globals['_SETDIGITALBUFFERRESPONSE_SETDIGITALBUFFERRESPONSESUCCESS']._serialized_end=1506
  _globals['_SETINPUTDCOFFSETRESPONSE']._serialized_start=1527
  _globals['_SETINPUTDCOFFSETRESPONSE']._serialized_end=1830
  _globals['_SETINPUTDCOFFSETRESPONSE_SETINPUTDCOFFSETRESPONSEERROR']._serialized_start=1729
  _globals['_SETINPUTDCOFFSETRESPONSE_SETINPUTDCOFFSETRESPONSEERROR']._serialized_end=1777
  _globals['_SETINPUTDCOFFSETRESPONSE_SETINPUTDCOFFSETRESPONSESUCCESS']._serialized_start=1779
  _globals['_SETINPUTDCOFFSETRESPONSE_SETINPUTDCOFFSETRESPONSESUCCESS']._serialized_end=1812
  _globals['_SETOUTPUTDCOFFSETRESPONSE']._serialized_start=1833
  _globals['_SETOUTPUTDCOFFSETRESPONSE']._serialized_end=2143
  _globals['_SETOUTPUTDCOFFSETRESPONSE_SETOUTPUTDCOFFSETRESPONSEERROR']._serialized_start=2040
  _globals['_SETOUTPUTDCOFFSETRESPONSE_SETOUTPUTDCOFFSETRESPONSEERROR']._serialized_end=2089
  _globals['_SETOUTPUTDCOFFSETRESPONSE_SETOUTPUTDCOFFSETRESPONSESUCCESS']._serialized_start=2091
  _globals['_SETOUTPUTDCOFFSETRESPONSE_SETOUTPUTDCOFFSETRESPONSESUCCESS']._serialized_end=2125
  _globals['_SETIOVALUESRESPONSE']._serialized_start=2146
  _globals['_SETIOVALUESRESPONSE']._serialized_end=2414
  _globals['_SETIOVALUESRESPONSE_SETIOVALUESRESPONSEERROR']._serialized_start=2323
  _globals['_SETIOVALUESRESPONSE_SETIOVALUESRESPONSEERROR']._serialized_end=2366
  _globals['_SETIOVALUESRESPONSE_SETIOVALUESRESPONSESUCCESS']._serialized_start=2368
  _globals['_SETIOVALUESRESPONSE_SETIOVALUESRESPONSESUCCESS']._serialized_end=2396
  _globals['_SETIOVALUESREQUEST']._serialized_start=2417
  _globals['_SETIOVALUESREQUEST']._serialized_end=2678
  _globals['_SETIOVALUESREQUEST_IOVALUESETDATA']._serialized_start=2575
  _globals['_SETIOVALUESREQUEST_IOVALUESETDATA']._serialized_end=2678
  _globals['_GETIOVALUESREQUEST']._serialized_start=2680
  _globals['_GETIOVALUESREQUEST']._serialized_end=2716
  _globals['_IOVALUESDATA']._serialized_start=2718
  _globals['_IOVALUESDATA']._serialized_end=2796
  _globals['_GETIOVALUESRESPONSE']._serialized_start=2799
  _globals['_GETIOVALUESRESPONSE']._serialized_end=3320
  _globals['_GETIOVALUESRESPONSE_GETIOVALUESRESPONSESUCCESS']._serialized_start=2977
  _globals['_GETIOVALUESRESPONSE_GETIOVALUESRESPONSESUCCESS']._serialized_end=3257
  _globals['_GETIOVALUESRESPONSE_GETIOVALUESRESPONSESUCCESS_IOVALUESDATA']._serialized_start=2718
  _globals['_GETIOVALUESRESPONSE_GETIOVALUESRESPONSESUCCESS_IOVALUESDATA']._serialized_end=2796
  _globals['_GETIOVALUESRESPONSE_GETIOVALUESRESPONSEERROR']._serialized_start=3259
  _globals['_GETIOVALUESRESPONSE_GETIOVALUESRESPONSEERROR']._serialized_end=3302
  _globals['_JOBSERVICEISPAUSEDREQUEST']._serialized_start=3322
  _globals['_JOBSERVICEISPAUSEDREQUEST']._serialized_end=3365
  _globals['_ISPAUSEDRESPONSE']._serialized_start=3368
  _globals['_ISPAUSEDRESPONSE']._serialized_end=3634
  _globals['_ISPAUSEDRESPONSE_ISPAUSEDRESPONSEERROR']._serialized_start=3530
  _globals['_ISPAUSEDRESPONSE_ISPAUSEDRESPONSEERROR']._serialized_end=3570
  _globals['_ISPAUSEDRESPONSE_ISPAUSEDRESPONSESUCCESS']._serialized_start=3572
  _globals['_ISPAUSEDRESPONSE_ISPAUSEDRESPONSESUCCESS']._serialized_end=3616
  _globals['_JOBSERVICEGETCONFIGREQUEST']._serialized_start=3636
  _globals['_JOBSERVICEGETCONFIGREQUEST']._serialized_end=3680
  _globals['_JOBSERVICEGETJOBSTATUSREQUEST']._serialized_start=3682
  _globals['_JOBSERVICEGETJOBSTATUSREQUEST']._serialized_end=3729
  _globals['_RESUMEREQUEST']._serialized_start=3731
  _globals['_RESUMEREQUEST']._serialized_end=3762
  _globals['_RESUMERESPONSE']._serialized_start=3765
  _globals['_RESUMERESPONSE']._serialized_end=3998
  _globals['_RESUMERESPONSE_RESUMERESPONSEERROR']._serialized_start=3917
  _globals['_RESUMERESPONSE_RESUMERESPONSEERROR']._serialized_end=3955
  _globals['_RESUMERESPONSE_RESUMERESPONSESUCCESS']._serialized_start=3957
  _globals['_RESUMERESPONSE_RESUMERESPONSESUCCESS']._serialized_end=3980
  _globals['_SETMATRIXCORRECTIONREQUEST']._serialized_start=4000
  _globals['_SETMATRIXCORRECTIONREQUEST']._serialized_end=4100
  _globals['_SETINTERMEDIATEFREQUENCYREQUEST']._serialized_start=4102
  _globals['_SETINTERMEDIATEFREQUENCYREQUEST']._serialized_end=4182
  _globals['_SETDIGITALDELAYREQUEST']._serialized_start=4184
  _globals['_SETDIGITALDELAYREQUEST']._serialized_end=4265
  _globals['_SETDIGITALBUFFERREQUEST']._serialized_start=4267
  _globals['_SETDIGITALBUFFERREQUEST']._serialized_end=4350
  _globals['_SETINPUTDCOFFSETREQUEST']._serialized_start=4352
  _globals['_SETINPUTDCOFFSETREQUEST']._serialized_end=4435
  _globals['_SETOUTPUTDCOFFSETREQUEST']._serialized_start=4438
  _globals['_SETOUTPUTDCOFFSETREQUEST']._serialized_end=4630
  _globals['_GETMATRIXCORRECTIONREQUEST']._serialized_start=4632
  _globals['_GETMATRIXCORRECTIONREQUEST']._serialized_end=4688
  _globals['_GETMATRIXCORRECTIONERROR']._serialized_start=4690
  _globals['_GETMATRIXCORRECTIONERROR']._serialized_end=4733
  _globals['_GETMATRIXCORRECTIONRESPONSE']._serialized_start=4736
  _globals['_GETMATRIXCORRECTIONRESPONSE']._serialized_end=5140
  _globals['_GETMATRIXCORRECTIONRESPONSE_GETMATRIXCORRECTIONRESPONSESUCCESS']._serialized_start=4953
  _globals['_GETMATRIXCORRECTIONRESPONSE_GETMATRIXCORRECTIONRESPONSESUCCESS']._serialized_end=5033
  _globals['_GETMATRIXCORRECTIONRESPONSE_GETMATRIXCORRECTIONRESPONSEERROR']._serialized_start=5035
  _globals['_GETMATRIXCORRECTIONRESPONSE_GETMATRIXCORRECTIONRESPONSEERROR']._serialized_end=5122
  _globals['_GETINTERMEDIATEFREQUENCYREQUEST']._serialized_start=5142
  _globals['_GETINTERMEDIATEFREQUENCYREQUEST']._serialized_end=5203
  _globals['_GETINTERMEDIATEFREQUENCYRESPONSE']._serialized_start=5206
  _globals['_GETINTERMEDIATEFREQUENCYRESPONSE']._serialized_end=5584
  _globals['_GETINTERMEDIATEFREQUENCYRESPONSE_GETINTERMEDIATEFREQUENCYRESPONSEERROR']._serialized_start=5448
  _globals['_GETINTERMEDIATEFREQUENCYRESPONSE_GETINTERMEDIATEFREQUENCYRESPONSEERROR']._serialized_end=5504
  _globals['_GETINTERMEDIATEFREQUENCYRESPONSE_GETINTERMEDIATEFREQUENCYRESPONSESUCCESS']._serialized_start=5506
  _globals['_GETINTERMEDIATEFREQUENCYRESPONSE_GETINTERMEDIATEFREQUENCYRESPONSESUCCESS']._serialized_end=5566
  _globals['_GETDIGITALDELAYREQUEST']._serialized_start=5586
  _globals['_GETDIGITALDELAYREQUEST']._serialized_end=5652
  _globals['_GETDIGITALDELAYRESPONSE']._serialized_start=5655
  _globals['_GETDIGITALDELAYRESPONSE']._serialized_end=5966
  _globals['_GETDIGITALDELAYRESPONSE_GETDIGITALDELAYRESPONSEERROR']._serialized_start=5852
  _globals['_GETDIGITALDELAYRESPONSE_GETDIGITALDELAYRESPONSEERROR']._serialized_end=5899
  _globals['_GETDIGITALDELAYRESPONSE_GETDIGITALDELAYRESPONSESUCCESS']._serialized_start=5901
  _globals['_GETDIGITALDELAYRESPONSE_GETDIGITALDELAYRESPONSESUCCESS']._serialized_end=5948
  _globals['_GETDIGITALBUFFERREQUEST']._serialized_start=5968
  _globals['_GETDIGITALBUFFERREQUEST']._serialized_end=6035
  _globals['_GETDIGITALBUFFERRESPONSE']._serialized_start=6038
  _globals['_GETDIGITALBUFFERRESPONSE']._serialized_end=6357
  _globals['_GETDIGITALBUFFERRESPONSE_GETDIGITALBUFFERRESPONSEERROR']._serialized_start=6240
  _globals['_GETDIGITALBUFFERRESPONSE_GETDIGITALBUFFERRESPONSEERROR']._serialized_end=6288
  _globals['_GETDIGITALBUFFERRESPONSE_GETDIGITALBUFFERRESPONSESUCCESS']._serialized_start=6290
  _globals['_GETDIGITALBUFFERRESPONSE_GETDIGITALBUFFERRESPONSESUCCESS']._serialized_end=6339
  _globals['_GETINPUTDCOFFSETREQUEST']._serialized_start=6359
  _globals['_GETINPUTDCOFFSETREQUEST']._serialized_end=6426
  _globals['_GETINPUTDCOFFSETERROR']._serialized_start=6428
  _globals['_GETINPUTDCOFFSETERROR']._serialized_end=6468
  _globals['_GETINPUTDCOFFSETSUCCESS']._serialized_start=6470
  _globals['_GETINPUTDCOFFSETSUCCESS']._serialized_end=6511
  _globals['_GETINPUTDCOFFSETRESPONSE']._serialized_start=6514
  _globals['_GETINPUTDCOFFSETRESPONSE']._serialized_end=6833
  _globals['_GETINPUTDCOFFSETRESPONSE_GETINPUTDCOFFSETRESPONSEERROR']._serialized_start=6716
  _globals['_GETINPUTDCOFFSETRESPONSE_GETINPUTDCOFFSETRESPONSEERROR']._serialized_end=6764
  _globals['_GETINPUTDCOFFSETRESPONSE_GETINPUTDCOFFSETRESPONSESUCCESS']._serialized_start=6766
  _globals['_GETINPUTDCOFFSETRESPONSE_GETINPUTDCOFFSETRESPONSESUCCESS']._serialized_end=6815
  _globals['_GETOUTPUTDCOFFSETREQUEST']._serialized_start=6835
  _globals['_GETOUTPUTDCOFFSETREQUEST']._serialized_end=6889
  _globals['_GETOUTPUTDCOFFSETRESPONSE']._serialized_start=6892
  _globals['_GETOUTPUTDCOFFSETRESPONSE']._serialized_end=7341
  _globals['_GETOUTPUTDCOFFSETRESPONSE_GETOUTPUTDCOFFSETRESPONSEERROR']._serialized_start=7099
  _globals['_GETOUTPUTDCOFFSETRESPONSE_GETOUTPUTDCOFFSETRESPONSEERROR']._serialized_end=7148
  _globals['_GETOUTPUTDCOFFSETRESPONSE_GETOUTPUTDCOFFSETRESPONSESUCCESS']._serialized_start=7151
  _globals['_GETOUTPUTDCOFFSETRESPONSE_GETOUTPUTDCOFFSETRESPONSESUCCESS']._serialized_end=7323
  _globals['_MIXINPUTSDCOFFSET']._serialized_start=7343
  _globals['_MIXINPUTSDCOFFSET']._serialized_end=7406
  _globals['_SINGLEINPUTDCOFFSET']._serialized_start=7408
  _globals['_SINGLEINPUTDCOFFSET']._serialized_end=7445
  _globals['_JOBSERVICEGETCONFIGRESPONSE']._serialized_start=7448
  _globals['_JOBSERVICEGETCONFIGRESPONSE']._serialized_end=7589
  _globals['_JOBSERVICEGETJOBSTATUSRESPONSE']._serialized_start=7592
  _globals['_JOBSERVICEGETJOBSTATUSRESPONSE']._serialized_end=7985
  _globals['_JOBSERVICEGETJOBSTATUSRESPONSE_JOBSERVICEGETJOBSTATUSRESPONSEERROR']._serialized_start=7824
  _globals['_JOBSERVICEGETJOBSTATUSRESPONSE_JOBSERVICEGETJOBSTATUSRESPONSEERROR']._serialized_end=7878
  _globals['_JOBSERVICEGETJOBSTATUSRESPONSE_JOBSERVICEGETJOBSTATUSRESPONSESUCCESS']._serialized_start=7880
  _globals['_JOBSERVICEGETJOBSTATUSRESPONSE_JOBSERVICEGETJOBSTATUSRESPONSESUCCESS']._serialized_end=7967
  _globals['_JOBSERVICEPUSHTOINPUTSTREAMREQUEST']._serialized_start=7988
  _globals['_JOBSERVICEPUSHTOINPUTSTREAMREQUEST']._serialized_end=8277
  _globals['_PUSHTOINPUTSTREAMRESPONSE']._serialized_start=8280
  _globals['_PUSHTOINPUTSTREAMRESPONSE']._serialized_end=8590
  _globals['_PUSHTOINPUTSTREAMRESPONSE_PUSHTOINPUTSTREAMRESPONSESUCCESS']._serialized_start=8487
  _globals['_PUSHTOINPUTSTREAMRESPONSE_PUSHTOINPUTSTREAMRESPONSESUCCESS']._serialized_end=8521
  _globals['_PUSHTOINPUTSTREAMRESPONSE_PUSHTOINPUTSTREAMRESPONSEERROR']._serialized_start=8523
  _globals['_PUSHTOINPUTSTREAMRESPONSE_PUSHTOINPUTSTREAMRESPONSEERROR']._serialized_end=8572
  _globals['_GETJOBRESULTSCHEMAREQUEST']._serialized_start=8592
  _globals['_GETJOBRESULTSCHEMAREQUEST']._serialized_end=8635
  _globals['_GETJOBRESULTSCHEMARESPONSE']._serialized_start=8638
  _globals['_GETJOBRESULTSCHEMARESPONSE']._serialized_end=9152
  _globals['_GETJOBRESULTSCHEMARESPONSE_GETJOBRESULTSCHEMARESPONSESUCCESS']._serialized_start=8851
  _globals['_GETJOBRESULTSCHEMARESPONSE_GETJOBRESULTSCHEMARESPONSESUCCESS']._serialized_end=9082
  _globals['_GETJOBRESULTSCHEMARESPONSE_GETJOBRESULTSCHEMARESPONSESUCCESS_ITEM']._serialized_start=8982
  _globals['_GETJOBRESULTSCHEMARESPONSE_GETJOBRESULTSCHEMARESPONSESUCCESS_ITEM']._serialized_end=9082
  _globals['_GETJOBRESULTSCHEMARESPONSE_GETJOBRESULTSCHEMARESPONSEERROR']._serialized_start=9084
  _globals['_GETJOBRESULTSCHEMARESPONSE_GETJOBRESULTSCHEMARESPONSEERROR']._serialized_end=9134
  _globals['_GETJOBNAMEDRESULTHEADERREQUEST']._serialized_start=9154
  _globals['_GETJOBNAMEDRESULTHEADERREQUEST']._serialized_end=9244
  _globals['_GETJOBNAMEDRESULTSHEADERSREQUEST']._serialized_start=9247
  _globals['_GETJOBNAMEDRESULTSHEADERSREQUEST']._serialized_end=9419
  _globals['_GETJOBNAMEDRESULTSHEADERSREQUEST_OUTPUT']._serialized_start=9369
  _globals['_GETJOBNAMEDRESULTSHEADERSREQUEST_OUTPUT']._serialized_end=9419
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE']._serialized_start=9422
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE']._serialized_end=10026
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE_GETJOBNAMEDRESULTSHEADERSRESPONSESUCCESS']._serialized_start=9670
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE_GETJOBNAMEDRESULTSHEADERSRESPONSESUCCESS']._serialized_end=9949
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE_GETJOBNAMEDRESULTSHEADERSRESPONSESUCCESS_OUTPUTHEADER']._serialized_start=9832
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE_GETJOBNAMEDRESULTSHEADERSRESPONSESUCCESS_OUTPUTHEADER']._serialized_end=9949
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE_GETJOBNAMEDRESULTSHEADERSRESPONSEERROR']._serialized_start=9951
  _globals['_GETJOBNAMEDRESULTSHEADERSRESPONSE_GETJOBNAMEDRESULTSHEADERSRESPONSEERROR']._serialized_end=10008
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE']._serialized_start=10029
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE']._serialized_end=10504
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE_GETJOBNAMEDRESULTHEADERRESPONSEERROR']._serialized_start=10266
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE_GETJOBNAMEDRESULTHEADERRESPONSEERROR']._serialized_end=10321
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE_GETJOBNAMEDRESULTHEADERRESPONSESUCCESS']._serialized_start=10324
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE_GETJOBNAMEDRESULTHEADERRESPONSESUCCESS']._serialized_end=10486
  _globals['_GETNAMEDRESULTSREQUEST']._serialized_start=10507
  _globals['_GETNAMEDRESULTSREQUEST']._serialized_end=10672
  _globals['_GETNAMEDRESULTSREQUEST_OUTPUT']._serialized_start=10609
  _globals['_GETNAMEDRESULTSREQUEST_OUTPUT']._serialized_end=10672
  _globals['_GETNAMEDRESULTREQUEST']._serialized_start=10674
  _globals['_GETNAMEDRESULTREQUEST']._serialized_end=10799
  _globals['_GETNAMEDRESULTRESPONSE']._serialized_start=10802
  _globals['_GETNAMEDRESULTRESPONSE']._serialized_end=11430
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSEERROR']._serialized_start=10994
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSEERROR']._serialized_end=11040
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS']._serialized_start=11043
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS']._serialized_end=11412
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS_DATACHUNK']._serialized_start=11343
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS_DATACHUNK']._serialized_end=11368
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS_DATASUMMARY']._serialized_start=11370
  _globals['_GETNAMEDRESULTRESPONSE_GETNAMEDRESULTRESPONSESUCCESS_DATASUMMARY']._serialized_end=11398
  _globals['_GETJOBERRORSREQUEST']._serialized_start=11432
  _globals['_GETJOBERRORSREQUEST']._serialized_end=11469
  _globals['_GETJOBERRORSRESPONSE']._serialized_start=11472
  _globals['_GETJOBERRORSRESPONSE']._serialized_end=12036
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSEERROR']._serialized_start=11654
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSEERROR']._serialized_end=11698
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSESUCCESS']._serialized_start=11701
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSESUCCESS']._serialized_end=12018
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSESUCCESS_ERROR']._serialized_start=11817
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSESUCCESS_ERROR']._serialized_end=11968
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSESUCCESS_EXECUTIONERRORSEVERITY']._serialized_start=11970
  _globals['_GETJOBERRORSRESPONSE_GETJOBERRORSRESPONSESUCCESS_EXECUTIONERRORSEVERITY']._serialized_end=12018
  _globals['_CANCELREQUEST']._serialized_start=12038
  _globals['_CANCELREQUEST']._serialized_end=12069
  _globals['_CANCELRESPONSE']._serialized_start=12072
  _globals['_CANCELRESPONSE']._serialized_end=12285
  _globals['_CANCELRESPONSE_CANCELJOBERROR']._serialized_start=12214
  _globals['_CANCELRESPONSE_CANCELJOBERROR']._serialized_end=12247
  _globals['_CANCELRESPONSE_CANCELJOBSUCCESS']._serialized_start=12249
  _globals['_CANCELRESPONSE_CANCELJOBSUCCESS']._serialized_end=12267
  _globals['_GETJOBRESULTSTATEREQUEST']._serialized_start=12287
  _globals['_GETJOBRESULTSTATEREQUEST']._serialized_end=12329
  _globals['_GETJOBRESULTSTATERESPONSE']._serialized_start=12332
  _globals['_GETJOBRESULTSTATERESPONSE']._serialized_end=12694
  _globals['_GETJOBRESULTSTATERESPONSE_GETJOBRESULTSTATERESPONSEERROR']._serialized_start=12539
  _globals['_GETJOBRESULTSTATERESPONSE_GETJOBRESULTSTATERESPONSEERROR']._serialized_end=12588
  _globals['_GETJOBRESULTSTATERESPONSE_GETJOBRESULTSTATERESPONSESUCCESS']._serialized_start=12590
  _globals['_GETJOBRESULTSTATERESPONSE_GETJOBRESULTSTATERESPONSESUCCESS']._serialized_end=12676
  _globals['_PULLSAMPLESREQUEST']._serialized_start=12696
  _globals['_PULLSAMPLESREQUEST']._serialized_end=12781
  _globals['_PULLSAMPLESRESPONSE']._serialized_start=12784
  _globals['_PULLSAMPLESRESPONSE']._serialized_end=13787
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSEERROR']._serialized_start=12961
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSEERROR']._serialized_end=13004
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS']._serialized_start=13007
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS']._serialized_end=13769
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_DOUBLEDATA']._serialized_start=13360
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_DOUBLEDATA']._serialized_end=13536
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_MW']._serialized_start=13538
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_MW']._serialized_end=13579
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_LF']._serialized_start=13581
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_LF']._serialized_end=13600
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_BOOLEANDATA']._serialized_start=13602
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_BOOLEANDATA']._serialized_end=13728
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_BOOLEANDATA_DATA']._serialized_start=13708
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_BOOLEANDATA_DATA']._serialized_end=13728
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_MODE']._serialized_start=13730
  _globals['_PULLSAMPLESRESPONSE_PULLSAMPLESRESPONSESUCCESS_MODE']._serialized_end=13761
  _globals['_SETOSCILLATORFREQUENCYREQUEST']._serialized_start=13790
  _globals['_SETOSCILLATORFREQUENCYREQUEST']._serialized_end=14043
  _globals['_SETOSCILLATORFREQUENCYREQUEST_UPDATECOMPONENTSELECTION']._serialized_start=13971
  _globals['_SETOSCILLATORFREQUENCYREQUEST_UPDATECOMPONENTSELECTION']._serialized_end=14043
  _globals['_SETOSCILLATORFREQUENCYRESPONSE']._serialized_start=14046
  _globals['_SETOSCILLATORFREQUENCYRESPONSE']._serialized_end=14371
  _globals['_SETOSCILLATORFREQUENCYRESPONSE_CHANGEOSCILLATORFREQUENCYERROR']._serialized_start=14268
  _globals['_SETOSCILLATORFREQUENCYRESPONSE_CHANGEOSCILLATORFREQUENCYERROR']._serialized_end=14317
  _globals['_SETOSCILLATORFREQUENCYRESPONSE_CHANGEOSCILLATORFREQUENCYSUCCESS']._serialized_start=14319
  _globals['_SETOSCILLATORFREQUENCYRESPONSE_CHANGEOSCILLATORFREQUENCYSUCCESS']._serialized_end=14353
  _globals['_GETWAVEFORMREPORTREQUEST']._serialized_start=14373
  _globals['_GETWAVEFORMREPORTREQUEST']._serialized_end=14415
  _globals['_GETWAVEFORMREPORTRESPONSE']._serialized_start=14418
  _globals['_GETWAVEFORMREPORTRESPONSE']._serialized_end=14745
  _globals['_GETWAVEFORMREPORTRESPONSE_GETWAVEFORMREPORTSUCCESS']._serialized_start=14609
  _globals['_GETWAVEFORMREPORTRESPONSE_GETWAVEFORMREPORTSUCCESS']._serialized_end=14684
  _globals['_GETWAVEFORMREPORTRESPONSE_GETWAVEFORMREPORTERROR']._serialized_start=14686
  _globals['_GETWAVEFORMREPORTRESPONSE_GETWAVEFORMREPORTERROR']._serialized_end=14727
  _globals['_JOBSERVICE']._serialized_start=14748
  _globals['_JOBSERVICE']._serialized_end=17810
# @@protoc_insertion_point(module_scope)
