# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/errors.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/errors.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12qm/pb/errors.proto\x12\x0eqm.grpc.errors*\xa7\x02\n\x14JobManagerErrorTypes\x12\x1e\n\x1aJobManagerUnspecifiedError\x10\x00\x12\x14\n\x0fMissingJobError\x10\xe8\x07\x12#\n\x1eInvalidJobExecutionStatusError\x10\xe9\x07\x12(\n#InvalidOperationOnSimulatorJobError\x10\xea\x07\x12#\n\x1eInvalidOperationOnRealJobError\x10\xeb\x07\x12\x1e\n\x19JobOperationSpecificError\x10\xec\x07\x12\x15\n\x10\x43onfigQueryError\x10\xed\x07\x12\x1c\n\x17UnknownInputStreamError\x10\xee\x07\"\x05\x08\x01\x10\xe7\x07\"\t\x08\xd0\x0f\x10\xff\xff\xff\xff\x07*\xba\x02\n\x1eJobOperationSpecificErrorTypes\x12 \n\x1cJobOperationUnspecifiedError\x10\x00\x12\x1c\n\x17SingleInputElementError\x10\xb8\x17\x12!\n\x1cInvalidCorrectionMatrixError\x10\xb9\x17\x12-\n(ElementWithoutIntermediateFrequencyError\x10\xba\x17\x12&\n!InvalidDigitalInputThresholdError\x10\xbb\x17\x12%\n InvalidDigitalInputDeadtimeError\x10\xbc\x17\x12%\n InvalidDigitalInputPolarityError\x10\xbd\x17\"\x05\x08\x01\x10\xb7\x17\"\t\x08\xa0\x1f\x10\xff\xff\xff\xff\x07*\xa0\x01\n\x15\x43onfigQueryErrorTypes\x12\x1f\n\x1b\x43onfigQueryUnspecifiedError\x10\x00\x12\x1b\n\x16MissingControllerError\x10\xa0\x1f\x12\x18\n\x13MissingElementError\x10\xa1\x1f\x12\x1d\n\x18MissingDigitalInputError\x10\xa2\x1f\"\x05\x08\x01\x10\x9f\x1f\"\t\x08\x88\'\x10\xff\xff\xff\xff\x07\x42%\n\x0eqm.grpc.errorsB\x0b\x45rrorsProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.errors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016qm.grpc.errorsB\013ErrorsProtoP\001\242\002\003HLW'
  _globals['_JOBMANAGERERRORTYPES']._serialized_start=39
  _globals['_JOBMANAGERERRORTYPES']._serialized_end=334
  _globals['_JOBOPERATIONSPECIFICERRORTYPES']._serialized_start=337
  _globals['_JOBOPERATIONSPECIFICERRORTYPES']._serialized_end=651
  _globals['_CONFIGQUERYERRORTYPES']._serialized_start=654
  _globals['_CONFIGQUERYERRORTYPES']._serialized_end=814
# @@protoc_insertion_point(module_scope)
