# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/general_messages.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/general_messages.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cqm/pb/general_messages.proto\x12\x18qm.grpc.general_messages\"-\n\x0c\x45rrorMessage\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"<\n\x06Matrix\x12\x0b\n\x03v00\x18\x01 \x01(\x01\x12\x0b\n\x03v01\x18\x02 \x01(\x01\x12\x0b\n\x03v10\x18\x03 \x01(\x01\x12\x0b\n\x03v11\x18\x04 \x01(\x01*Z\n\x0cMessageLevel\x12\x17\n\x13Message_LEVEL_ERROR\x10\x00\x12\x19\n\x15Message_LEVEL_WARNING\x10\x01\x12\x16\n\x12Message_LEVEL_INFO\x10\x02\x42\x37\n\x17qm.grpc.generalMessagesB\x14GeneralMessagesProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.general_messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027qm.grpc.generalMessagesB\024GeneralMessagesProtoP\001\242\002\003HLW'
  _globals['_MESSAGELEVEL']._serialized_start=167
  _globals['_MESSAGELEVEL']._serialized_end=257
  _globals['_ERRORMESSAGE']._serialized_start=58
  _globals['_ERRORMESSAGE']._serialized_end=103
  _globals['_MATRIX']._serialized_start=105
  _globals['_MATRIX']._serialized_end=165
# @@protoc_insertion_point(module_scope)
