# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/job_manager.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/job_manager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.grpc.qm.pb import errors_pb2 as qm_dot_pb_dot_errors__pb2
from qm.grpc.qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17qm/pb/job_manager.proto\x12\x13qm.grpc.job_manager\x1a\x12qm/pb/errors.proto\x1a\x1cqm/pb/general_messages.proto\"v\n\x1bGetElementCorrectionRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x0e\n\x06qeName\x18\x02 \x01(\t\x12\x38\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.MatrixB\x02\x18\x01\"\xa5\x01\n\x1cGetElementCorrectionResponse\x12O\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32-.qm.grpc.job_manager.JobManagerResponseHeader\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"r\n\x1bSetElementCorrectionRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x0e\n\x06qeName\x18\x02 \x01(\t\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xa5\x01\n\x1cSetElementCorrectionResponse\x12O\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32-.qm.grpc.job_manager.JobManagerResponseHeader\x12\x34\n\ncorrection\x18\x02 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xbc\x01\n\x18JobManagerResponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x41\n\x13jobManagerErrorType\x18\n \x01(\x0e\x32$.qm.grpc.errors.JobManagerErrorTypes\x12=\n\x0fjobErrorDetails\x18\x0b \x01(\x0b\x32$.qm.grpc.job_manager.JobErrorDetails\"\xcf\x01\n\x0fJobErrorDetails\x12W\n\x1djobOperationSpecificErrorType\x18\x01 \x01(\x0e\x32..qm.grpc.errors.JobOperationSpecificErrorTypesH\x00\x12\x45\n\x14\x63onfigQueryErrorType\x18\x02 \x01(\x0e\x32%.qm.grpc.errors.ConfigQueryErrorTypesH\x00\x12\x0f\n\x07message\x18\n \x01(\tB\x0b\n\terrorType\"j\n\x19JobOperationSpecificError\x12<\n\x04type\x18\x01 \x01(\x0e\x32..qm.grpc.errors.JobOperationSpecificErrorTypes\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x8f\x02\n\x18InsertInputStreamRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\nstreamName\x18\x02 \x01(\t\x12;\n\rintStreamData\x18\x03 \x01(\x0b\x32\".qm.grpc.job_manager.IntStreamDataH\x00\x12?\n\x0f\x66ixedStreamData\x18\x04 \x01(\x0b\x32$.qm.grpc.job_manager.FixedStreamDataH\x00\x12=\n\x0e\x62oolStreamData\x18\x05 \x01(\x0b\x32#.qm.grpc.job_manager.BoolStreamDataH\x00\x42\x13\n\x11stream_data_oneof\"\x91\x02\n ChangeOscillatorFrequencyRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x13\n\x0b\x65lementName\x18\x02 \x01(\t\x12\x16\n\x0enewFrequencyHz\x18\x03 \x01(\x01\x12g\n\x0fupdateComponent\x18\x04 \x01(\x0e\x32N.qm.grpc.job_manager.ChangeOscillatorFrequencyRequest.UpdateComponentSelection\"H\n\x18UpdateComponentSelection\x12\x08\n\x04\x62oth\x10\x00\x12\x0f\n\x0bupconverter\x10\x01\x12\x11\n\rdownconverter\x10\x02\"t\n!ChangeOscillatorFrequencyResponse\x12O\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32-.qm.grpc.job_manager.JobManagerResponseHeader\"\x1d\n\rIntStreamData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"\x1f\n\x0f\x46ixedStreamData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"\x1e\n\x0e\x42oolStreamData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x08\"l\n\x19InsertInputStreamResponse\x12O\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32-.qm.grpc.job_manager.JobManagerResponseHeader2\x96\x04\n\x11JobManagerService\x12}\n\x14GetElementCorrection\x12\x30.qm.grpc.job_manager.GetElementCorrectionRequest\x1a\x31.qm.grpc.job_manager.GetElementCorrectionResponse\"\x00\x12}\n\x14SetElementCorrection\x12\x30.qm.grpc.job_manager.SetElementCorrectionRequest\x1a\x31.qm.grpc.job_manager.SetElementCorrectionResponse\"\x00\x12t\n\x11InsertInputStream\x12-.qm.grpc.job_manager.InsertInputStreamRequest\x1a..qm.grpc.job_manager.InsertInputStreamResponse\"\x00\x12\x8c\x01\n\x19UpdateOscillatorFrequency\x12\x35.qm.grpc.job_manager.ChangeOscillatorFrequencyRequest\x1a\x36.qm.grpc.job_manager.ChangeOscillatorFrequencyResponse\"\x00\x42\x34\n\x12qm.grpc.jobManagerB\x16JobManagerServiceProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.job_manager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022qm.grpc.jobManagerB\026JobManagerServiceProtoP\001\242\002\003HLW'
  _globals['_GETELEMENTCORRECTIONREQUEST'].fields_by_name['correction']._loaded_options = None
  _globals['_GETELEMENTCORRECTIONREQUEST'].fields_by_name['correction']._serialized_options = b'\030\001'
  _globals['_GETELEMENTCORRECTIONREQUEST']._serialized_start=98
  _globals['_GETELEMENTCORRECTIONREQUEST']._serialized_end=216
  _globals['_GETELEMENTCORRECTIONRESPONSE']._serialized_start=219
  _globals['_GETELEMENTCORRECTIONRESPONSE']._serialized_end=384
  _globals['_SETELEMENTCORRECTIONREQUEST']._serialized_start=386
  _globals['_SETELEMENTCORRECTIONREQUEST']._serialized_end=500
  _globals['_SETELEMENTCORRECTIONRESPONSE']._serialized_start=503
  _globals['_SETELEMENTCORRECTIONRESPONSE']._serialized_end=668
  _globals['_JOBMANAGERRESPONSEHEADER']._serialized_start=671
  _globals['_JOBMANAGERRESPONSEHEADER']._serialized_end=859
  _globals['_JOBERRORDETAILS']._serialized_start=862
  _globals['_JOBERRORDETAILS']._serialized_end=1069
  _globals['_JOBOPERATIONSPECIFICERROR']._serialized_start=1071
  _globals['_JOBOPERATIONSPECIFICERROR']._serialized_end=1177
  _globals['_INSERTINPUTSTREAMREQUEST']._serialized_start=1180
  _globals['_INSERTINPUTSTREAMREQUEST']._serialized_end=1451
  _globals['_CHANGEOSCILLATORFREQUENCYREQUEST']._serialized_start=1454
  _globals['_CHANGEOSCILLATORFREQUENCYREQUEST']._serialized_end=1727
  _globals['_CHANGEOSCILLATORFREQUENCYREQUEST_UPDATECOMPONENTSELECTION']._serialized_start=1655
  _globals['_CHANGEOSCILLATORFREQUENCYREQUEST_UPDATECOMPONENTSELECTION']._serialized_end=1727
  _globals['_CHANGEOSCILLATORFREQUENCYRESPONSE']._serialized_start=1729
  _globals['_CHANGEOSCILLATORFREQUENCYRESPONSE']._serialized_end=1845
  _globals['_INTSTREAMDATA']._serialized_start=1847
  _globals['_INTSTREAMDATA']._serialized_end=1876
  _globals['_FIXEDSTREAMDATA']._serialized_start=1878
  _globals['_FIXEDSTREAMDATA']._serialized_end=1909
  _globals['_BOOLSTREAMDATA']._serialized_start=1911
  _globals['_BOOLSTREAMDATA']._serialized_end=1941
  _globals['_INSERTINPUTSTREAMRESPONSE']._serialized_start=1943
  _globals['_INSERTINPUTSTREAMRESPONSE']._serialized_end=2051
  _globals['_JOBMANAGERSERVICE']._serialized_start=2054
  _globals['_JOBMANAGERSERVICE']._serialized_end=2588
# @@protoc_insertion_point(module_scope)
