# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/grpc/v2/qmm_api.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/grpc/v2/qmm_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from qm.grpc.qm.grpc.v2 import common_types_pb2 as qm_dot_grpc_dot_v2_dot_common__types__pb2
from qm.grpc.qm.pb import compiler_pb2 as qm_dot_pb_dot_compiler__pb2
from qm.grpc.qm.pb import frontend_pb2 as qm_dot_pb_dot_frontend__pb2
from qm.grpc.qm.pb import inc_qua_pb2 as qm_dot_pb_dot_inc__qua__pb2
from qm.grpc.qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.grpc.qm.pb import qm_manager_pb2 as qm_dot_pb_dot_qm__manager__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qm/grpc/v2/qmm_api.proto\x12\nqm.grpc.v2\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dqm/grpc/v2/common_types.proto\x1a\x14qm/pb/compiler.proto\x1a\x14qm/pb/frontend.proto\x1a\x13qm/pb/inc_qua.proto\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x16qm/pb/qm_manager.proto\"\x13\n\x11GetVersionRequest\"&\n$QmmServiceResetDataProcessingRequest\"8\n\"QmmServiceGetQuantumMachineRequest\x12\x12\n\nmachine_id\x18\x01 \x01(\t\":\n$QmmServiceCloseQuantumMachineRequest\x12\x12\n\nmachine_id\x18\x01 \x01(\t\"\x14\n\x12HealthCheckRequest\"\x88\x05\n\x13HealthCheckResponse\x12M\n\x07success\x18\x01 \x01(\x0b\x32:.qm.grpc.v2.HealthCheckResponse.HealthCheckResponseSuccessH\x00\x12I\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x38.qm.grpc.v2.HealthCheckResponse.HealthCheckResponseErrorH\x00\x1a\x97\x03\n\x1aHealthCheckResponseSuccess\x12\n\n\x02ok\x18\x02 \x01(\x08\x12^\n\ncomponents\x18\x03 \x03(\x0b\x32J.qm.grpc.v2.HealthCheckResponse.HealthCheckResponseSuccess.ComponentsEntry\x12X\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32G.qm.grpc.v2.HealthCheckResponse.HealthCheckResponseSuccess.DetailsEntry\x1am\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.qm.grpc.v2.HealthCheckResponse.HealthCheckResponseSuccess:\x02\x38\x01\x1a\x44\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x1a+\n\x18HealthCheckResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\xe6\x01\n\x19OpenQuantumMachineRequest\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x43\n\nclose_mode\x18\x02 \x01(\x0e\x32/.qm.grpc.v2.OpenQuantumMachineRequest.CloseMode\"U\n\tCloseMode\x12\x1a\n\x16\x43LOSE_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x43LOSE_MODE_IF_NEEDED\x10\x01\x12\x12\n\x0e\x43LOSE_MODE_ALL\x10\x02\"\xa8\x04\n\x1aOpenQuantumMachineResponse\x12[\n\x07success\x18\x01 \x01(\x0b\x32H.qm.grpc.v2.OpenQuantumMachineResponse.OpenQuantumMachineResponseSuccessH\x00\x12W\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x46.qm.grpc.v2.OpenQuantumMachineResponse.OpenQuantumMachineResponseErrorH\x00\x1a|\n!OpenQuantumMachineResponseSuccess\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12;\n\x10open_qm_warnings\x18\x02 \x03(\x0b\x32!.qm.grpc.qm_manager.OpenQmWarning\x1a\xc3\x01\n\x1fOpenQuantumMachineResponseError\x12M\n\x18\x63onfig_validation_errors\x18\x01 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessage\x12Q\n\x1aphysical_validation_errors\x18\x02 \x03(\x0b\x32-.qm.grpc.qm_manager.PhysicalValidationMessageB\x10\n\x0eresponse_oneof\"\xf9\x02\n\x19GetQuantumMachineResponse\x12Y\n\x07success\x18\x01 \x01(\x0b\x32\x46.qm.grpc.v2.GetQuantumMachineResponse.GetQuantumMachineResponseSuccessH\x00\x12U\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x44.qm.grpc.v2.GetQuantumMachineResponse.GetQuantumMachineResponseErrorH\x00\x1a\x65\n GetQuantumMachineResponseSuccess\x12\x12\n\nmachine_id\x18\x02 \x01(\t\x12-\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x1a\x31\n\x1eGetQuantumMachineResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\x17\n\x15GetControllersRequest\" \n\x1eListOpenQuantumMachinesRequest\"\xf5\x02\n\x1fListOpenQuantumMachinesResponse\x12\x65\n\x07success\x18\x01 \x01(\x0b\x32R.qm.grpc.v2.ListOpenQuantumMachinesResponse.ListOpenQuantumMachinesResponseSuccessH\x00\x12\x61\n\x05\x65rror\x18\x02 \x01(\x0b\x32P.qm.grpc.v2.ListOpenQuantumMachinesResponse.ListOpenQuantumMachinesResponseErrorH\x00\x1a=\n&ListOpenQuantumMachinesResponseSuccess\x12\x13\n\x0bmachine_ids\x18\x01 \x03(\t\x1a\x37\n$ListOpenQuantumMachinesResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\" \n\x1e\x43loseAllQuantumMachinesRequest\"\x96\x01\n\x0fJobsQueryParams\x12\x1b\n\x13quantum_machine_ids\x18\x01 \x03(\t\x12\x0f\n\x07job_ids\x18\x02 \x03(\t\x12\x10\n\x08user_ids\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\x06status\x18\x05 \x03(\x0e\x32\x1e.qm.grpc.v2.JobExecutionStatus\"\xa8\x01\n\x0fJobResponseData\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12.\n\x06status\x18\x03 \x01(\x0e\x32\x1e.qm.grpc.v2.JobExecutionStatus\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.qm.grpc.v2.JobMetadata\x12\x15\n\ris_simulation\x18\x05 \x01(\x08\"\xa9\x01\n\x0bJobMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_status_updated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"<\n\x0eGetJobsRequest\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.qm.grpc.v2.JobsQueryParams\"}\n\x0fGetJobsResponse\x12-\n\x07success\x18\x01 \x01(\x0b\x32\x1a.qm.grpc.v2.GetJobsSuccessH\x00\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x18.qm.grpc.v2.GetJobsErrorH\x00\x42\x10\n\x0eresponse_oneof\"\x1f\n\x0cGetJobsError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\";\n\x0eGetJobsSuccess\x12)\n\x04jobs\x18\x02 \x03(\x0b\x32\x1b.qm.grpc.v2.JobResponseData\"\xe5\x08\n\x16GetControllersResponse\x12S\n\x07success\x18\x01 \x01(\x0b\x32@.qm.grpc.v2.GetControllersResponse.GetControllersResponseSuccessH\x00\x12O\n\x05\x65rror\x18\x02 \x01(\x0b\x32>.qm.grpc.v2.GetControllersResponse.GetControllersResponseErrorH\x00\x1a\xf4\x01\n\x1dGetControllersResponseSuccess\x12m\n\x0f\x63ontrol_devices\x18\x01 \x03(\x0b\x32T.qm.grpc.v2.GetControllersResponse.GetControllersResponseSuccess.ControlDevicesEntry\x1a\x64\n\x13\x43ontrolDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.qm.grpc.v2.GetControllersResponse.Controller:\x02\x38\x01\x1a.\n\x1bGetControllersResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x1a\x92\x03\n\nController\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12J\n\x0f\x63ontroller_type\x18\x02 \x01(\x0e\x32\x31.qm.grpc.v2.GetControllersResponse.ControllerType\x12\x45\n\x04\x66\x65ms\x18\x03 \x03(\x0b\x32\x37.qm.grpc.v2.GetControllersResponse.Controller.FemsEntry\x12U\n\x0ctemperatures\x18\x04 \x03(\x0b\x32?.qm.grpc.v2.GetControllersResponse.Controller.TemperaturesEntry\x1aS\n\tFemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.v2.GetControllersResponse.Fem:\x02\x38\x01\x1a\x33\n\x11TemperaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a?\n\x03\x46\x65m\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.qm.grpc.v2.GetControllersResponse.FemType\"E\n\x07\x46\x65mType\x12\x18\n\x14\x46\x45M_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46\x45M_TYPE_LF\x10\x01\x12\x0f\n\x0b\x46\x45M_TYPE_MW\x10\x02\"O\n\x0e\x43ontrollerType\x12\x1f\n\x1b\x43ONTROLLER_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONTROLLER_TYPE_OPX_1000\x10\x01\x42\x10\n\x0eresponse_oneof\"\xab\x03\n\x12GetVersionResponse\x12K\n\x07success\x18\x01 \x01(\x0b\x32\x38.qm.grpc.v2.GetVersionResponse.GetVersionResponseSuccessH\x00\x12G\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x36.qm.grpc.v2.GetVersionResponse.GetVersionResponseErrorH\x00\x1a\xc0\x01\n\x19GetVersionResponseSuccess\x12\x0f\n\x07gateway\x18\x02 \x01(\t\x12^\n\x0b\x63ontrollers\x18\x03 \x03(\x0b\x32I.qm.grpc.v2.GetVersionResponse.GetVersionResponseSuccess.ControllersEntry\x1a\x32\n\x10\x43ontrollersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a*\n\x17GetVersionResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\x84\x02\n\x19QmmServiceSimulateRequest\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x33\n\x12high_level_program\x18\x03 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12=\n\x08simulate\x18\x04 \x01(\x0b\x32+.qm.grpc.frontend.ExecutionRequest.Simulate\x12\x44\n\x16\x63ontroller_connections\x18\x05 \x03(\x0b\x32$.qm.grpc.frontend.InterOpxConnection\"\x8e\x01\n\x1aQmmServiceSimulateResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.v2.SimulationSuccessH\x00\x12,\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1b.qm.grpc.v2.SimulationErrorH\x00\x42\x10\n\x0eresponse_oneof\"\x98\x01\n\x11SimulationSuccess\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x33\n\x08messages\x18\x02 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12>\n\tsimulated\x18\x03 \x01(\x0b\x32\'.qm.grpc.frontend.SimulatedResponsePartB\x02\x18\x01\"\xf9\x01\n\x0fSimulationError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x12M\n\x18\x63onfig_validation_errors\x18\x02 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessage\x12Q\n\x1aphysical_validation_errors\x18\x03 \x03(\x0b\x32-.qm.grpc.qm_manager.PhysicalValidationMessage\x12\x33\n\x08messages\x18\x04 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\"\xc4\x02\n\x1bResetDataProcessingResponse\x12]\n\x07success\x18\x01 \x01(\x0b\x32J.qm.grpc.v2.ResetDataProcessingResponse.ResetDataProcessingResponseSuccessH\x00\x12Y\n\x05\x65rror\x18\x02 \x01(\x0b\x32H.qm.grpc.v2.ResetDataProcessingResponse.ResetDataProcessingResponseErrorH\x00\x1a$\n\"ResetDataProcessingResponseSuccess\x1a\x33\n ResetDataProcessingResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\xc4\x02\n\x1b\x43loseQuantumMachineResponse\x12]\n\x07success\x18\x01 \x01(\x0b\x32J.qm.grpc.v2.CloseQuantumMachineResponse.CloseQuantumMachineResponseSuccessH\x00\x12Y\n\x05\x65rror\x18\x02 \x01(\x0b\x32H.qm.grpc.v2.CloseQuantumMachineResponse.CloseQuantumMachineResponseErrorH\x00\x1a$\n\"CloseQuantumMachineResponseSuccess\x1a\x33\n CloseQuantumMachineResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\xe0\x02\n\x1f\x43loseAllQuantumMachinesResponse\x12\x65\n\x07success\x18\x01 \x01(\x0b\x32R.qm.grpc.v2.CloseAllQuantumMachinesResponse.CloseAllQuantumMachinesResponseSuccessH\x00\x12\x61\n\x05\x65rror\x18\x02 \x01(\x0b\x32P.qm.grpc.v2.CloseAllQuantumMachinesResponse.CloseAllQuantumMachinesResponseErrorH\x00\x1a(\n&CloseAllQuantumMachinesResponseSuccess\x1a\x37\n$CloseAllQuantumMachinesResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\x1b\n\x19\x43learAllJobResultsRequest\"\xbd\x02\n\x1a\x43learAllJobResultsResponse\x12[\n\x07success\x18\x01 \x01(\x0b\x32H.qm.grpc.v2.ClearAllJobResultsResponse.ClearAllJobResultsResponseSuccessH\x00\x12W\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x46.qm.grpc.v2.ClearAllJobResultsResponse.ClearAllJobResultsResponseErrorH\x00\x1a#\n!ClearAllJobResultsResponseSuccess\x1a\x32\n\x1f\x43learAllJobResultsResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof2\xc7\x08\n\nQmmService\x12M\n\nGetVersion\x12\x1d.qm.grpc.v2.GetVersionRequest\x1a\x1e.qm.grpc.v2.GetVersionResponse\"\x00\x12P\n\x0bHealthCheck\x12\x1e.qm.grpc.v2.HealthCheckRequest\x1a\x1f.qm.grpc.v2.HealthCheckResponse\"\x00\x12Y\n\x0eGetControllers\x12!.qm.grpc.v2.GetControllersRequest\x1a\".qm.grpc.v2.GetControllersResponse\"\x00\x12\x65\n\x12OpenQuantumMachine\x12%.qm.grpc.v2.OpenQuantumMachineRequest\x1a&.qm.grpc.v2.OpenQuantumMachineResponse\"\x00\x12l\n\x11GetQuantumMachine\x12..qm.grpc.v2.QmmServiceGetQuantumMachineRequest\x1a%.qm.grpc.v2.GetQuantumMachineResponse\"\x00\x12t\n\x17ListOpenQuantumMachines\x12*.qm.grpc.v2.ListOpenQuantumMachinesRequest\x1a+.qm.grpc.v2.ListOpenQuantumMachinesResponse\"\x00\x12t\n\x17\x43loseAllQuantumMachines\x12*.qm.grpc.v2.CloseAllQuantumMachinesRequest\x1a+.qm.grpc.v2.CloseAllQuantumMachinesResponse\"\x00\x12\x65\n\x12\x43learAllJobResults\x12%.qm.grpc.v2.ClearAllJobResultsRequest\x1a&.qm.grpc.v2.ClearAllJobResultsResponse\"\x00\x12\x44\n\x07GetJobs\x12\x1a.qm.grpc.v2.GetJobsRequest\x1a\x1b.qm.grpc.v2.GetJobsResponse\"\x00\x12r\n\x13ResetDataProcessing\x12\x30.qm.grpc.v2.QmmServiceResetDataProcessingRequest\x1a\'.qm.grpc.v2.ResetDataProcessingResponse\"\x00\x12[\n\x08Simulate\x12%.qm.grpc.v2.QmmServiceSimulateRequest\x1a&.qm.grpc.v2.QmmServiceSimulateResponse\"\x00\x42\x1a\n\x10qm.client.api.v2P\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.grpc.v2.qmm_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020qm.client.api.v2P\001\242\002\003HLW'
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_COMPONENTSENTRY']._loaded_options = None
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_DETAILSENTRY']._loaded_options = None
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSESUCCESS_CONTROLDEVICESENTRY']._loaded_options = None
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSESUCCESS_CONTROLDEVICESENTRY']._serialized_options = b'8\001'
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_FEMSENTRY']._loaded_options = None
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_FEMSENTRY']._serialized_options = b'8\001'
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_TEMPERATURESENTRY']._loaded_options = None
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_TEMPERATURESENTRY']._serialized_options = b'8\001'
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSESUCCESS_CONTROLLERSENTRY']._loaded_options = None
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSESUCCESS_CONTROLLERSENTRY']._serialized_options = b'8\001'
  _globals['_SIMULATIONSUCCESS'].fields_by_name['simulated']._loaded_options = None
  _globals['_SIMULATIONSUCCESS'].fields_by_name['simulated']._serialized_options = b'\030\001'
  _globals['_GETVERSIONREQUEST']._serialized_start=248
  _globals['_GETVERSIONREQUEST']._serialized_end=267
  _globals['_QMMSERVICERESETDATAPROCESSINGREQUEST']._serialized_start=269
  _globals['_QMMSERVICERESETDATAPROCESSINGREQUEST']._serialized_end=307
  _globals['_QMMSERVICEGETQUANTUMMACHINEREQUEST']._serialized_start=309
  _globals['_QMMSERVICEGETQUANTUMMACHINEREQUEST']._serialized_end=365
  _globals['_QMMSERVICECLOSEQUANTUMMACHINEREQUEST']._serialized_start=367
  _globals['_QMMSERVICECLOSEQUANTUMMACHINEREQUEST']._serialized_end=425
  _globals['_HEALTHCHECKREQUEST']._serialized_start=427
  _globals['_HEALTHCHECKREQUEST']._serialized_end=447
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=450
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=1098
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS']._serialized_start=628
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS']._serialized_end=1035
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_COMPONENTSENTRY']._serialized_start=856
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_COMPONENTSENTRY']._serialized_end=965
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_DETAILSENTRY']._serialized_start=967
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSESUCCESS_DETAILSENTRY']._serialized_end=1035
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSEERROR']._serialized_start=1037
  _globals['_HEALTHCHECKRESPONSE_HEALTHCHECKRESPONSEERROR']._serialized_end=1080
  _globals['_OPENQUANTUMMACHINEREQUEST']._serialized_start=1101
  _globals['_OPENQUANTUMMACHINEREQUEST']._serialized_end=1331
  _globals['_OPENQUANTUMMACHINEREQUEST_CLOSEMODE']._serialized_start=1246
  _globals['_OPENQUANTUMMACHINEREQUEST_CLOSEMODE']._serialized_end=1331
  _globals['_OPENQUANTUMMACHINERESPONSE']._serialized_start=1334
  _globals['_OPENQUANTUMMACHINERESPONSE']._serialized_end=1886
  _globals['_OPENQUANTUMMACHINERESPONSE_OPENQUANTUMMACHINERESPONSESUCCESS']._serialized_start=1546
  _globals['_OPENQUANTUMMACHINERESPONSE_OPENQUANTUMMACHINERESPONSESUCCESS']._serialized_end=1670
  _globals['_OPENQUANTUMMACHINERESPONSE_OPENQUANTUMMACHINERESPONSEERROR']._serialized_start=1673
  _globals['_OPENQUANTUMMACHINERESPONSE_OPENQUANTUMMACHINERESPONSEERROR']._serialized_end=1868
  _globals['_GETQUANTUMMACHINERESPONSE']._serialized_start=1889
  _globals['_GETQUANTUMMACHINERESPONSE']._serialized_end=2266
  _globals['_GETQUANTUMMACHINERESPONSE_GETQUANTUMMACHINERESPONSESUCCESS']._serialized_start=2096
  _globals['_GETQUANTUMMACHINERESPONSE_GETQUANTUMMACHINERESPONSESUCCESS']._serialized_end=2197
  _globals['_GETQUANTUMMACHINERESPONSE_GETQUANTUMMACHINERESPONSEERROR']._serialized_start=2199
  _globals['_GETQUANTUMMACHINERESPONSE_GETQUANTUMMACHINERESPONSEERROR']._serialized_end=2248
  _globals['_GETCONTROLLERSREQUEST']._serialized_start=2268
  _globals['_GETCONTROLLERSREQUEST']._serialized_end=2291
  _globals['_LISTOPENQUANTUMMACHINESREQUEST']._serialized_start=2293
  _globals['_LISTOPENQUANTUMMACHINESREQUEST']._serialized_end=2325
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE']._serialized_start=2328
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE']._serialized_end=2701
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE_LISTOPENQUANTUMMACHINESRESPONSESUCCESS']._serialized_start=2565
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE_LISTOPENQUANTUMMACHINESRESPONSESUCCESS']._serialized_end=2626
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE_LISTOPENQUANTUMMACHINESRESPONSEERROR']._serialized_start=2628
  _globals['_LISTOPENQUANTUMMACHINESRESPONSE_LISTOPENQUANTUMMACHINESRESPONSEERROR']._serialized_end=2683
  _globals['_CLOSEALLQUANTUMMACHINESREQUEST']._serialized_start=2703
  _globals['_CLOSEALLQUANTUMMACHINESREQUEST']._serialized_end=2735
  _globals['_JOBSQUERYPARAMS']._serialized_start=2738
  _globals['_JOBSQUERYPARAMS']._serialized_end=2888
  _globals['_JOBRESPONSEDATA']._serialized_start=2891
  _globals['_JOBRESPONSEDATA']._serialized_end=3059
  _globals['_JOBMETADATA']._serialized_start=3062
  _globals['_JOBMETADATA']._serialized_end=3231
  _globals['_GETJOBSREQUEST']._serialized_start=3233
  _globals['_GETJOBSREQUEST']._serialized_end=3293
  _globals['_GETJOBSRESPONSE']._serialized_start=3295
  _globals['_GETJOBSRESPONSE']._serialized_end=3420
  _globals['_GETJOBSERROR']._serialized_start=3422
  _globals['_GETJOBSERROR']._serialized_end=3453
  _globals['_GETJOBSSUCCESS']._serialized_start=3455
  _globals['_GETJOBSSUCCESS']._serialized_end=3514
  _globals['_GETCONTROLLERSRESPONSE']._serialized_start=3517
  _globals['_GETCONTROLLERSRESPONSE']._serialized_end=4642
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSESUCCESS']._serialized_start=3710
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSESUCCESS']._serialized_end=3954
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSESUCCESS_CONTROLDEVICESENTRY']._serialized_start=3854
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSESUCCESS_CONTROLDEVICESENTRY']._serialized_end=3954
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSEERROR']._serialized_start=3956
  _globals['_GETCONTROLLERSRESPONSE_GETCONTROLLERSRESPONSEERROR']._serialized_end=4002
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER']._serialized_start=4005
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER']._serialized_end=4407
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_FEMSENTRY']._serialized_start=4271
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_FEMSENTRY']._serialized_end=4354
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_TEMPERATURESENTRY']._serialized_start=4356
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLER_TEMPERATURESENTRY']._serialized_end=4407
  _globals['_GETCONTROLLERSRESPONSE_FEM']._serialized_start=4409
  _globals['_GETCONTROLLERSRESPONSE_FEM']._serialized_end=4472
  _globals['_GETCONTROLLERSRESPONSE_FEMTYPE']._serialized_start=4474
  _globals['_GETCONTROLLERSRESPONSE_FEMTYPE']._serialized_end=4543
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLERTYPE']._serialized_start=4545
  _globals['_GETCONTROLLERSRESPONSE_CONTROLLERTYPE']._serialized_end=4624
  _globals['_GETVERSIONRESPONSE']._serialized_start=4645
  _globals['_GETVERSIONRESPONSE']._serialized_end=5072
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSESUCCESS']._serialized_start=4818
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSESUCCESS']._serialized_end=5010
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSESUCCESS_CONTROLLERSENTRY']._serialized_start=4960
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSESUCCESS_CONTROLLERSENTRY']._serialized_end=5010
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSEERROR']._serialized_start=5012
  _globals['_GETVERSIONRESPONSE_GETVERSIONRESPONSEERROR']._serialized_end=5054
  _globals['_QMMSERVICESIMULATEREQUEST']._serialized_start=5075
  _globals['_QMMSERVICESIMULATEREQUEST']._serialized_end=5335
  _globals['_QMMSERVICESIMULATERESPONSE']._serialized_start=5338
  _globals['_QMMSERVICESIMULATERESPONSE']._serialized_end=5480
  _globals['_SIMULATIONSUCCESS']._serialized_start=5483
  _globals['_SIMULATIONSUCCESS']._serialized_end=5635
  _globals['_SIMULATIONERROR']._serialized_start=5638
  _globals['_SIMULATIONERROR']._serialized_end=5887
  _globals['_RESETDATAPROCESSINGRESPONSE']._serialized_start=5890
  _globals['_RESETDATAPROCESSINGRESPONSE']._serialized_end=6214
  _globals['_RESETDATAPROCESSINGRESPONSE_RESETDATAPROCESSINGRESPONSESUCCESS']._serialized_start=6107
  _globals['_RESETDATAPROCESSINGRESPONSE_RESETDATAPROCESSINGRESPONSESUCCESS']._serialized_end=6143
  _globals['_RESETDATAPROCESSINGRESPONSE_RESETDATAPROCESSINGRESPONSEERROR']._serialized_start=6145
  _globals['_RESETDATAPROCESSINGRESPONSE_RESETDATAPROCESSINGRESPONSEERROR']._serialized_end=6196
  _globals['_CLOSEQUANTUMMACHINERESPONSE']._serialized_start=6217
  _globals['_CLOSEQUANTUMMACHINERESPONSE']._serialized_end=6541
  _globals['_CLOSEQUANTUMMACHINERESPONSE_CLOSEQUANTUMMACHINERESPONSESUCCESS']._serialized_start=6434
  _globals['_CLOSEQUANTUMMACHINERESPONSE_CLOSEQUANTUMMACHINERESPONSESUCCESS']._serialized_end=6470
  _globals['_CLOSEQUANTUMMACHINERESPONSE_CLOSEQUANTUMMACHINERESPONSEERROR']._serialized_start=6472
  _globals['_CLOSEQUANTUMMACHINERESPONSE_CLOSEQUANTUMMACHINERESPONSEERROR']._serialized_end=6523
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE']._serialized_start=6544
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE']._serialized_end=6896
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE_CLOSEALLQUANTUMMACHINESRESPONSESUCCESS']._serialized_start=6781
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE_CLOSEALLQUANTUMMACHINESRESPONSESUCCESS']._serialized_end=6821
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE_CLOSEALLQUANTUMMACHINESRESPONSEERROR']._serialized_start=6823
  _globals['_CLOSEALLQUANTUMMACHINESRESPONSE_CLOSEALLQUANTUMMACHINESRESPONSEERROR']._serialized_end=6878
  _globals['_CLEARALLJOBRESULTSREQUEST']._serialized_start=6898
  _globals['_CLEARALLJOBRESULTSREQUEST']._serialized_end=6925
  _globals['_CLEARALLJOBRESULTSRESPONSE']._serialized_start=6928
  _globals['_CLEARALLJOBRESULTSRESPONSE']._serialized_end=7245
  _globals['_CLEARALLJOBRESULTSRESPONSE_CLEARALLJOBRESULTSRESPONSESUCCESS']._serialized_start=7140
  _globals['_CLEARALLJOBRESULTSRESPONSE_CLEARALLJOBRESULTSRESPONSESUCCESS']._serialized_end=7175
  _globals['_CLEARALLJOBRESULTSRESPONSE_CLEARALLJOBRESULTSRESPONSEERROR']._serialized_start=7177
  _globals['_CLEARALLJOBRESULTSRESPONSE_CLEARALLJOBRESULTSRESPONSEERROR']._serialized_end=7227
  _globals['_QMMSERVICE']._serialized_start=7248
  _globals['_QMMSERVICE']._serialized_end=8343
# @@protoc_insertion_point(module_scope)
