# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/frontend.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/frontend.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.grpc.qm.pb import inc_qua_pb2 as qm_dot_pb_dot_inc__qua__pb2
from qm.grpc.qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.grpc.qm.pb import inc_qm_api_pb2 as qm_dot_pb_dot_inc__qm__api__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from qm.grpc.qm.pb import compiler_pb2 as qm_dot_pb_dot_compiler__pb2
from qm.grpc.qm.pb import job_results_pb2 as qm_dot_pb_dot_job__results__pb2
from qm.grpc.qm.pb import qm_manager_pb2 as qm_dot_pb_dot_qm__manager__pb2
from qm.grpc.qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14qm/pb/frontend.proto\x12\x10qm.grpc.frontend\x1a\x13qm/pb/inc_qua.proto\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x16qm/pb/inc_qm_api.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14qm/pb/compiler.proto\x1a\x17qm/pb/job_results.proto\x1a\x16qm/pb/qm_manager.proto\x1a\x1cqm/pb/general_messages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\rQueuePosition\x12%\n\x03\x65nd\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\x05start\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\n\n\x08position\"\x98\x01\n\x11\x41\x64\x64ToQueueRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x31\n\x10highLevelProgram\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12\x36\n\rqueuePosition\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.QueuePosition\"d\n\x12\x41\x64\x64ToQueueResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x33\n\x08messages\x18\x03 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\"#\n\x10WaveformOverride\x12\x0f\n\x07samples\x18\x01 \x03(\x01\"\xb2\x01\n\x12\x45xecutionOverrides\x12\x46\n\twaveforms\x18\x01 \x03(\x0b\x32\x33.qm.grpc.frontend.ExecutionOverrides.WaveformsEntry\x1aT\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".qm.grpc.frontend.WaveformOverride:\x02\x38\x01\"\xc2\x01\n\x19\x41\x64\x64\x43ompiledToQueueRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x11\n\tprogramId\x18\x02 \x01(\t\x12\x36\n\rqueuePosition\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.QueuePosition\x12@\n\x12\x65xecutionOverrides\x18\x04 \x01(\x0b\x32$.qm.grpc.frontend.ExecutionOverrides\"o\n\x1a\x41\x64\x64\x43ompiledToQueueResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x36\n\x06\x65rrors\x18\x03 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\"]\n\x0e\x43ompileRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x31\n\x10highLevelProgram\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\"e\n\x0f\x43ompileResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x11\n\tprogramId\x18\x02 \x01(\t\x12\x33\n\x08messages\x18\x03 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\"G\n\x1cGetJobExecutionStatusRequest\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\r\n\x05jobId\x18\x02 \x01(\t\"U\n\x1dGetJobExecutionStatusResponse\x12\x34\n\x06status\x18\x01 \x01(\x0b\x32$.qm.grpc.frontend.JobExecutionStatus\"\xe0\n\n\x12JobExecutionStatus\x12?\n\x07unknown\x18\x01 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.UnknownH\x00\x12?\n\x07pending\x18\x02 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.PendingH\x00\x12?\n\x07running\x18\x03 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.RunningH\x00\x12\x43\n\tcompleted\x18\x04 \x01(\x0b\x32..qm.grpc.frontend.JobExecutionStatus.CompletedH\x00\x12\x41\n\x08\x63\x61nceled\x18\x05 \x01(\x0b\x32-.qm.grpc.frontend.JobExecutionStatus.CanceledH\x00\x12?\n\x07loading\x18\x06 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.LoadingH\x00\x12;\n\x05\x65rror\x18\x07 \x01(\x0b\x32*.qm.grpc.frontend.JobExecutionStatus.ErrorH\x00\x12\x45\n\nprocessing\x18\x08 \x01(\x0b\x32/.qm.grpc.frontend.JobExecutionStatus.ProcessingH\x00\x1a\t\n\x07Unknown\x1a\x62\n\x07Pending\x12\x17\n\x0fpositionInQueue\x18\x01 \x01(\x05\x12-\n\ttimeAdded\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x03 \x01(\t\x1az\n\x07Running\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12/\n\x0btimeStarted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xaf\x01\n\tCompleted\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12/\n\x0btimeStarted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rtimeCompleted\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a|\n\x08\x43\x61nceled\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12\x30\n\x0ctimeCanceled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x07Loading\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x1aK\n\x05\x45rror\x12\x31\n\rerrorMessages\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x1a}\n\nProcessing\x12-\n\ttimeAdded\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61\x64\x64\x65\x64\x42y\x18\x02 \x01(\t\x12/\n\x0btimeStarted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\n\x06status\"\xca\x01\n\x16GetPendingJobsResponse\x12N\n\x0bpendingJobs\x18\x01 \x03(\x0b\x32\x39.qm.grpc.frontend.GetPendingJobsResponse.PendingJobsEntry\x1a`\n\x10PendingJobsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.qm.grpc.frontend.JobExecutionStatus.Pending:\x02\x38\x01\"\xc3\x01\n\x0eJobQueryParams\x12\x18\n\x10quantumMachineId\x18\x01 \x01(\t\x12\x32\n\x05jobId\x18\x02 \x01(\x0b\x32#.qm.grpc.frontend.QueryValueMatcher\x12\x33\n\x06userId\x18\x03 \x01(\x0b\x32#.qm.grpc.frontend.QueryValueMatcher\x12.\n\x08position\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"@\n\x11QueryValueMatcher\x12\r\n\x03\x61ny\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05value\x18\x02 \x01(\tH\x00\x42\x0b\n\tvalueType\"9\n\x19RemovePendingJobsResponse\x12\x1c\n\x14numbersOfJobsRemoved\x18\x01 \x01(\x05\"\xf9\x01\n\x11SimulationRequest\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x31\n\x10highLevelProgram\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12=\n\x08simulate\x18\x03 \x01(\x0b\x32+.qm.grpc.frontend.ExecutionRequest.Simulate\x12\x43\n\x15\x63ontrollerConnections\x18\x06 \x03(\x0b\x32$.qm.grpc.frontend.InterOpxConnection\"3\n\x0fInterOpxAddress\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0c\n\x04left\x18\x02 \x01(\x08\"O\n\x0eInterOpxTarget\x12\x33\n\x06\x64irect\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddressH\x00\x42\x08\n\x06target\"<\n\x0fInterOpxChannel\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x15\n\rchannelNumber\x18\x02 \x01(\x05\"\xad\x04\n\x12InterOpxConnection\x12\x35\n\x06source\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddressB\x02\x18\x01\x12\x34\n\x06target\x18\x02 \x01(\x0b\x32 .qm.grpc.frontend.InterOpxTargetB\x02\x18\x01\x12Q\n\x10\x61\x64\x64ressToAddress\x18\x03 \x01(\x0b\x32\x35.qm.grpc.frontend.InterOpxConnection.AddressToAddressH\x00\x12Q\n\x10\x63hannelToChannel\x18\x04 \x01(\x0b\x32\x35.qm.grpc.frontend.InterOpxConnection.ChannelToChannelH\x00\x1ax\n\x10\x41\x64\x64ressToAddress\x12\x31\n\x06source\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddress\x12\x31\n\x06target\x18\x02 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxAddress\x1ax\n\x10\x43hannelToChannel\x12\x31\n\x06source\x18\x01 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxChannel\x12\x31\n\x06target\x18\x02 \x01(\x0b\x32!.qm.grpc.frontend.InterOpxChannelB\x10\n\x0e\x63onnectionType\"\xc3\x02\n\x12SimulationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12K\n\x16\x63onfigValidationErrors\x18\x03 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessage\x12O\n\x18physicalValidationErrors\x18\x04 \x03(\x0b\x32-.qm.grpc.qm_manager.PhysicalValidationMessage\x12\x33\n\x08messages\x18\x05 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12:\n\tsimulated\x18\x06 \x01(\x0b\x32\'.qm.grpc.frontend.SimulatedResponsePart\"$\n\x13IsJobRunningRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"8\n\x14IsJobRunningResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x11\n\tisRunning\x18\x02 \x01(\x08\"*\n\x19IsJobAcquiringDataRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\xdb\x01\n\x1aIsJobAcquiringDataResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12U\n\x0f\x61\x63quiringStatus\x18\x02 \x01(\x0e\x32<.qm.grpc.frontend.IsJobAcquiringDataResponse.AcquiringStatus\"W\n\x0f\x41\x63quiringStatus\x12\x13\n\x0f\x41\x43QUIRE_STOPPED\x10\x00\x12\x16\n\x12NO_DATA_TO_ACQUIRE\x10\x01\x12\x17\n\x13HAS_DATA_TO_ACQUIRE\x10\x02\"K\n\rQmDataRequest\x12:\n\x10io_value_Request\x18\x01 \x03(\x0b\x32 .qm.grpc.frontend.IOValueRequest\"\x99\x02\n\x0eQmDataResponse\x12K\n\x11io_value_response\x18\x01 \x03(\x0b\x32\x30.qm.grpc.frontend.QmDataResponse.IOValueResponse\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x03 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\x1aq\n\x0fIOValueResponse\x12\x31\n\x07request\x18\x01 \x01(\x0b\x32 .qm.grpc.frontend.IOValueRequest\x12+\n\x06values\x18\x02 \x01(\x0b\x32\x1b.qm.grpc.compiler.QuaValues\"\x80\x01\n\x0eIOValueRequest\x12\x19\n\rpulser_number\x18\x01 \x01(\rB\x02\x18\x01\x12\x11\n\tio_number\x18\x02 \x01(\r\x12\x0f\n\x05jobId\x18\x03 \x01(\tH\x00\x12\x1a\n\x10quantumMachineId\x18\x04 \x01(\tH\x00\x42\x13\n\x11identifier_one_of\"9\n\rResumeRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x19\n\rpulsersBitmap\x18\x02 \x01(\rB\x02\x18\x01\"\x10\n\x0eResumeResponse\"$\n\x13PausedStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"O\n\x14PausedStatusResponse\x12\x19\n\rpulsersBitmap\x18\x01 \x01(\rB\x02\x18\x01\x12\n\n\x02ok\x18\x02 \x01(\x08\x12\x10\n\x08isPaused\x18\x03 \x01(\x08\"\"\n\x11PullResultRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"=\n\x1aPullAnalysedResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\"\x94\x01\n\x12PullResultResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x11\n\tbytesLeft\x18\x03 \x01(\r\x12\x16\n\x0e\x63ontrollerName\x18\x04 \x01(\t\x12\x19\n\x11\x61pplicationNumber\x18\x05 \x01(\r\x12\x1a\n\x12implementationName\x18\x06 \x01(\t\"b\n\x13HealthCheckResponse\x12\x0f\n\x07message\x18\x01 \x03(\t\x12\n\n\x02ok\x18\x02 \x01(\x08\x12\x15\n\rerrorMessages\x18\x03 \x03(\t\x12\x17\n\x0fwarningMessages\x18\x04 \x03(\t\"\xec\x0b\n\x10\x45xecutionRequest\x12\x33\n\x10highLevelProgram\x18\x01 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgramH\x00\x12\x1d\n\x0flowLevelProgram\x18\x02 \x01(\x0c\x42\x02\x18\x01H\x00\x12\x1b\n\x13streamDurationLimit\x18\x03 \x01(\r\x12\x17\n\x0fstreamDataLimit\x18\x04 \x01(\r\x12\x16\n\x0e\x66orceExecution\x18\x05 \x01(\x08\x12=\n\x08simulate\x18\x06 \x01(\x0b\x32+.qm.grpc.frontend.ExecutionRequest.Simulate\x12\x0e\n\x06\x64ryRun\x18\x07 \x01(\x08\x12\x18\n\x10quantumMachineId\x18\x08 \x01(\t\x1a\xba\t\n\x08Simulate\x12\x10\n\x08\x64uration\x18\x01 \x01(\r\x12!\n\x15simulateAnalogOutputs\x18\x02 \x01(\x08\x42\x02\x18\x01\x12\"\n\x16simulateDigitalOutputs\x18\x03 \x01(\x08\x42\x02\x18\x01\x12 \n\x14includeAnalogSamples\x18\x04 \x01(\x08\x42\x02\x18\x01\x12!\n\x15includeDigitalSamples\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x16includeAnalogWaveforms\x18\x06 \x01(\x08\x12\x1f\n\x17includeDigitalWaveforms\x18\x07 \x01(\x08\x12\\\n\x13simulationInterface\x18\x08 \x01(\x0b\x32?.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface\x12 \n\x18\x65xtraProcessingTimeoutMs\x18\t \x01(\x05\x1a\xce\x06\n\x13SimulationInterface\x12T\n\x04none\x18\x01 \x01(\x0b\x32\x44.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.NoneH\x00\x12\\\n\x08loopback\x18\x02 \x01(\x0b\x32H.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.LoopbackH\x00\x12[\n\x03raw\x18\x04 \x01(\x0b\x32L.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterfaceH\x00\x1a\x06\n\x04None\x1a\x99\x02\n\x08Loopback\x12i\n\x0b\x63onnections\x18\x02 \x03(\x0b\x32T.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.Loopback.Connections\x12\x0f\n\x07latency\x18\x03 \x01(\r\x12\x12\n\nnoisePower\x18\x04 \x01(\x01\x1a}\n\x0b\x43onnections\x12\x16\n\x0e\x66romController\x18\x01 \x01(\t\x12\x0f\n\x07\x66romFem\x18\x05 \x01(\x05\x12\x10\n\x08\x66romPort\x18\x02 \x01(\x05\x12\x14\n\x0ctoController\x18\x03 \x01(\t\x12\r\n\x05toFem\x18\x06 \x01(\x05\x12\x0e\n\x06toPort\x18\x04 \x01(\x05\x1a\xee\x01\n\x0cRawInterface\x12m\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32X.qm.grpc.frontend.ExecutionRequest.Simulate.SimulationInterface.RawInterface.Connections\x12\x12\n\nnoisePower\x18\x02 \x01(\x01\x1a[\n\x0b\x43onnections\x12\x16\n\x0e\x66romController\x18\x01 \x01(\t\x12\x0f\n\x07\x66romFem\x18\x04 \x01(\x05\x12\x10\n\x08\x66romPort\x18\x02 \x01(\x05\x12\x11\n\ttoSamples\x18\x03 \x03(\x01\x42\x11\n\x0finterface_oneofB\x10\n\x0eprogram_one_of\"\xe0\x01\n\x11\x45xecutionResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x33\n\x08messages\x18\x03 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12:\n\tsimulated\x18\x06 \x01(\x0b\x32\'.qm.grpc.frontend.SimulatedResponsePart\x12-\n\x06\x63onfig\x18\x07 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\"\xc1\x01\n\x15SimulatedResponsePart\x12\x32\n\ranalogOutputs\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01\x12\x33\n\x0e\x64igitalOutputs\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01\x12/\n\x0ewaveformReport\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\"\x1c\n\x1aResetDataProcessingRequest\"\x1d\n\x1bResetDataProcessingResponse\"\x1c\n\x0bHaltRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\x1a\n\x0cHaltResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\"4\n\x0bPeekRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\r\x12\x14\n\x0c\x63ontrollerId\x18\x02 \x01(\t\"\x1d\n\x0cPeekResponse\x12\r\n\x05value\x18\x01 \x01(\r\"C\n\x0bPokeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x14\n\x0c\x63ontrollerId\x18\x03 \x01(\t\"\x1a\n\x0cPokeResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\"0\n\x1fGetSimulatedQuantumStateRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"m\n GetSimulatedQuantumStateResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\n\n\x02ok\x18\x02 \x01(\x08\x12.\n\x05state\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.DensityMatrix\"Q\n\rDensityMatrix\x12\x11\n\ttimeStamp\x18\x01 \x01(\x04\x12-\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x1f.qm.grpc.frontend.ComplexNumber\"\'\n\rComplexNumber\x12\n\n\x02re\x18\x01 \x01(\x01\x12\n\n\x02im\x18\x02 \x01(\x01\"H\n\x1dPerformHalDebugCommandRequest\x12\x16\n\x0e\x63ontrollerName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"C\n\x1ePerformHalDebugCommandResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08response\x18\x02 \x01(\t2\x80\x19\n\x08\x46rontend\x12\x44\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x1c.google.protobuf.StringValue\"\x00\x12N\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a%.qm.grpc.frontend.HealthCheckResponse\"\x00\x12T\n\x07\x45xecute\x12\".qm.grpc.frontend.ExecutionRequest\x1a#.qm.grpc.frontend.ExecutionResponse\"\x00\x12Y\n\nAddToQueue\x12#.qm.grpc.frontend.AddToQueueRequest\x1a$.qm.grpc.frontend.AddToQueueResponse\"\x00\x12P\n\x07\x43ompile\x12 .qm.grpc.frontend.CompileRequest\x1a!.qm.grpc.frontend.CompileResponse\"\x00\x12q\n\x12\x41\x64\x64\x43ompiledToQueue\x12+.qm.grpc.frontend.AddCompiledToQueueRequest\x1a,.qm.grpc.frontend.AddCompiledToQueueResponse\"\x00\x12\x64\n\x11RemovePendingJobs\x12 .qm.grpc.frontend.JobQueryParams\x1a+.qm.grpc.frontend.RemovePendingJobsResponse\"\x00\x12^\n\x0eGetPendingJobs\x12 .qm.grpc.frontend.JobQueryParams\x1a(.qm.grpc.frontend.GetPendingJobsResponse\"\x00\x12z\n\x15GetJobExecutionStatus\x12..qm.grpc.frontend.GetJobExecutionStatusRequest\x1a/.qm.grpc.frontend.GetJobExecutionStatusResponse\"\x00\x12z\n\x13GetJobStatusUpdates\x12..qm.grpc.frontend.GetJobExecutionStatusRequest\x1a/.qm.grpc.frontend.GetJobExecutionStatusResponse\"\x00\x30\x01\x12_\n\x0cPausedStatus\x12%.qm.grpc.frontend.PausedStatusRequest\x1a&.qm.grpc.frontend.PausedStatusResponse\"\x00\x12M\n\x06Resume\x12\x1f.qm.grpc.frontend.ResumeRequest\x1a .qm.grpc.frontend.ResumeResponse\"\x00\x12G\n\x04Halt\x12\x1d.qm.grpc.frontend.HaltRequest\x1a\x1e.qm.grpc.frontend.HaltResponse\"\x00\x12t\n\x13ResetDataProcessing\x12,.qm.grpc.frontend.ResetDataProcessingRequest\x1a-.qm.grpc.frontend.ResetDataProcessingResponse\"\x00\x12W\n\x0eValidateConfig\x12\x1d.qm.grpc.qua_config.QuaConfig\x1a$.qm.grpc.compiler.ValidationResponse\"\x00\x12\x38\n\x04Init\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x10PerformQmRequest\x12 .qm.grpc.qm_api.HighQmApiRequest\x1a!.qm.grpc.qm_api.HighQmApiResponse\"\x00\x12R\n\x0bRequestData\x12\x1f.qm.grpc.frontend.QmDataRequest\x1a .qm.grpc.frontend.QmDataResponse\"\x00\x12\x85\x01\n\x14PullSimulatorSamples\x12\x35.qm.grpc.results_analyser.PullSimulatorSamplesRequest\x1a\x32.qm.grpc.results_analyser.SimulatorSamplesResponse\"\x00\x30\x01\x12u\n\x12OpenQuantumMachine\x12-.qm.grpc.qm_manager.OpenQuantumMachineRequest\x1a..qm.grpc.qm_manager.OpenQuantumMachineResponse\"\x00\x12x\n\x13\x43loseQuantumMachine\x12..qm.grpc.qm_manager.CloseQuantumMachineRequest\x1a/.qm.grpc.qm_manager.CloseQuantumMachineResponse\"\x00\x12r\n\x11GetQuantumMachine\x12,.qm.grpc.qm_manager.GetQuantumMachineRequest\x1a-.qm.grpc.qm_manager.GetQuantumMachineResponse\"\x00\x12\x66\n\rGetRunningJob\x12(.qm.grpc.qm_manager.GetRunningJobRequest\x1a).qm.grpc.qm_manager.GetRunningJobResponse\"\x00\x12h\n\x17ListOpenQuantumMachines\x12\x16.google.protobuf.Empty\x1a\x33.qm.grpc.qm_manager.ListOpenQuantumMachinesResponse\"\x00\x12h\n\x17\x43loseAllQuantumMachines\x12\x16.google.protobuf.Empty\x1a\x33.qm.grpc.qm_manager.CloseAllQuantumMachinesResponse\"\x00\x12V\n\x0eGetControllers\x12\x16.google.protobuf.Empty\x1a*.qm.grpc.qm_manager.GetControllersResponse\"\x00\x12_\n\x0cIsJobRunning\x12%.qm.grpc.frontend.IsJobRunningRequest\x1a&.qm.grpc.frontend.IsJobRunningResponse\"\x00\x12q\n\x12IsJobAcquiringData\x12+.qm.grpc.frontend.IsJobAcquiringDataRequest\x1a,.qm.grpc.frontend.IsJobAcquiringDataResponse\"\x00\x12W\n\x08Simulate\x12#.qm.grpc.frontend.SimulationRequest\x1a$.qm.grpc.frontend.SimulationResponse\"\x00\x12\x46\n\x12\x43learAllJobResults\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12}\n\x16PerformHalDebugCommand\x12/.qm.grpc.frontend.PerformHalDebugCommandRequest\x1a\x30.qm.grpc.frontend.PerformHalDebugCommandResponse\"\x00\x12\x83\x01\n\x18GetSimulatedQuantumState\x12\x31.qm.grpc.frontend.GetSimulatedQuantumStateRequest\x1a\x32.qm.grpc.frontend.GetSimulatedQuantumStateResponse\"\x00\x42)\n\x10qm.grpc.frontendB\rFrontendProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.frontend_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020qm.grpc.frontendB\rFrontendProtoP\001\242\002\003HLW'
  _globals['_EXECUTIONOVERRIDES_WAVEFORMSENTRY']._loaded_options = None
  _globals['_EXECUTIONOVERRIDES_WAVEFORMSENTRY']._serialized_options = b'8\001'
  _globals['_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY']._loaded_options = None
  _globals['_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY']._serialized_options = b'8\001'
  _globals['_INTEROPXCONNECTION'].fields_by_name['source']._loaded_options = None
  _globals['_INTEROPXCONNECTION'].fields_by_name['source']._serialized_options = b'\030\001'
  _globals['_INTEROPXCONNECTION'].fields_by_name['target']._loaded_options = None
  _globals['_INTEROPXCONNECTION'].fields_by_name['target']._serialized_options = b'\030\001'
  _globals['_IOVALUEREQUEST'].fields_by_name['pulser_number']._loaded_options = None
  _globals['_IOVALUEREQUEST'].fields_by_name['pulser_number']._serialized_options = b'\030\001'
  _globals['_RESUMEREQUEST'].fields_by_name['pulsersBitmap']._loaded_options = None
  _globals['_RESUMEREQUEST'].fields_by_name['pulsersBitmap']._serialized_options = b'\030\001'
  _globals['_PAUSEDSTATUSRESPONSE'].fields_by_name['pulsersBitmap']._loaded_options = None
  _globals['_PAUSEDSTATUSRESPONSE'].fields_by_name['pulsersBitmap']._serialized_options = b'\030\001'
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['simulateAnalogOutputs']._loaded_options = None
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['simulateAnalogOutputs']._serialized_options = b'\030\001'
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['simulateDigitalOutputs']._loaded_options = None
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['simulateDigitalOutputs']._serialized_options = b'\030\001'
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['includeAnalogSamples']._loaded_options = None
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['includeAnalogSamples']._serialized_options = b'\030\001'
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['includeDigitalSamples']._loaded_options = None
  _globals['_EXECUTIONREQUEST_SIMULATE'].fields_by_name['includeDigitalSamples']._serialized_options = b'\030\001'
  _globals['_EXECUTIONREQUEST'].fields_by_name['lowLevelProgram']._loaded_options = None
  _globals['_EXECUTIONREQUEST'].fields_by_name['lowLevelProgram']._serialized_options = b'\030\001'
  _globals['_SIMULATEDRESPONSEPART'].fields_by_name['analogOutputs']._loaded_options = None
  _globals['_SIMULATEDRESPONSEPART'].fields_by_name['analogOutputs']._serialized_options = b'\030\001'
  _globals['_SIMULATEDRESPONSEPART'].fields_by_name['digitalOutputs']._loaded_options = None
  _globals['_SIMULATEDRESPONSEPART'].fields_by_name['digitalOutputs']._serialized_options = b'\030\001'
  _globals['_QUEUEPOSITION']._serialized_start=340
  _globals['_QUEUEPOSITION']._serialized_end=447
  _globals['_ADDTOQUEUEREQUEST']._serialized_start=450
  _globals['_ADDTOQUEUEREQUEST']._serialized_end=602
  _globals['_ADDTOQUEUERESPONSE']._serialized_start=604
  _globals['_ADDTOQUEUERESPONSE']._serialized_end=704
  _globals['_WAVEFORMOVERRIDE']._serialized_start=706
  _globals['_WAVEFORMOVERRIDE']._serialized_end=741
  _globals['_EXECUTIONOVERRIDES']._serialized_start=744
  _globals['_EXECUTIONOVERRIDES']._serialized_end=922
  _globals['_EXECUTIONOVERRIDES_WAVEFORMSENTRY']._serialized_start=838
  _globals['_EXECUTIONOVERRIDES_WAVEFORMSENTRY']._serialized_end=922
  _globals['_ADDCOMPILEDTOQUEUEREQUEST']._serialized_start=925
  _globals['_ADDCOMPILEDTOQUEUEREQUEST']._serialized_end=1119
  _globals['_ADDCOMPILEDTOQUEUERESPONSE']._serialized_start=1121
  _globals['_ADDCOMPILEDTOQUEUERESPONSE']._serialized_end=1232
  _globals['_COMPILEREQUEST']._serialized_start=1234
  _globals['_COMPILEREQUEST']._serialized_end=1327
  _globals['_COMPILERESPONSE']._serialized_start=1329
  _globals['_COMPILERESPONSE']._serialized_end=1430
  _globals['_GETJOBEXECUTIONSTATUSREQUEST']._serialized_start=1432
  _globals['_GETJOBEXECUTIONSTATUSREQUEST']._serialized_end=1503
  _globals['_GETJOBEXECUTIONSTATUSRESPONSE']._serialized_start=1505
  _globals['_GETJOBEXECUTIONSTATUSRESPONSE']._serialized_end=1590
  _globals['_JOBEXECUTIONSTATUS']._serialized_start=1593
  _globals['_JOBEXECUTIONSTATUS']._serialized_end=2969
  _globals['_JOBEXECUTIONSTATUS_UNKNOWN']._serialized_start=2143
  _globals['_JOBEXECUTIONSTATUS_UNKNOWN']._serialized_end=2152
  _globals['_JOBEXECUTIONSTATUS_PENDING']._serialized_start=2154
  _globals['_JOBEXECUTIONSTATUS_PENDING']._serialized_end=2252
  _globals['_JOBEXECUTIONSTATUS_RUNNING']._serialized_start=2254
  _globals['_JOBEXECUTIONSTATUS_RUNNING']._serialized_end=2376
  _globals['_JOBEXECUTIONSTATUS_COMPLETED']._serialized_start=2379
  _globals['_JOBEXECUTIONSTATUS_COMPLETED']._serialized_end=2554
  _globals['_JOBEXECUTIONSTATUS_CANCELED']._serialized_start=2556
  _globals['_JOBEXECUTIONSTATUS_CANCELED']._serialized_end=2680
  _globals['_JOBEXECUTIONSTATUS_LOADING']._serialized_start=2682
  _globals['_JOBEXECUTIONSTATUS_LOADING']._serialized_end=2755
  _globals['_JOBEXECUTIONSTATUS_ERROR']._serialized_start=2757
  _globals['_JOBEXECUTIONSTATUS_ERROR']._serialized_end=2832
  _globals['_JOBEXECUTIONSTATUS_PROCESSING']._serialized_start=2834
  _globals['_JOBEXECUTIONSTATUS_PROCESSING']._serialized_end=2959
  _globals['_GETPENDINGJOBSRESPONSE']._serialized_start=2972
  _globals['_GETPENDINGJOBSRESPONSE']._serialized_end=3174
  _globals['_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY']._serialized_start=3078
  _globals['_GETPENDINGJOBSRESPONSE_PENDINGJOBSENTRY']._serialized_end=3174
  _globals['_JOBQUERYPARAMS']._serialized_start=3177
  _globals['_JOBQUERYPARAMS']._serialized_end=3372
  _globals['_QUERYVALUEMATCHER']._serialized_start=3374
  _globals['_QUERYVALUEMATCHER']._serialized_end=3438
  _globals['_REMOVEPENDINGJOBSRESPONSE']._serialized_start=3440
  _globals['_REMOVEPENDINGJOBSRESPONSE']._serialized_end=3497
  _globals['_SIMULATIONREQUEST']._serialized_start=3500
  _globals['_SIMULATIONREQUEST']._serialized_end=3749
  _globals['_INTEROPXADDRESS']._serialized_start=3751
  _globals['_INTEROPXADDRESS']._serialized_end=3802
  _globals['_INTEROPXTARGET']._serialized_start=3804
  _globals['_INTEROPXTARGET']._serialized_end=3883
  _globals['_INTEROPXCHANNEL']._serialized_start=3885
  _globals['_INTEROPXCHANNEL']._serialized_end=3945
  _globals['_INTEROPXCONNECTION']._serialized_start=3948
  _globals['_INTEROPXCONNECTION']._serialized_end=4505
  _globals['_INTEROPXCONNECTION_ADDRESSTOADDRESS']._serialized_start=4245
  _globals['_INTEROPXCONNECTION_ADDRESSTOADDRESS']._serialized_end=4365
  _globals['_INTEROPXCONNECTION_CHANNELTOCHANNEL']._serialized_start=4367
  _globals['_INTEROPXCONNECTION_CHANNELTOCHANNEL']._serialized_end=4487
  _globals['_SIMULATIONRESPONSE']._serialized_start=4508
  _globals['_SIMULATIONRESPONSE']._serialized_end=4831
  _globals['_ISJOBRUNNINGREQUEST']._serialized_start=4833
  _globals['_ISJOBRUNNINGREQUEST']._serialized_end=4869
  _globals['_ISJOBRUNNINGRESPONSE']._serialized_start=4871
  _globals['_ISJOBRUNNINGRESPONSE']._serialized_end=4927
  _globals['_ISJOBACQUIRINGDATAREQUEST']._serialized_start=4929
  _globals['_ISJOBACQUIRINGDATAREQUEST']._serialized_end=4971
  _globals['_ISJOBACQUIRINGDATARESPONSE']._serialized_start=4974
  _globals['_ISJOBACQUIRINGDATARESPONSE']._serialized_end=5193
  _globals['_ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS']._serialized_start=5106
  _globals['_ISJOBACQUIRINGDATARESPONSE_ACQUIRINGSTATUS']._serialized_end=5193
  _globals['_QMDATAREQUEST']._serialized_start=5195
  _globals['_QMDATAREQUEST']._serialized_end=5270
  _globals['_QMDATARESPONSE']._serialized_start=5273
  _globals['_QMDATARESPONSE']._serialized_end=5554
  _globals['_QMDATARESPONSE_IOVALUERESPONSE']._serialized_start=5441
  _globals['_QMDATARESPONSE_IOVALUERESPONSE']._serialized_end=5554
  _globals['_IOVALUEREQUEST']._serialized_start=5557
  _globals['_IOVALUEREQUEST']._serialized_end=5685
  _globals['_RESUMEREQUEST']._serialized_start=5687
  _globals['_RESUMEREQUEST']._serialized_end=5744
  _globals['_RESUMERESPONSE']._serialized_start=5746
  _globals['_RESUMERESPONSE']._serialized_end=5762
  _globals['_PAUSEDSTATUSREQUEST']._serialized_start=5764
  _globals['_PAUSEDSTATUSREQUEST']._serialized_end=5800
  _globals['_PAUSEDSTATUSRESPONSE']._serialized_start=5802
  _globals['_PAUSEDSTATUSRESPONSE']._serialized_end=5881
  _globals['_PULLRESULTREQUEST']._serialized_start=5883
  _globals['_PULLRESULTREQUEST']._serialized_end=5917
  _globals['_PULLANALYSEDRESULTSREQUEST']._serialized_start=5919
  _globals['_PULLANALYSEDRESULTSREQUEST']._serialized_end=5980
  _globals['_PULLRESULTRESPONSE']._serialized_start=5983
  _globals['_PULLRESULTRESPONSE']._serialized_end=6131
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=6133
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=6231
  _globals['_EXECUTIONREQUEST']._serialized_start=6234
  _globals['_EXECUTIONREQUEST']._serialized_end=7750
  _globals['_EXECUTIONREQUEST_SIMULATE']._serialized_start=6522
  _globals['_EXECUTIONREQUEST_SIMULATE']._serialized_end=7732
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE']._serialized_start=6886
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE']._serialized_end=7732
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE']._serialized_start=7182
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_NONE']._serialized_end=7188
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK']._serialized_start=7191
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK']._serialized_end=7472
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS']._serialized_start=7347
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_LOOPBACK_CONNECTIONS']._serialized_end=7472
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE']._serialized_start=7475
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE']._serialized_end=7713
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS']._serialized_start=7622
  _globals['_EXECUTIONREQUEST_SIMULATE_SIMULATIONINTERFACE_RAWINTERFACE_CONNECTIONS']._serialized_end=7713
  _globals['_EXECUTIONRESPONSE']._serialized_start=7753
  _globals['_EXECUTIONRESPONSE']._serialized_end=7977
  _globals['_SIMULATEDRESPONSEPART']._serialized_start=7980
  _globals['_SIMULATEDRESPONSEPART']._serialized_end=8173
  _globals['_RESETDATAPROCESSINGREQUEST']._serialized_start=8175
  _globals['_RESETDATAPROCESSINGREQUEST']._serialized_end=8203
  _globals['_RESETDATAPROCESSINGRESPONSE']._serialized_start=8205
  _globals['_RESETDATAPROCESSINGRESPONSE']._serialized_end=8234
  _globals['_HALTREQUEST']._serialized_start=8236
  _globals['_HALTREQUEST']._serialized_end=8264
  _globals['_HALTRESPONSE']._serialized_start=8266
  _globals['_HALTRESPONSE']._serialized_end=8292
  _globals['_PEEKREQUEST']._serialized_start=8294
  _globals['_PEEKREQUEST']._serialized_end=8346
  _globals['_PEEKRESPONSE']._serialized_start=8348
  _globals['_PEEKRESPONSE']._serialized_end=8377
  _globals['_POKEREQUEST']._serialized_start=8379
  _globals['_POKEREQUEST']._serialized_end=8446
  _globals['_POKERESPONSE']._serialized_start=8448
  _globals['_POKERESPONSE']._serialized_end=8474
  _globals['_GETSIMULATEDQUANTUMSTATEREQUEST']._serialized_start=8476
  _globals['_GETSIMULATEDQUANTUMSTATEREQUEST']._serialized_end=8524
  _globals['_GETSIMULATEDQUANTUMSTATERESPONSE']._serialized_start=8526
  _globals['_GETSIMULATEDQUANTUMSTATERESPONSE']._serialized_end=8635
  _globals['_DENSITYMATRIX']._serialized_start=8637
  _globals['_DENSITYMATRIX']._serialized_end=8718
  _globals['_COMPLEXNUMBER']._serialized_start=8720
  _globals['_COMPLEXNUMBER']._serialized_end=8759
  _globals['_PERFORMHALDEBUGCOMMANDREQUEST']._serialized_start=8761
  _globals['_PERFORMHALDEBUGCOMMANDREQUEST']._serialized_end=8833
  _globals['_PERFORMHALDEBUGCOMMANDRESPONSE']._serialized_start=8835
  _globals['_PERFORMHALDEBUGCOMMANDRESPONSE']._serialized_end=8902
  _globals['_FRONTEND']._serialized_start=8905
  _globals['_FRONTEND']._serialized_end=12105
# @@protoc_insertion_point(module_scope)
