# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/grpc/v2/qm_api.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/grpc/v2/qm_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.grpc.qm.grpc.v2 import common_types_pb2 as qm_dot_grpc_dot_v2_dot_common__types__pb2
from qm.grpc.qm.grpc.v2 import qmm_api_pb2 as qm_dot_grpc_dot_v2_dot_qmm__api__pb2
from qm.grpc.qm.pb import compiler_pb2 as qm_dot_pb_dot_compiler__pb2
from qm.grpc.qm.pb import frontend_pb2 as qm_dot_pb_dot_frontend__pb2
from qm.grpc.qm.pb import inc_qua_pb2 as qm_dot_pb_dot_inc__qua__pb2
from qm.grpc.qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.grpc.qm.pb import qm_manager_pb2 as qm_dot_pb_dot_qm__manager__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17qm/grpc/v2/qm_api.proto\x12\nqm.grpc.v2\x1a\x1dqm/grpc/v2/common_types.proto\x1a\x18qm/grpc/v2/qmm_api.proto\x1a\x14qm/pb/compiler.proto\x1a\x14qm/pb/frontend.proto\x1a\x13qm/pb/inc_qua.proto\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x16qm/pb/qm_manager.proto\"7\n\x19QmServiceGetConfigRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\"`\n\x13UpdateConfigRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\"\xe2\x02\n\x14UpdateConfigResponse\x12O\n\x07success\x18\x01 \x01(\x0b\x32<.qm.grpc.v2.UpdateConfigResponse.UpdateConfigResponseSuccessH\x00\x12K\n\x05\x65rror\x18\x02 \x01(\x0b\x32:.qm.grpc.v2.UpdateConfigResponse.UpdateConfigResponseErrorH\x00\x1a\x1d\n\x1bUpdateConfigResponseSuccess\x1a{\n\x19UpdateConfigResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x12M\n\x18\x63onfig_validation_errors\x18\x02 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessageB\x10\n\x0eresponse_oneof\"3\n\x15QmServiceCloseRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\"\xa1\x02\n\x16QmServiceCloseResponse\x12S\n\x07success\x18\x01 \x01(\x0b\x32@.qm.grpc.v2.QmServiceCloseResponse.QmServiceCloseResponseSuccessH\x00\x12O\n\x05\x65rror\x18\x02 \x01(\x0b\x32>.qm.grpc.v2.QmServiceCloseResponse.QmServiceCloseResponseErrorH\x00\x1a\x1f\n\x1dQmServiceCloseResponseSuccess\x1a.\n\x1bQmServiceCloseResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\xaf\x02\n\x18QmServiceSimulateRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12\x33\n\x12high_level_program\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12=\n\x08simulate\x18\x03 \x01(\x0b\x32+.qm.grpc.frontend.ExecutionRequest.Simulate\x12\x44\n\x16\x63ontroller_connections\x18\x04 \x03(\x0b\x32$.qm.grpc.frontend.InterOpxConnection\x12\x32\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"\x8d\x01\n\x19QmServiceSimulateResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.v2.SimulationSuccessH\x00\x12,\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1b.qm.grpc.v2.SimulationErrorH\x00\x42\x10\n\x0eresponse_oneof\"\x9e\x01\n\x18QmServiceJobsQueryParams\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12\x0f\n\x07job_ids\x18\x02 \x03(\t\x12\x10\n\x08user_ids\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\x06status\x18\x05 \x03(\x0e\x32\x1e.qm.grpc.v2.JobExecutionStatus\"E\n\x17QmServiceGetJobsRequest\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.qm.grpc.v2.JobsQueryParams\"?\n\x11RemoveJobsRequest\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.qm.grpc.v2.JobsQueryParams\"\x9e\x02\n\x12RemoveJobsResponse\x12K\n\x07success\x18\x01 \x01(\x0b\x32\x38.qm.grpc.v2.RemoveJobsResponse.RemoveJobsResponseSuccessH\x00\x12G\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x36.qm.grpc.v2.RemoveJobsResponse.RemoveJobsResponseErrorH\x00\x1a\x34\n\x19RemoveJobsResponseSuccess\x12\x17\n\x0fremoved_job_ids\x18\x01 \x03(\t\x1a*\n\x17RemoveJobsResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\x8c\x01\n\x1aQmServiceGetConfigResponse\x12/\n\x07success\x18\x01 \x01(\x0b\x32\x1c.qm.grpc.v2.GetConfigSuccessH\x00\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1a.qm.grpc.v2.GetConfigErrorH\x00\x42\x10\n\x0eresponse_oneof\"A\n\x10GetConfigSuccess\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\"!\n\x0eGetConfigError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\"\xa9\x01\n\x17QmServiceCompileRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12\x33\n\x12high_level_program\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12\x32\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"\xae\x03\n\x0f\x43ompileResponse\x12\x41\n\x07success\x18\x01 \x01(\x0b\x32..qm.grpc.v2.CompileResponse.CompilationSuccessH\x00\x12=\n\x05\x65rror\x18\x02 \x01(\x0b\x32,.qm.grpc.v2.CompileResponse.CompilationErrorH\x00\x1a]\n\x12\x43ompilationSuccess\x12\x12\n\nprogram_id\x18\x01 \x01(\t\x12\x33\n\x08messages\x18\x02 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x1a\xa7\x01\n\x10\x43ompilationError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x12\x33\n\x08messages\x18\x02 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12M\n\x18\x63onfig_validation_errors\x18\x03 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessageB\x10\n\x0eresponse_oneof\"\xe5\x01\n\x1aQmServiceAddToQueueRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12\x33\n\x12high_level_program\x18\x02 \x01(\x0b\x32\x17.qm.grpc.qua.QuaProgram\x12\x37\n\x0equeue_position\x18\x03 \x01(\x0b\x32\x1f.qm.grpc.frontend.QueuePosition\x12\x32\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"\xcf\x03\n\x12\x41\x64\x64ToQueueResponse\x12K\n\x07success\x18\x01 \x01(\x0b\x32\x38.qm.grpc.v2.AddToQueueResponse.AddToQueueResponseSuccessH\x00\x12G\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x36.qm.grpc.v2.AddToQueueResponse.AddToQueueResponseErrorH\x00\x1a`\n\x19\x41\x64\x64ToQueueResponseSuccess\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x33\n\x08messages\x18\x02 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x1a\xae\x01\n\x17\x41\x64\x64ToQueueResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\t\x12\x33\n\x08messages\x18\x02 \x03(\x0b\x32!.qm.grpc.compiler.CompilerMessage\x12M\n\x18\x63onfig_validation_errors\x18\x03 \x03(\x0b\x32+.qm.grpc.qm_manager.ConfigValidationMessageB\x10\n\x0eresponse_oneof\"T\n\"QmServiceAddCompiledToQueueRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\x12\x12\n\nprogram_id\x18\x02 \x01(\t\"\xcd\x02\n\x1a\x41\x64\x64\x43ompiledToQueueResponse\x12[\n\x07success\x18\x01 \x01(\x0b\x32H.qm.grpc.v2.AddCompiledToQueueResponse.AddCompiledToQueueResponseSuccessH\x00\x12W\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x46.qm.grpc.v2.AddCompiledToQueueResponse.AddCompiledToQueueResponseErrorH\x00\x1a\x33\n!AddCompiledToQueueResponseSuccess\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x1a\x32\n\x1f\x41\x64\x64\x43ompiledToQueueResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof\"\x86\x01\n\x18QmServiceGetJobsResponse\x12-\n\x07success\x18\x01 \x01(\x0b\x32\x1a.qm.grpc.v2.GetJobsSuccessH\x00\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x18.qm.grpc.v2.GetJobsErrorH\x00\x42\x10\n\x0eresponse_oneof\"8\n\x1aResetDigitalFiltersRequest\x12\x1a\n\x12quantum_machine_id\x18\x01 \x01(\t\"\xc4\x02\n\x1bResetDigitalFiltersResponse\x12]\n\x07success\x18\x01 \x01(\x0b\x32J.qm.grpc.v2.ResetDigitalFiltersResponse.ResetDigitalFiltersResponseSuccessH\x00\x12Y\n\x05\x65rror\x18\x02 \x01(\x0b\x32H.qm.grpc.v2.ResetDigitalFiltersResponse.ResetDigitalFiltersResponseErrorH\x00\x1a$\n\"ResetDigitalFiltersResponseSuccess\x1a\x33\n ResetDigitalFiltersResponseError\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x10\n\x0eresponse_oneof2\x93\x07\n\tQmService\x12S\n\x0cUpdateConfig\x12\x1f.qm.grpc.v2.UpdateConfigRequest\x1a .qm.grpc.v2.UpdateConfigResponse\"\x00\x12\\\n\tGetConfig\x12%.qm.grpc.v2.QmServiceGetConfigRequest\x1a&.qm.grpc.v2.QmServiceGetConfigResponse\"\x00\x12M\n\x07\x43ompile\x12#.qm.grpc.v2.QmServiceCompileRequest\x1a\x1b.qm.grpc.v2.CompileResponse\"\x00\x12P\n\x05\x43lose\x12!.qm.grpc.v2.QmServiceCloseRequest\x1a\".qm.grpc.v2.QmServiceCloseResponse\"\x00\x12V\n\nAddToQueue\x12&.qm.grpc.v2.QmServiceAddToQueueRequest\x1a\x1e.qm.grpc.v2.AddToQueueResponse\"\x00\x12n\n\x12\x41\x64\x64\x43ompiledToQueue\x12..qm.grpc.v2.QmServiceAddCompiledToQueueRequest\x1a&.qm.grpc.v2.AddCompiledToQueueResponse\"\x00\x12V\n\x07GetJobs\x12#.qm.grpc.v2.QmServiceGetJobsRequest\x1a$.qm.grpc.v2.QmServiceGetJobsResponse\"\x00\x12M\n\nRemoveJobs\x12\x1d.qm.grpc.v2.RemoveJobsRequest\x1a\x1e.qm.grpc.v2.RemoveJobsResponse\"\x00\x12Y\n\x08Simulate\x12$.qm.grpc.v2.QmServiceSimulateRequest\x1a%.qm.grpc.v2.QmServiceSimulateResponse\"\x00\x12h\n\x13ResetDigitalFilters\x12&.qm.grpc.v2.ResetDigitalFiltersRequest\x1a\'.qm.grpc.v2.ResetDigitalFiltersResponse\"\x00\x42\x1a\n\x10qm.client.api.v2P\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.grpc.v2.qm_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020qm.client.api.v2P\001\242\002\003HLW'
  _globals['_QMSERVICEGETCONFIGREQUEST']._serialized_start=213
  _globals['_QMSERVICEGETCONFIGREQUEST']._serialized_end=268
  _globals['_UPDATECONFIGREQUEST']._serialized_start=270
  _globals['_UPDATECONFIGREQUEST']._serialized_end=366
  _globals['_UPDATECONFIGRESPONSE']._serialized_start=369
  _globals['_UPDATECONFIGRESPONSE']._serialized_end=723
  _globals['_UPDATECONFIGRESPONSE_UPDATECONFIGRESPONSESUCCESS']._serialized_start=551
  _globals['_UPDATECONFIGRESPONSE_UPDATECONFIGRESPONSESUCCESS']._serialized_end=580
  _globals['_UPDATECONFIGRESPONSE_UPDATECONFIGRESPONSEERROR']._serialized_start=582
  _globals['_UPDATECONFIGRESPONSE_UPDATECONFIGRESPONSEERROR']._serialized_end=705
  _globals['_QMSERVICECLOSEREQUEST']._serialized_start=725
  _globals['_QMSERVICECLOSEREQUEST']._serialized_end=776
  _globals['_QMSERVICECLOSERESPONSE']._serialized_start=779
  _globals['_QMSERVICECLOSERESPONSE']._serialized_end=1068
  _globals['_QMSERVICECLOSERESPONSE_QMSERVICECLOSERESPONSESUCCESS']._serialized_start=971
  _globals['_QMSERVICECLOSERESPONSE_QMSERVICECLOSERESPONSESUCCESS']._serialized_end=1002
  _globals['_QMSERVICECLOSERESPONSE_QMSERVICECLOSERESPONSEERROR']._serialized_start=1004
  _globals['_QMSERVICECLOSERESPONSE_QMSERVICECLOSERESPONSEERROR']._serialized_end=1050
  _globals['_QMSERVICESIMULATEREQUEST']._serialized_start=1071
  _globals['_QMSERVICESIMULATEREQUEST']._serialized_end=1374
  _globals['_QMSERVICESIMULATERESPONSE']._serialized_start=1377
  _globals['_QMSERVICESIMULATERESPONSE']._serialized_end=1518
  _globals['_QMSERVICEJOBSQUERYPARAMS']._serialized_start=1521
  _globals['_QMSERVICEJOBSQUERYPARAMS']._serialized_end=1679
  _globals['_QMSERVICEGETJOBSREQUEST']._serialized_start=1681
  _globals['_QMSERVICEGETJOBSREQUEST']._serialized_end=1750
  _globals['_REMOVEJOBSREQUEST']._serialized_start=1752
  _globals['_REMOVEJOBSREQUEST']._serialized_end=1815
  _globals['_REMOVEJOBSRESPONSE']._serialized_start=1818
  _globals['_REMOVEJOBSRESPONSE']._serialized_end=2104
  _globals['_REMOVEJOBSRESPONSE_REMOVEJOBSRESPONSESUCCESS']._serialized_start=1990
  _globals['_REMOVEJOBSRESPONSE_REMOVEJOBSRESPONSESUCCESS']._serialized_end=2042
  _globals['_REMOVEJOBSRESPONSE_REMOVEJOBSRESPONSEERROR']._serialized_start=2044
  _globals['_REMOVEJOBSRESPONSE_REMOVEJOBSRESPONSEERROR']._serialized_end=2086
  _globals['_QMSERVICEGETCONFIGRESPONSE']._serialized_start=2107
  _globals['_QMSERVICEGETCONFIGRESPONSE']._serialized_end=2247
  _globals['_GETCONFIGSUCCESS']._serialized_start=2249
  _globals['_GETCONFIGSUCCESS']._serialized_end=2314
  _globals['_GETCONFIGERROR']._serialized_start=2316
  _globals['_GETCONFIGERROR']._serialized_end=2349
  _globals['_QMSERVICECOMPILEREQUEST']._serialized_start=2352
  _globals['_QMSERVICECOMPILEREQUEST']._serialized_end=2521
  _globals['_COMPILERESPONSE']._serialized_start=2524
  _globals['_COMPILERESPONSE']._serialized_end=2954
  _globals['_COMPILERESPONSE_COMPILATIONSUCCESS']._serialized_start=2673
  _globals['_COMPILERESPONSE_COMPILATIONSUCCESS']._serialized_end=2766
  _globals['_COMPILERESPONSE_COMPILATIONERROR']._serialized_start=2769
  _globals['_COMPILERESPONSE_COMPILATIONERROR']._serialized_end=2936
  _globals['_QMSERVICEADDTOQUEUEREQUEST']._serialized_start=2957
  _globals['_QMSERVICEADDTOQUEUEREQUEST']._serialized_end=3186
  _globals['_ADDTOQUEUERESPONSE']._serialized_start=3189
  _globals['_ADDTOQUEUERESPONSE']._serialized_end=3652
  _globals['_ADDTOQUEUERESPONSE_ADDTOQUEUERESPONSESUCCESS']._serialized_start=3361
  _globals['_ADDTOQUEUERESPONSE_ADDTOQUEUERESPONSESUCCESS']._serialized_end=3457
  _globals['_ADDTOQUEUERESPONSE_ADDTOQUEUERESPONSEERROR']._serialized_start=3460
  _globals['_ADDTOQUEUERESPONSE_ADDTOQUEUERESPONSEERROR']._serialized_end=3634
  _globals['_QMSERVICEADDCOMPILEDTOQUEUEREQUEST']._serialized_start=3654
  _globals['_QMSERVICEADDCOMPILEDTOQUEUEREQUEST']._serialized_end=3738
  _globals['_ADDCOMPILEDTOQUEUERESPONSE']._serialized_start=3741
  _globals['_ADDCOMPILEDTOQUEUERESPONSE']._serialized_end=4074
  _globals['_ADDCOMPILEDTOQUEUERESPONSE_ADDCOMPILEDTOQUEUERESPONSESUCCESS']._serialized_start=3953
  _globals['_ADDCOMPILEDTOQUEUERESPONSE_ADDCOMPILEDTOQUEUERESPONSESUCCESS']._serialized_end=4004
  _globals['_ADDCOMPILEDTOQUEUERESPONSE_ADDCOMPILEDTOQUEUERESPONSEERROR']._serialized_start=4006
  _globals['_ADDCOMPILEDTOQUEUERESPONSE_ADDCOMPILEDTOQUEUERESPONSEERROR']._serialized_end=4056
  _globals['_QMSERVICEGETJOBSRESPONSE']._serialized_start=4077
  _globals['_QMSERVICEGETJOBSRESPONSE']._serialized_end=4211
  _globals['_RESETDIGITALFILTERSREQUEST']._serialized_start=4213
  _globals['_RESETDIGITALFILTERSREQUEST']._serialized_end=4269
  _globals['_RESETDIGITALFILTERSRESPONSE']._serialized_start=4272
  _globals['_RESETDIGITALFILTERSRESPONSE']._serialized_end=4596
  _globals['_RESETDIGITALFILTERSRESPONSE_RESETDIGITALFILTERSRESPONSESUCCESS']._serialized_start=4489
  _globals['_RESETDIGITALFILTERSRESPONSE_RESETDIGITALFILTERSRESPONSESUCCESS']._serialized_end=4525
  _globals['_RESETDIGITALFILTERSRESPONSE_RESETDIGITALFILTERSRESPONSEERROR']._serialized_start=4527
  _globals['_RESETDIGITALFILTERSRESPONSE_RESETDIGITALFILTERSRESPONSEERROR']._serialized_end=4578
  _globals['_QMSERVICE']._serialized_start=4599
  _globals['_QMSERVICE']._serialized_end=5514
# @@protoc_insertion_point(module_scope)
