# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/job_results.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/job_results.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from qm.grpc.qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17qm/pb/job_results.proto\x12\x18qm.grpc.results_analyser\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cqm/pb/general_messages.proto\x1a\x1cgoogle/protobuf/struct.proto\"*\n\x19GetJobResultSchemaRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\xc9\x01\n\x1aGetJobResultSchemaResponse\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.qm.grpc.results_analyser.GetJobResultSchemaResponse.Item\x1a\x61\n\x04Item\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bsimpleDType\x18\x02 \x01(\t\x12\x10\n\x08isSingle\x18\x03 \x01(\x08\x12\x15\n\rexpectedCount\x18\x04 \x01(\x05\x12\r\n\x05shape\x18\x05 \x03(\x05\"#\n\x12GetJobStateRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"H\n\x13GetJobStateResponse\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12\x0e\n\x06\x63losed\x18\x02 \x01(\x08\x12\x13\n\x0bhasDataloss\x18\x03 \x01(\x08\"W\n\x1eGetJobNamedResultHeaderRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x12\n\nflatFormat\x18\x03 \x01(\x08\"\xde\x01\n\x1fGetJobNamedResultHeaderResponse\x12\x10\n\x08isSingle\x18\x01 \x01(\x08\x12\x12\n\ncountSoFar\x18\x02 \x01(\x05\x12\x13\n\x0bsimpleDType\x18\x03 \x01(\t\x12\x10\n\x04\x64one\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\x12\n\x06\x63losed\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x13\n\x0bhasDataloss\x18\x06 \x01(\x08\x12\r\n\x05shape\x18\x07 \x03(\x05\x12\x36\n\x12hasExecutionErrors\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x91\x01\n\x18GetJobNamedResultRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x12\n\x06offset\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\r\n\x05limit\x18\x04 \x01(\x05\x12/\n\nlongOffset\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"?\n\x19GetJobNamedResultResponse\x12\x14\n\x0c\x63ountOfItems\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"$\n\x13GetJobErrorsRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\"\xa9\x02\n\x14GetJobErrorsResponse\x12\x44\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x34.qm.grpc.results_analyser.GetJobErrorsResponse.Error\x12\r\n\x05jobId\x18\x02 \x01(\t\x1a\x89\x01\n\x05\x45rror\x12\x11\n\terrorCode\x18\x01 \x01(\x05\x12\\\n\rerrorSeverity\x18\x02 \x01(\x0e\x32\x45.qm.grpc.results_analyser.GetJobErrorsResponse.ExecutionErrorSeverity\x12\x0f\n\x07message\x18\x03 \x01(\t\"0\n\x16\x45xecutionErrorSeverity\x12\t\n\x05\x45RROR\x10\x00\x12\x0b\n\x07WARNING\x10\x01\"\\\n\x1aPullAnalysedResultsRequest\x12\x13\n\x0bjobFilePath\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x17\n\x0f\x63ontainsVersion\x18\x03 \x01(\x08\"\xe8\x01\n\x17\x41nalysedResultsResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12;\n\nicpResults\x18\x0b \x03(\x0b\x32\'.qm.grpc.results_analyser.IcpResultData\x12\x41\n\rstreamResults\x18\x0c \x03(\x0b\x32*.qm.grpc.results_analyser.StreamResultData\x12\x36\n\x06\x65rrors\x18\r \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessageJ\x04\x08\x02\x10\x0b\"<\n\x17PullResultOutputRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\"\xca\x04\n\x18PullResultOutputResponse\x12G\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x37.qm.grpc.results_analyser.PullResultOutputResponse.DataH\x00\x12K\n\x06header\x18\x02 \x01(\x0b\x32\x39.qm.grpc.results_analyser.PullResultOutputResponse.HeaderH\x00\x12\x45\n\x03npz\x18\x03 \x01(\x0b\x32\x36.qm.grpc.results_analyser.PullResultOutputResponse.NpzH\x00\x12\x45\n\x03npy\x18\x04 \x01(\x0b\x32\x36.qm.grpc.results_analyser.PullResultOutputResponse.NpyH\x00\x1a\x87\x01\n\x06Header\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61taLoss\x18\x03 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x04 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\x12\x0e\n\x06single\x18\x05 \x01(\x08\x1a/\n\x04\x44\x61ta\x12\'\n\x07results\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\x1a\x12\n\x03Npz\x12\x0b\n\x03npz\x18\x01 \x01(\x0c\x1a/\n\x03Npy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03npy\x18\x02 \x01(\x0c\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x42\n\n\x08response\"\x1d\n\rBinaryWrapper\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x0c\"U\n\x15PullFileResultRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x12\x0f\n\x05\x61sNpz\x18\x04 \x01(\x08H\x00\x42\n\n\x08\x66ileType\"\xaa\x01\n\x12\x46ileResultResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x16\n\x0e\x63ontrollerName\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\r\n\x03npz\x18\x04 \x01(\x0cH\x00\x12\x0f\n\x07version\x18\n \x01(\t\x12\x36\n\x06\x65rrors\x18\x0b \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessageB\x06\n\x04\x66ile\"\x97\x01\n\x1bPullSimulatorSamplesRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x15\n\rincludeAnalog\x18\x02 \x01(\x08\x12\x16\n\x0eincludeDigital\x18\x03 \x01(\x08\x12\x0f\n\x05\x61sNpz\x18\x04 \x01(\x08H\x00\x12\x1d\n\x15includeAllConnections\x18\x05 \x01(\x08\x42\n\n\x08\x66ileType\"\xa4\x02\n\x18SimulatorSamplesResponse\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\n\n\x02ok\x18\x05 \x01(\x08\x12K\n\x06header\x18\x06 \x01(\x0b\x32\x39.qm.grpc.results_analyser.SimulatorSamplesResponse.HeaderH\x00\x12G\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x37.qm.grpc.results_analyser.SimulatorSamplesResponse.DataH\x00\x1a\x33\n\x06Header\x12\x13\n\x0bsimpleDType\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountOfItems\x18\x02 \x01(\x05\x1a\x14\n\x04\x44\x61ta\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\x0c\x42\x06\n\x04\x62odyJ\x04\x08\x02\x10\x05\"\x93\x01\n\rIcpResultData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08\x64\x61taLoss\x18\x03 \x01(\x08\x12\x12\n\x08intValue\x18\x0b \x01(\x05H\x00\x12\x15\n\x0b\x64oubleValue\x18\x0c \x01(\x01H\x00\x12\x16\n\x0c\x62ooleanValue\x18\r \x01(\x08H\x00\x42\x06\n\x04\x64\x61taJ\x04\x08\x04\x10\x0b\"\x8a\x01\n\x10StreamResultData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08\x64\x61taLoss\x18\x03 \x01(\x08\x12\x17\n\x0fmultipleSources\x18\x04 \x01(\x08\x12\x16\n\x0e\x64\x61taSourceName\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x0b \x01(\x03J\x04\x08\x06\x10\x0b\x32\x8c\x05\n\x11JobResultsService\x12\x81\x01\n\x12GetJobResultSchema\x12\x33.qm.grpc.results_analyser.GetJobResultSchemaRequest\x1a\x34.qm.grpc.results_analyser.GetJobResultSchemaResponse\"\x00\x12l\n\x0bGetJobState\x12,.qm.grpc.results_analyser.GetJobStateRequest\x1a-.qm.grpc.results_analyser.GetJobStateResponse\"\x00\x12\x90\x01\n\x17GetJobNamedResultHeader\x12\x38.qm.grpc.results_analyser.GetJobNamedResultHeaderRequest\x1a\x39.qm.grpc.results_analyser.GetJobNamedResultHeaderResponse\"\x00\x12\x80\x01\n\x11GetJobNamedResult\x12\x32.qm.grpc.results_analyser.GetJobNamedResultRequest\x1a\x33.qm.grpc.results_analyser.GetJobNamedResultResponse\"\x00\x30\x01\x12o\n\x0cGetJobErrors\x12-.qm.grpc.results_analyser.GetJobErrorsRequest\x1a..qm.grpc.results_analyser.GetJobErrorsResponse\"\x00\x42*\n\x0fqm.grpc.resultsB\x0fJobResultsProtoP\x01\xa2\x02\x03HLWb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.job_results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017qm.grpc.resultsB\017JobResultsProtoP\001\242\002\003HLW'
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE'].fields_by_name['done']._loaded_options = None
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE'].fields_by_name['done']._serialized_options = b'\030\001'
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE'].fields_by_name['closed']._loaded_options = None
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE'].fields_by_name['closed']._serialized_options = b'\030\001'
  _globals['_GETJOBNAMEDRESULTREQUEST'].fields_by_name['offset']._loaded_options = None
  _globals['_GETJOBNAMEDRESULTREQUEST'].fields_by_name['offset']._serialized_options = b'\030\001'
  _globals['_GETJOBRESULTSCHEMAREQUEST']._serialized_start=145
  _globals['_GETJOBRESULTSCHEMAREQUEST']._serialized_end=187
  _globals['_GETJOBRESULTSCHEMARESPONSE']._serialized_start=190
  _globals['_GETJOBRESULTSCHEMARESPONSE']._serialized_end=391
  _globals['_GETJOBRESULTSCHEMARESPONSE_ITEM']._serialized_start=294
  _globals['_GETJOBRESULTSCHEMARESPONSE_ITEM']._serialized_end=391
  _globals['_GETJOBSTATEREQUEST']._serialized_start=393
  _globals['_GETJOBSTATEREQUEST']._serialized_end=428
  _globals['_GETJOBSTATERESPONSE']._serialized_start=430
  _globals['_GETJOBSTATERESPONSE']._serialized_end=502
  _globals['_GETJOBNAMEDRESULTHEADERREQUEST']._serialized_start=504
  _globals['_GETJOBNAMEDRESULTHEADERREQUEST']._serialized_end=591
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE']._serialized_start=594
  _globals['_GETJOBNAMEDRESULTHEADERRESPONSE']._serialized_end=816
  _globals['_GETJOBNAMEDRESULTREQUEST']._serialized_start=819
  _globals['_GETJOBNAMEDRESULTREQUEST']._serialized_end=964
  _globals['_GETJOBNAMEDRESULTRESPONSE']._serialized_start=966
  _globals['_GETJOBNAMEDRESULTRESPONSE']._serialized_end=1029
  _globals['_GETJOBERRORSREQUEST']._serialized_start=1031
  _globals['_GETJOBERRORSREQUEST']._serialized_end=1067
  _globals['_GETJOBERRORSRESPONSE']._serialized_start=1070
  _globals['_GETJOBERRORSRESPONSE']._serialized_end=1367
  _globals['_GETJOBERRORSRESPONSE_ERROR']._serialized_start=1180
  _globals['_GETJOBERRORSRESPONSE_ERROR']._serialized_end=1317
  _globals['_GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY']._serialized_start=1319
  _globals['_GETJOBERRORSRESPONSE_EXECUTIONERRORSEVERITY']._serialized_end=1367
  _globals['_PULLANALYSEDRESULTSREQUEST']._serialized_start=1369
  _globals['_PULLANALYSEDRESULTSREQUEST']._serialized_end=1461
  _globals['_ANALYSEDRESULTSRESPONSE']._serialized_start=1464
  _globals['_ANALYSEDRESULTSRESPONSE']._serialized_end=1696
  _globals['_PULLRESULTOUTPUTREQUEST']._serialized_start=1698
  _globals['_PULLRESULTOUTPUTREQUEST']._serialized_end=1758
  _globals['_PULLRESULTOUTPUTRESPONSE']._serialized_start=1761
  _globals['_PULLRESULTOUTPUTRESPONSE']._serialized_end=2347
  _globals['_PULLRESULTOUTPUTRESPONSE_HEADER']._serialized_start=2082
  _globals['_PULLRESULTOUTPUTRESPONSE_HEADER']._serialized_end=2217
  _globals['_PULLRESULTOUTPUTRESPONSE_DATA']._serialized_start=2219
  _globals['_PULLRESULTOUTPUTRESPONSE_DATA']._serialized_end=2266
  _globals['_PULLRESULTOUTPUTRESPONSE_NPZ']._serialized_start=2268
  _globals['_PULLRESULTOUTPUTRESPONSE_NPZ']._serialized_end=2286
  _globals['_PULLRESULTOUTPUTRESPONSE_NPY']._serialized_start=2288
  _globals['_PULLRESULTOUTPUTRESPONSE_NPY']._serialized_end=2335
  _globals['_BINARYWRAPPER']._serialized_start=2349
  _globals['_BINARYWRAPPER']._serialized_end=2378
  _globals['_PULLFILERESULTREQUEST']._serialized_start=2380
  _globals['_PULLFILERESULTREQUEST']._serialized_end=2465
  _globals['_FILERESULTRESPONSE']._serialized_start=2468
  _globals['_FILERESULTRESPONSE']._serialized_end=2638
  _globals['_PULLSIMULATORSAMPLESREQUEST']._serialized_start=2641
  _globals['_PULLSIMULATORSAMPLESREQUEST']._serialized_end=2792
  _globals['_SIMULATORSAMPLESRESPONSE']._serialized_start=2795
  _globals['_SIMULATORSAMPLESRESPONSE']._serialized_end=3087
  _globals['_SIMULATORSAMPLESRESPONSE_HEADER']._serialized_start=3000
  _globals['_SIMULATORSAMPLESRESPONSE_HEADER']._serialized_end=3051
  _globals['_SIMULATORSAMPLESRESPONSE_DATA']._serialized_start=3053
  _globals['_SIMULATORSAMPLESRESPONSE_DATA']._serialized_end=3073
  _globals['_ICPRESULTDATA']._serialized_start=3090
  _globals['_ICPRESULTDATA']._serialized_end=3237
  _globals['_STREAMRESULTDATA']._serialized_start=3240
  _globals['_STREAMRESULTDATA']._serialized_end=3378
  _globals['_JOBRESULTSSERVICE']._serialized_start=3381
  _globals['_JOBRESULTSSERVICE']._serialized_end=4033
# @@protoc_insertion_point(module_scope)
